/*****************************************************
*Adverse event summary program;
*Description:  Read Demographic (1 rec/subject) and AE (1 rec/AE) datasets and generate AE summary table ;
*Change History:
*  1/31/2008 - J. Shipway.  Added Relationship To Study Drug as outer grouping
*****************************************************/


*define variable names;
%let subjid = USUBJID;
%let treat= &TrtName;  *treatment group;
%let advp = AEDECOD;  *AE prefered term;
%let advbs = AEBODSYS; *AE body system;
%let advsev=AESEV; *AE severity;
%let advrel=AEREL; *AE relationship to study drug;

options nofmterr nosymbolgen;



******Step 1***********;
* Select patient population; 
data pop(keep=&subjid &treat);
   set &in_adsl end = eof;
   *population subsetting statements here;
   *if age lt 40;
   if eof then call symput("vartype", vtype(&treat));    
run;
proc sort data=pop; by &subjid; run;

*select only subjects in pop;
data temp;
   *merge pop(in=inpop) nicsah1.ae(obs=1000 in=inae);
   merge pop(in=inpop) teae;
   by &subjid;
   if inpop;
run;

proc sort data = TEMP out = POP1(keep = &trtname);
	by &trtname;
run;
proc sort nodupkey data = POP1 out = POP1;
	by &trtname;
run;
%SortRowsByValueOrdering(POP1, &treat);
data POP1;
	set POP1 end = eof;
	trtnum = _n_;
	call symput('TRT'||left(_n_), &trtname);
	if eof then call symput('maxtrt', left(_n_));
run;

******Step 2***********;
* Summarize population counts by treatment;
proc summary data=pop nway;
   class &treat;
   output out=nsubj(drop=_type_ rename=(_freq_=nsubj));
run;

******Step 3***********;
*summarize to 1 rec/sub/unique AE(optionally severity/ relationship);
proc summary data=temp;
   class &advrel &advbs &advp &subjid &treat; * &advsev &advrel;
   output out=uniqueae(drop=_freq_ rename=(_type_=level));
   types &subjid*&treat &subjid*&treat*&advrel &subjid*&treat*&advrel*&advbs &subjid*&treat*&advrel*&advbs*&advp;
run;

******Step 4***********;
*summarize to overall, body system, preferred term, including empty cells;
proc freq data=uniqueae noprint;
   *need to look at this proc...do we put advrel in both the by and table statements?;
   by &advrel &advbs notsorted;
   table &advrel*&advp*&treat/ out=count missing sparse;
run;
proc sort data=count;
   by &treat &advrel &advbs &advp;
run;
proc sort data=nsubj; by &treat; run;

******Step 5***********;
* add population counts and generate complements(no ae counts) for PROC Freq statistics;
data aefreq;
   merge count nsubj;
   by &treat;
   *add summary level labels;
   if &advrel eq ' ' then &advp=" Any Relationship";
   if &advbs eq ' ' then &advp=" Any Adverse Events";
   if &advp eq ' ' then &advp=' Total';
   drop level _type_ nsubj;
   ae="yes";
   output;
   ae="no";
   count=nsubj-count;
   output;
run;

proc sort;
   by &advrel &advbs &advp;
run;

******Step 6***********;
data aestat;
   if (0);
run;

* compute p values and subset out ae='yes' records;
proc freq data=aefreq noprint order=data;
   by   &advrel &advbs &advp notsorted;
   table ae*&treat/out=aecount(where=(ae='yes')drop=percent pct_row) 
      outpct missing sparse;
   exact fisher / n=10000 maxtime=10;
   weight count;
   output fisher  out=aestat;
run;

* check if there is any obervations in aestat. If no obs, it will not run the following part;
%NObsVars(aestat);
%macro TAB;
   %if &nobs >0 %then %do;
      *merge pvalue into counts;
/*      data aefinal;*/
/*         merge aecount aestat;*/
/*         by &advrel &advbs &advp;*/
/*      run;*/

	  	 PROC SORT DATA=AECOUNT; BY &treat; run;
		 proc sort data=pop1; by &treat; run;
		 data aecount;
		 	merge aecount pop1;
			by &treat;
		 run;
		 proc sort data=aecount; by &advrel &advbs &advp; run;
         data aefinal;
            merge aecount aestat;
            BY &advrel &advbs &advp;
			if &advp ^="";
			value = catx(" ",count,cats("(",round(pct_col,1),")"));
         run;

		 proc sort data = aefinal;
		   by &advrel &advbs &advp xp2_fish;
		 run;
		** PROC REPORT format dataset;
		proc transpose data =aefinal out = stats;
		   by &advrel &advbs &advp xp2_fish;
		   id trtnum;
		   var value;
		run;
		*** Fill in 0 cells;
		data stats;
		   set stats;
		   %do i = 1 %to &maxtrt;
		      if _&i = "" then  _&i = "0 (0)";
		   %end;
		run;

      ******Step 7***********;
      * display table;
      proc format;
         picture pct low-high='09)'( prefix='(');
      run;


      %let domain = Adverse Events;
      %let title = Incidence of Treatment-Emergent Adverse Events Related to Study Drug by System Organ Class and Preferred Term;

/*      PROC REPORT DATA=WORK.aefinal LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&title";*/
/*         break before &advbs/skip;*/
/*         COLUMN  &advrel &advbs &ADVP  &treat,( COUNT PCT_COL) xp2_fish;*/
/*   */
/*         DEFINE  &advrel / group FORMAT= $28. WIDTH=28     SPACING=2   LEFT "Rel. To Study Drug" order=data;*/
/*         DEFINE  &advbs / group FORMAT= $&aebodsyslen.. WIDTH=21   SPACING=2   LEFT "Body System" order=data;*/
/*         DEFINE  &ADVP / group FORMAT= $&aedecodlen.. WIDTH=21    SPACING=2   LEFT "Reported Term for AE" order=data;*/
/*         DEFINE  &TREAT / across %if &vartype = C %then %do; FORMAT= $&armlen.. %end; WIDTH=10    SPACING=2   LEFT*/
/*         "&TrtLabel" ;*/
/*         DEFINE  COUNT / SUM FORMAT= BEST9. WIDTH=9     SPACING=2   RIGHT "N" ;*/
/*         DEFINE  PCT_COL / SUM FORMAT= pct4. WIDTH=9     SPACING=2  left "(%)";*/
/*         Define xp2_fish/min format=5.4  width=9 "Fishers Exact P-value";*/
/**/
/*         title "&title";*/
/*         title2 "ICHE3 Table 14.3.1.2";*/
/*         ods proclabel = "&domain";       */
/*      RUN;*/


%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;

	PROC REPORT DATA=WORK.STATS LS=97  PS=54  SPLIT="|" CENTER nowindows missing contents="&Title.";
         break before &advbs/skip;
/*         COLUMN  &advrel &advbs &ADVP  &treat,( COUNT PCT_COL) xp2_fish;*/
   		 column &advrel &advbs &ADVP ("^S={borderbottomcolor=black borderbottomwidth=2} &trtlabel" %do i = 1 %to &maxtrt; _&i %end;)  xp2_fish;

         DEFINE  &advrel / id group FORMAT= $28. style(column)=[cellwidth=9%]     SPACING=2   LEFT "Rel. To Study Drug" order=data style(header)={just=l};
         DEFINE  &advbs / id group FORMAT= $&aebodsyslen.. style(column)=[cellwidth=15%]   SPACING=2   LEFT "Body System" order=data style(header)={just=l};
         DEFINE  &ADVP / id group FORMAT= $&aedecodlen.. style(column)=[cellwidth=15%]    SPACING=2   LEFT "Reported Term for AE" order=data style(header)={just=l};
         %do i = 1 %to &maxtrt; 
		      %if %sysfunc(mod(&i,6))=0 %then %do;
		         define _&i / page display "&&TRT&i||(N=&&TrtCount&i)" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		      %else %do;
		         define _&i / display "&&TRT&i||(N=&&TrtCount&i)" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		   %end; 
   
		   %if %sysfunc(mod(&maxtrt,5))=0 %then %do;
		   		define xp2_fish / page min format=5.4  width=9 "Fishers Exact P-value";
		   %end;
   		   %else %do;
		   		define xp2_fish / min format=5.4  width=9 "Fishers Exact P-value";
		   %end;
         title "&title";
         title2 "ICHE3 Table 14.3.1.2";
         ods proclabel = "&domain";       
      RUN;
      *ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
   %end;
%mend TAB;
%TAB;

proc datasets nolist;
   delete temp aecount aestat POP1;
quit;
%postProcess;





