/*************************************

Hepatotoxicity Evaluation
Author:  John Shipway, SAS Institute
Date:  January 17, 2008
Description: For a given serum chemistry parameter, give a report listing
of the rate of the tested values and a given multiplier of the upper
limit of normal (ULN).

**************************************/


*%let chemval = "Total Bilirubin";
*%let chemval = "SGOT/AST";
*%let chemval = "SGPT/ALT";
*%let chemval = "Alkaline Phosphatase";
*%let chemval = "Transaminase";

%let treat=&TrtName;  *treatment group;

%let multiplierThreshhold = 1.5;

* Select patient population; 
data pop(keep=usubjid &treat);
   set dm end = eof;
   if eof then call symput("vartype", vtype(&treat)); 
run;

*load lab data;
data lab;
   set lb;
   *calculate the multiplier between the tested value and the ULN;
   Multiplier = lbstresn / lbstnrhi;
   where 
      index(upcase(lbtest),"BILI") or 
      index(upcase(lbtest),"AST") or 
      index(upcase(lbtest),"ALT") or 
      index(upcase(lbtest),"ALKALINE") or 
      index(upcase(lbtest),"TRANSAMINASE")
   ;
run;

*merge lab with dm so we can segment by treatment;
data labpop;
   merge pop(in=inpop) lab;
   by usubjid;
   if inpop;
run;


*get a listing of the unique subjects who had this serum;
*chemistry value drawn;
proc summary data=labpop nway;
   class usubjid &treat;
   output out=totallabpopcount(drop=_type_ rename=(_freq_=ntotal));
run;

proc summary data=totallabpopcount;
   class &treat;
   output out=totalsummarycount(drop=_type_ rename=(_freq_=ntotal));
run;


proc sort data=labpop;
   by &treat;
run;

proc sort data=totallabpopcount;
   by &treat;
run;


data labwithcounts;
   merge labpop(in=inlabpop) totalsummarycount;
   by &treat;  
   if inlabpop;
run;


data reportdata;
   set labwithcounts;
   where multiplier >= &multiplierThreshhold;
run;

proc sort data=reportdata;
   by usubjid;
run;

%macro TAB;
%let domain = Labs;
%let title = Hepatotoxicity Evaluation: Listing of Patients with Result >= &multiplierThreshhold Times the Upper Limit of Normal;
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
PROC REPORT DATA=WORK.reportdata LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title.";
   COLUMN  studyid usubjid  &treat lbdtc lbtest lbstresn lbstnrhi lbstresu Multiplier;    

   DEFINE  STUDYID /id GROUP FORMAT= $&studlen.. WIDTH=7     SPACING=2   LEFT "Trial" style(header)={just=l};   
   DEFINE  USUBJID /id GROUP FORMAT= $&sublen.. WIDTH=10     SPACING=2   LEFT "Patient" order=data style(header)={just=l};
   DEFINE  &treat /  GROUP %if &vartype = C %then %do; FORMAT= $&armlen.. %end; WIDTH=30     SPACING=2   LEFT "&TrtLabel" order=data style(header)={just=l};         
   DEFINE  lbdtc / FORMAT=$10. WIDTH=10     SPACING=2   LEFT "Date of Visit" order=data style(header)={just=l};
   DEFINE  lbtest / FORMAT=$&lbtestlen.. WIDTH=10     SPACING=2   LEFT "Lab" order=data style(header)={just=l};
   DEFINE  lbstresn / FORMAT=8.2 WIDTH=10 SPACING=2 LEFT "Result" style(header)={just=l};
   DEFINE  lbstnrhi / FORMAT=8.2 WIDTH=10 SPACING=2 LEFT "ULN" style(header)={just=l};
   DEFINE  Multiplier / FORMAT= 5.2 WIDTH=7     SPACING=2   LEFT "Multiple of ULN" order=data style(header)={just=l};

   title "&title";
   title2 "GRP Table 7.1.7.5.1";
   ods proclabel = "&domain";       
RUN;
* ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%mend TAB;
%TAB;

%postProcess;

