/*************************************

Incidence of Potentially Clinically Significant Changes in Serum Chemistry Parameters
Author:  John Shipway, SAS Institute
Date:  January 3, 2008
Description: 

This is a listing of patients who were normal at baseline for a given serum
chemistry parameter, but then became abnormal at some point.

The noduplicates in the proc sort removes the dups so that we know a single patient 
had a high\low value for a given serum chemistry parm.


todo: 

1) see what to do if result exactly equals threshhold, is this a = or a <=...
2) The GRP says to provide a separate listing of patients who were also abnormal at baseline.
3) we are assuming that if the data is in the ADaM table, they have at least a baseline visit
   and an additional visit, need to verify this.

**************************************/

%macro MCB;
%if %sysfunc(findw(%upcase(&LBVARS), %upcase(LBBLFL))) %then %do;
   %let treat=&TrtName;  *treatment group;

   /*============ V8 =============*/
	  	proc sort data = &in_adsl out = adsl(keep =usubjid &trtname);
		   by &trtname;
		run;

		proc sort nodupkey data = adsl out = trts;
		   by &trtname;
		run;
		%SortRowsByValueOrdering(trts, &treat);

		data trts;
		  set trts end = eof;
		  trtnum = _n_;
		  call symput('TRT'||left(_n_), &trtname);
		  if eof then call symput('maxtrt', left(_n_));
		run;

		%let TRT999 = %nrbquote(%LocaleGet(Total_Text));

		proc sort data=trts;
			by &treat;
		run;
		proc sort data=adsl;
			by &treat;
		run;
		data adsl;
			merge adsl trts;
			by &treat;
		run;
		proc sort data = adsl;
			by usubjid;
		run;
		data subjects(keep = usubjid trtnum int);
		   set adsl;
		   by usubjid;
		   int = 1;
		   if first.usubjid;
		run;
		** Total counts per regimen and overall;
		proc means noprint data = subjects;
		   class trtnum;
		   var int;
		   output out = treattots n = n;
		run;
		data _null_;
		   set treattots;
		   if trtnum = . then trtnum = 999;
		   call symputx("TrtCount"||trim(left(trtnum)),strip(n));
		run;
		/*================================*/
		proc sort data=lb; by usubjid; run;
		proc sort data=subjects; by usubjid; run;
		data lb;
			merge lb(in = ina) subjects(in=inb);
			by usubjid;
			if ina and inb;
		run;

   data labdata(keep=usubjid lbtest lbstnrlo lbstnrhi lbstresu lbstresn lbtestlow lbtesthigh &treat trtnum);
      *set admstudy.adlbc;
      set lb end = eof;
      *add the low test column;
      lbtestlow = strip(lbtest) || "-L (<" || strip(lbstnrlo) || " " || strip(lbstresu) || ")";
      *add the high test column;
      lbtesthigh = strip(lbtest) || "-H (>" || strip(lbstnrhi) || " " || strip(lbstresu) || ")";
      *check for baseline being normal;
      *where bltrfl ne 'Y';
      where lbblfl ne 'Y';
      if eof then call symput("vartype", vtype(&treat));    
   run;


   /* get total counts of test per treatment */

   data totals(keep=usubjid lbtesthigh lbtestlow lbtest &treat trtnum);  
      set labdata;
   run;


   proc sort data=totals out=totalsunique noduplicates;
      by usubjid lbtest;
   run;


   proc summary data=totalsunique nway;
      class lbtestlow trtnum;
      output out=totallowcounts(drop=_type_ rename=(_freq_=ntotal lbtestlow=test));
   run;

   proc summary data=totalsunique nway;
      class lbtesthigh trtnum;
      output out=totalhighcounts(drop=_type_ rename=(_freq_=ntotal lbtesthigh=test));
   run;


   data totalcounts;
      set totallowcounts totalhighcounts;
   run;


   /* Now focus on outliers */

   data lablows(keep=usubjid test &treat trtnum);
      set labdata;
      where lbstresn < lbstnrlo;
      test = lbtestlow;
   run;

   *remove the dups so we see distinct patient\low rows;
   proc sort data=lablows out=lablowsunique noduplicates;
      by usubjid test;
   run;


   data labhighs(keep=usubjid test &treat trtnum);
      set labdata;
      where lbstresn > lbstnrhi;
      test = lbtesthigh;
   run;


   *remove the dups so we see distinct patient\high rows;
   proc sort data=labhighs out=labhighsunique noduplicates;
      by usubjid test;
   run;

   *combine the low and high data sets;
   data combineddata;
      set lablowsunique labhighsunique;
   run;

   *get summary counts of outliers;
   proc summary data=combineddata nway;
      class test trtnum;
      output out=outliercounts(drop=_type_ rename=(_freq_=nabnormal));
   run;

   *sort so we can merge;
   proc sort data=totalcounts;
      by test trtnum;
   run;


   *sort so we can merge;
   proc sort data=outliercounts;
      by test trtnum;
   run;



   *merge totals with outliers;
   data reportdata;
      merge outliercounts totalcounts;
      by test trtnum;
	  if nabnormal=. then nabnormal=0;
      percentage = nabnormal / ntotal;
   run;

   data reportdata2;
      set reportdata;
	  length show $30.;
	  show = catx(" ",cats(nabnormal,"/" ,ntotal), cats("(",round(percentage*100,1),")"));
   run;
   proc sort data = reportdata2;
		   by test trtnum;
		run;
	** PROC REPORT format dataset;
	proc transpose data = reportdata2 out = stats;
		   by test;
		   id trtnum;
		   var show;
	run;

   %macro TAB;
   %let domain = Labs;
   %let title = Incidence of Potentially Clinically Significant Changes in Serum Chemistry Parameters;

/*   PROC REPORT DATA=WORK.reportdata2 LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&title";*/
/**/
/*      COLUMN  test &treat,(ntotal nabnormal percentage);*/
/**/
/*      DEFINE  test / GROUP FORMAT= $&lbtestlen.. WIDTH=50    SPACING=2   LEFT "Lab Test" order=data;     */
/*      DEFINE  &treat / ACROSS %if &vartype = C %then %do; FORMAT= $&armlen.. %end; WIDTH=40    SPACING=3   LEFT "&TrtLabel" ;*/
/*      DEFINE  ntotal / FORMAT=5.0 WIDTH=9     SPACING=2  left "Total Pts";*/
/*      DEFINE  nabnormal / FORMAT=5.0 WIDTH=9     SPACING=2  left "N Abnormal";*/
/*      DEFINE percentage / format=5.2  width=9 SPACING=2 left "% Abnormal"; */
      title "&title";
      title2 "GRP Table 7.1.7.3.2.1";
/*   RUN;*/
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
	proc report data = stats(drop = _name_) SPLIT="|" CENTER nowindows missing contents="&Title.";
		   column test ("^S={borderbottomcolor=black borderbottomwidth=2} &trtlabel" %do i = 1 %to &maxtrt; _&i %end;);
		   define test / id order left "Lab Test" style(header)={just=l} style(column)=[cellwidth=15%]; 
		   %do i = 1 %to &maxtrt; 
		      %if %sysfunc(mod(&i,6))=0 %then %do;
		         define _&i / page display "&&TRT&i||(N=&&TrtCount&i)||N abnormal/Total Pts ||(% Abnormal)" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		      %else %do;
		         define _&i / display "&&TRT&i||(N=&&TrtCount&i)||N abnormal/Total Pts ||(% Abnormal)" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		   %end; 
		   ods proclabel = "&domain";       
	run;
	*ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
   %mend TAB;
   %TAB;

   %postProcess;
%end;
%else %do;
   %let title = Incidence of Potentially Clinically Significant Changes in Serum Chemistry Parameters;   
	%if &Output_RTF = Yes %then %do;
	ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
	%END;
	data aa;
      length text $ 200;
      text = "LBBLFL not available. &title not generated.";
      label text = "Note:";
   run;

   proc print noobs label data = aa;
   run;  
%end;
%mend MCB;
%MCB;



