/*
Name: SAS Clinical Toolkit Macros
Authors: Richard C. Zink, SAS Institute Inc.

Description: 

   - MAKEDIR:           Checks for existence of a directory and creates if not available
   - TRANSSUPP:         Transforms SUPP data sets to merge onto main domains
   - CREATEMETADATA:    Calls CST macros to generate metadata and define.xml files for SDTM and ADaM
   - IDENTIFYDOMAINS:   Generates a list of all domains from the SDTM/ADAM directories that are of 
                        length 2 and are not ADaM BDS.  A flag indicating presence or  absence of ADSL 
                        is also generated.  Domain Class is derived within this macro
   - MISSVARS:          Creates data set of null variables                        
   - METADATAOUTFILES:  Creates text files of DM and ADSL Variables, Findings Domains Test Codes,
                        Domain Classes (Events, Interventions and Findings), and CSTMacros.sas which
                        contains macro variable lists of a) domains and b) variables present within
                        each data set considering whether domain is represented by ADAM or SDTM and
                        whether supplemental qualifier data is present from SUPPXX data sets. Also
                        assigns domain libraries to each available domain.
   - GENERATEMETA       Creates all needed metadata for a study
   - CHKSTUDYNAME       Checks for Special Characters
   - KEYS               Derives keys based on data set sort or SDTM IG
   - COMPARE            When NewSnap = Yes, the current data directories will be compared to previous
                        directories to identify any new or modified records
   - GETPREVDATA        Creates a DeltaFile# file which contains libnames and data set macro variables
                        of previous snapshot
   - MAKENOTES          Creates notes directory, ADSLRS and ADSLRSL and updates ADSLRS with new subjects
   - UPDATESUBJECTFLAGS Changes flags in ADSLRS
   - TOOLKITME          Gets necessary study metadata
   - DROPVARS           Removes variables from snapshot comparisons
   - UPDATELENGTH       Update length of USUBJID, COUNTRY, SITEID in notes
   - CHKBLIND           This macro will check if ARM is null and will impute values of Blinded Treatment.
*/

/*
-----------------------------------------------------------
Copyright (C) 2011 SAS Institute, Inc. All rights reserved. 

Notice: 
The above copyright notice and this notice must appear in
any whole or partial copy of this code and any related
documentation. Permission to use, copy, and modify the
source code contained in this file is hereby granted, but
is limited to customers of SAS with a valid license for the
SAS software product with which this file was provided. 
Except as expressly set forth herein, the terms of such
license apply.
-----------------------------------------------------------
*/

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

*** options nomprint nomlogic nosymbolgen;

%macro TOOLKITME;
   %put Entering TOOLKITME;
   %ClockStart(TOOLKITME);  
   
   %if %length(&InPath) %then %do;
      proc contents data = sdtm._all_ noprint out = sdtm(keep = memname memlabel name label nobs where = (nobs > 0));
      run;
      %if %symexist (SDTMDom) %then %do;
          %if %length(&SDTMDom) %then %do;
            %let i = 1;
            %let quotedSDTM =;
            %do %while(%length(%scan(&SDTMDom,&i,' ')));
               %let SDTMDomV&i = %upcase(%scan(&SDTMDom,&i,' '));
               %let quotedSDTM = &quotedSDTM "&&SDTMDomV&i";
               %let i = %eval(&i+1);
            %end;
            data sdtm;
               set sdtm;   
               if upcase(memname) in (&quotedSDTM);;
            run;
          %end;
      %end;
      %if &SpltDomainFlag %then %do;
      	proc contents data = sdtmsp._all_ noprint out = sdtmsp(keep = memname memlabel name label nobs where = (nobs > 0));
      	run;
      	* for selected domains;
      	%if %symexist (SDTMDom) %then %do;
      		%if %length(&SDTMDom) %then %do;
      			%if %length(&quotedSDTM) %then %do;
						data sdtmsp;
	            	   set sdtmsp;   
	            	   if upcase(memname) in (&quotedSDTM);;
	            	run;
	            %end;
      		%end;
      	%end;
			proc datasets lib=sdtmsp memtype=data nolist;
				ods output members=sdtmnousedDomSP (keep=Name MemType);
				contents data=_all_;
			quit;
			data sdtmnousedDomSP;
				set sdtmnousedDomSP;
				Folder = "SDTM/SPLIT";
			run;
      %end;
      ods exclude all;
      ods noresults;
      proc datasets lib=sdtm memtype=data nolist;
         ods output members=sdtmnousedDom (keep=Name MemType);
         contents data=_all_;
      quit;
      ods exclude none;
      ods results; 
      data sdtmnousedDom;
         set sdtmnousedDom;
         Folder = "SDTM";
      run;
   %end;
   
   %put [AddStudyLocal_~TOOLKITME AInPath~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.06];
   
   %if %length(&AInPath) %then %do;
      proc contents data = adam._all_ noprint out = adam(keep = memname memlabel name label nobs where = (nobs > 0));
      run;
      %if %symexist (ADaMDom) %then %do;
          %if %length(&ADaMDom) %then %do;
            %let i = 1;
            %let quotedADaM =;
            %do %while(%length(%scan(&ADaMDom,&i,' ')));
               %let ADaMDomV&i = %upcase(%scan(&ADaMDom,&i,' '));
               %let quotedADaM = &quotedADaM "&&ADaMDomV&i";
               %let i = %eval(&i+1);
            %end;
            data adam;
               set adam;   
               if upcase(memname) in (&quotedADaM);;
            run;
          %end;
      %end;
      ods exclude all;
      ods noresults;
      proc datasets lib=adam memtype=data nolist;
         ods output members=adamnousedDom (keep=Name MemType);
         contents data=_all_;
      quit;
      ods exclude none;
      ods results; 
      data adamnousedDom;
         set adamnousedDom;
         Folder = "ADaM";
      run;
   %end;
    
   *** Determine if SEND model based on dialog flag ***;
   %if %nrbquote(&StudyType) = %str(Non-Clinical) %then %let SEND = 1;
   %else %let SEND = 0;

   proc datasets nolist;
      delete dm;
   quit;
   
   %let trDemographics = %nrbquote(%LocaleGet(Demographics_Text));
   %let trSubjectElements = %nrbquote(%LocaleGet(SubjectElements_Text));
   %let trComments = %nrbquote(%LocaleGet(Comments_Text));
   %let trExposure = %nrbquote(%LocaleGet(Exposure_Text));
   %let trDisposition = %nrbquote(%LocaleGet(Disposition_Text));
   %let trLaboratoryTestResults = %nrbquote(%LocaleGet(LaboratoryTestResults_Text));
   %let trVitalSigns = %nrbquote(%LocaleGet(VitalSigns_Text));
   %let trECGTestResults = %nrbquote(%LocaleGet(ECGTestResults_Text));
   %let trPKConcentrations = %nrbquote(%LocaleGet(PKConcentrations_Text));
   %let trPKParameters = %nrbquote(%LocaleGet(PKParameters_Text));
   %let trSubjectCharacteristics = %nrbquote(%LocaleGet(SubjectCharacteristics_Text));
   %let trTrialArms = %nrbquote(%LocaleGet(TrialArms_Text));
   %let trTrialElements = %nrbquote(%LocaleGet(TrialElements_Text));
   %let trTrialSummary = %nrbquote(%LocaleGet(TrialSummary_Text));
   %let trRelatedRecords = %nrbquote(%LocaleGet(RelatedRecords_Text));
   %let trSupplementalQualifiers = %nrbquote(%LocaleGet(SupplementalQualifiers_Text));
   %let trBodyWeights = %nrbquote(%LocaleGet(BodyWeights_Text));
   %let trBodyWeightGains = %nrbquote(%LocaleGet(BodyWeightGains_Text));
   %let trClinicalObservations = %nrbquote(%LocaleGet(ClinicalObservations_Text));
   %let trDeathDiagnosis = %nrbquote(%LocaleGet(DeathDiagnosis_Text));
   %let trFoodandWaterConsumption = %nrbquote(%LocaleGet(FoodandWaterConsumption_Text));
   %let trMacroscopicFindings = %nrbquote(%LocaleGet(MacroscopicFindings_Text));
   %let trMicroscopicFindings = %nrbquote(%LocaleGet(MicroscopicFindings_Text));
   %let trOrganMeasurements = %nrbquote(%LocaleGet(OrganMeasurements_Text));
   %let trPalpableMasses = %nrbquote(%LocaleGet(PalpableMasses_Text));
   %let trTumorFindings = %nrbquote(%LocaleGet(TumorFindings_Text));
   %let trTrialSets = %nrbquote(%LocaleGet(TrialSets_Text));
   %let trPooling = %nrbquote(%LocaleGet(Pooling_Text));
   %let trSubjectVisits = %nrbquote(%LocaleGet(SubjectVisits_Text));
   %let trConcomitantMedications = %nrbquote(%LocaleGet(ConcomitantMedications_Text));
   %let trSubstanceUse = %nrbquote(%LocaleGet(SubstanceUse_Text));
   %let trAdverseEvents = %nrbquote(%LocaleGet(AdverseEvents_Text));
   %let trMedicalHistory = %nrbquote(%LocaleGet(MedicalHistory_Text));
   %let trClinicalEvents = %nrbquote(%LocaleGet(ClinicalEvents_Text));
   %let trProtocolDeviations = %nrbquote(%LocaleGet(ProtocolDeviations_Text));
   %let trQuestionnaires = %nrbquote(%LocaleGet(Questionnaires_Text));
   %let trMicrobiologySpecimen = %nrbquote(%LocaleGet(MicrobiologySpecimen_Text));
   %let trInclusionExclusionCritNotMet = %nrbquote(%LocaleGet(InclusionExclusionCriterionNotMet_Text));
   %let trPhysicalExamination = %nrbquote(%LocaleGet(PhysicalExamination_Text));
   %let trDrugAccountability = %nrbquote(%LocaleGet(DrugAccountability_Text));
   %let trMicrobiologySuscTest = %nrbquote(%LocaleGet(MicrobiologySusceptibilityTest_Text));
   %let trFindingsAbout = %nrbquote(%LocaleGet(FindingsAbout_Text));
   %let trTrialVisits = %nrbquote(%LocaleGet(TrialVisits_Text));
   %let trTrialInclusionExclusionCrit = %nrbquote(%LocaleGet(TrialInclusionExclusionCriteria_Text));
   %let trEvents = %nrbquote(%LocaleGet(Events_Text));
   %let trInterventions = %nrbquote(%LocaleGet(Interventions_Text));
   %let trFindings = %nrbquote(%LocaleGet(Findings_Text));
   %let trSpecial = %nrbquote(%LocaleGet(Special_Text));
   %let trTrialDesign = %nrbquote(%LocaleGet(TrialDesign_Text));
   %let trRelationship = %nrbquote(%LocaleGet(Relationship_Text));
   %let trOther = %nrbquote(%LocaleGet(Other_Text));
   %let trSplitting = %nrbquote(%LocaleGet(Splitting_Text));
   %let trSplit = %nrbquote(%LocaleGet(Split_Text));
   %let trTableName = %nrbquote(%LocaleGet(TableName_Text));
   %let trLabel = %nrbquote(%LocaleGet(Label_Text));
   %let trObservationClasswithinStand = %nrbquote(%LocaleGet(ObservationClasswithinStandard_Text));
   %let trColumnName = %nrbquote(%LocaleGet(ColumnName_Text));
   %let trSubjectLevel = %nrbquote(%LocaleGet(SubjectLevel_Text));
   
   %let trTrialDiseaseAssess = %nrbquote(%LocaleGet(TrialDiseaseAssessment_Text));
   %let trSkinResponse = %nrbquote(%LocaleGet(SkinResponse_Text));
   %let trTumorResults = %nrbquote(%LocaleGet(TumorResults_Text));
   %let trSubjectStatus = %nrbquote(%LocaleGet(SubjectStatus_Text));
   %let trDiseaseResponse = %nrbquote(%LocaleGet(DiseaseResponse_Text));
   %let trDeathDetails = %nrbquote(%LocaleGet(DeathDetails_Text));
   %let trTumorIdentification = %nrbquote(%LocaleGet(TumorIdentification_Text));
   %let trReproductiveSysFind = %nrbquote(%LocaleGet(ReproductiveSystemFindings_Text));
   %let trMorphology = %nrbquote(%LocaleGet(Morphology_Text));
   %let trImmunoSpecimenAssess = %nrbquote(%LocaleGet(ImmunogenicitySpecimenAssessments_Text));
   %let trProcedures = %nrbquote(%LocaleGet(Procedures_Text));
   %let trExposureasCollected = %nrbquote(%LocaleGet(ExposureasCollected_Text));
   %let trHealthcareEncounters = %nrbquote(%LocaleGet(HealthcareEncounters_Text));
   
   %put [AddStudyLocal_~TOOLKITME InPath~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.07];   
   
   %if %length(&InPath) %then %do;  
      %if %sysfunc(fileexist(&InPath.adsl.sas7bdat)) %then %do;
         %put [MS_S_0201];
         %put ERROR: ADSL detected in the SDTM folder. Please move to an ADaM folder distinct from the SDTM folder.;
         %let CSTERROR = 1;
         %goto tkexit;
      %end;
      %let faMainflag =0;

      data sdtm;
         set sdtm(drop = nobs);
         if not (length(trim(memname)) <= 4 or (substr(memname,1,4) = "SUPP" and length(trim(memname)) <= 8) or memname in ("RELREC", "POOLDEF")) then delete;
            *** Labels ***;
         if memname = "DM" and memlabel = "" then memlabel = "&trDemographics";
         else if memname = "SE" and memlabel = "" then memlabel = "&trSubjectElements";
         else if memname = "CO" and memlabel = "" then memlabel = "&trComments";
         else if memname = "EX" and memlabel = "" then memlabel = "&trExposure";
         else if memname = "DS" and memlabel = "" then memlabel = "&trDisposition";
         else if memname = "LB" and memlabel = "" then memlabel = "&trLaboratoryTestResults";
         else if memname = "VS" and memlabel = "" then memlabel = "&trVitalSigns";
         else if memname = "EG" and memlabel = "" then memlabel = "&trECGTestResults";
         else if memname = "PC" and memlabel = "" then memlabel = "&trPKConcentrations";
         else if memname = "PP" and memlabel = "" then memlabel = "&trPKParameters";
         else if memname = "SC" and memlabel = "" then memlabel = "&trSubjectCharacteristics";
         else if memname = "TA" and memlabel = "" then memlabel = "&trTrialArms";
         else if memname = "TE" and memlabel = "" then memlabel = "&trTrialElements";
         else if memname = "TS" and memlabel = "" then memlabel = "&trTrialSummary";                                            
         else if memname = "RELREC" and memlabel = "" then memlabel = "&trRelatedRecords";
         else if substr(memname,1,4) = "SUPP" and length(trim(memname)) <= 8 and memlabel = "" then memlabel = catx(" ", "&trSupplementalQualifiers", substr(memname,5,2));
         %if &SEND = 1 %then %do;
            else if memname = "BW" and memlabel = "" then memlabel = "&trBodyWeights";
            else if memname = "BG" and memlabel = "" then memlabel = "&trBodyWeightGains";
            else if memname = "CL" and memlabel = "" then memlabel = "&trClinicalObservations";
            else if memname = "DD" and memlabel = "" then memlabel = "&trDeathDiagnosis";
            else if memname = "FW" and memlabel = "" then memlabel = "&trFoodandWaterConsumption";
            else if memname = "MA" and memlabel = "" then memlabel = "&trMacroscopicFindings";
            else if memname = "MI" and memlabel = "" then memlabel = "&trMicroscopicFindings";
            else if memname = "OM" and memlabel = "" then memlabel = "&trOrganMeasurements";
            else if memname = "PM" and memlabel = "" then memlabel = "&trPalpableMasses";
            else if memname = "TF" and memlabel = "" then memlabel = "&trTumorFindings";
            else if memname = "TX" and memlabel = "" then memlabel = "&trTrialSets";
            else if memname = "POOLDEF" and memlabel = "" then memlabel = "&trPooling";
         %end;
         %if &SEND = 0 %then %do;
            else if substr(memname,1,2) = "SV" and memlabel = "" then memlabel = "&trSubjectVisits";
            else if substr(memname,1,2) = "CM" and memlabel = "" then memlabel = "&trConcomitantMedications";
            else if substr(memname,1,2) = "SU" and memlabel = "" then memlabel = "&trSubstanceUse";
            else if substr(memname,1,2) = "AE" and memlabel = "" then memlabel = "&trAdverseEvents";
            else if substr(memname,1,2) = "MH" and memlabel = "" then memlabel = "&trMedicalHistory";
            else if substr(memname,1,2) = "CE" and memlabel = "" then memlabel = "&trClinicalEvents";
            else if substr(memname,1,2) = "DV" and memlabel = "" then memlabel = "&trProtocolDeviations";            
            else if substr(memname,1,2) = "QS" and memlabel = "" then memlabel = "&trQuestionnaires";
            else if substr(memname,1,2) = "MB" and memlabel = "" then memlabel = "&trMicrobiologySpecimen";
            else if substr(memname,1,2) = "IE" and memlabel = "" then memlabel = "&trInclusionExclusionCritNotMet";
            else if substr(memname,1,2) = "PE" and memlabel = "" then memlabel = "&trPhysicalExamination";
            else if substr(memname,1,2) = "DA" and memlabel = "" then memlabel = "&trDrugAccountability";   
            else if substr(memname,1,2) = "MS" and memlabel = "" then memlabel = "&trMicrobiologySuscTest";
            else if substr(memname,1,2) = "FA" and memlabel = "" then memlabel = "&trFindingsAbout";
            else if substr(memname,1,2) = "TV" and memlabel = "" then memlabel = "&trTrialVisits";
            else if substr(memname,1,2) = "TI" and memlabel = "" then memlabel = "&trTrialInclusionExclusionCrit";
            else if substr(memname,1,2) = "EC" and memlabel = "" then memlabel = "&trExposureasCollected";
            else if substr(memname,1,2) = "PR" and memlabel = "" then memlabel = "&trProcedures";
            else if substr(memname,1,2) = "HO" and memlabel = "" then memlabel = "&trHealthcareEncounters";
            else if substr(memname,1,2) = "IS" and memlabel = "" then memlabel = "&trImmunoSpecimenAssess";
            else if substr(memname,1,2) = "MO" and memlabel = "" then memlabel = "&trMorphology";
            else if substr(memname,1,2) = "RP" and memlabel = "" then memlabel = "&trReproductiveSysFind";
            else if substr(memname,1,2) = "TU" and memlabel = "" then memlabel = "&trTumorIdentification";
            else if substr(memname,1,2) = "DD" and memlabel = "" then memlabel = "&trDeathDetails";
            else if substr(memname,1,2) = "RS" and memlabel = "" then memlabel = "&trDiseaseResponse";
            else if substr(memname,1,2) = "SS" and memlabel = "" then memlabel = "&trSubjectStatus";
            else if substr(memname,1,2) = "TR" and memlabel = "" then memlabel = "&trTumorResults";
            else if substr(memname,1,2) = "SR" and memlabel = "" then memlabel = "&trSkinResponse";     
            else if substr(memname,1,2) = "TD" and memlabel = "" then memlabel = "&trTrialDiseaseAssess";  
            else if length(trim(memname)) <= 4 and length(trim(memname)) >2 then memlabel = "&trSplit";
         %end;
         if memlabel = "" or memlabel = '" ' or memlabel = "'" or lengthn(strip(memlabel))=0 then memlabel = memname;
      run;      
      
      *** Define user-defined classes ***;
      data sdtm_type_other(keep = memname class2);
         length Class2 $ 15;
            set sdtm(where = (substr(upcase(name),3) in ("TERM","TRT","TESTCD")));
            if substr(upcase(name),3) = "TERM" then Class2 = "&trEvents";
            else if substr(upcase(name),3) = "TRT" then Class2 = "&trInterventions";
            else if substr(upcase(name),3) = "TESTCD" then Class2 = "&trFindings";
         *** delete if term does not begin with domain prefix ***;
         if substr(upcase(name),1,2) ne substr(memname,1,2) then delete;
      run;

      *** Define Model Classes ***;
      data sdtm_type(keep = memname memlabel class);
         length Class $ 50;
         set sdtm;
         by memname;
         if first.memname;
         %if &SEND = 0 %then %do;
         	if length(trim(memname)) = 2 or memname = "RELREC" or (substr(memname,1,4) = "SUPP" and length(trim(memname)) <= 8) then do; 
            	if memname in ("DM","SE","CO","SV") then class = "&trSpecial";
            	else if memname in ("CM","SU","EX") then class = "&trInterventions";
            	else if memname in ("AE","MH","CE","DS","DV") then class = "&trEvents";
            	else if memname in ("EG","LB","QS","VS","MB","PC","IE","PE","SC","DA","MS","PP") then class = "&trFindings";
            	else if memname in ("FA") then do;
            		class = "&trFindingsAbout";
						call symput ("faMainflag",trim(left(1)));
            	end;
            	else if memname in ("TA","TV","TS","TE","TT") then class = "&trTrialDesign";
            	else if memname = "RELREC" or (substr(memname,1,4) = "SUPP" and length(trim(memname)) <= 8) then class = "&trRelationship";
            end;
            else do;
            	if substr(memname,1,4) ^= "SUPP" then class = "&trSplit";
            end;
         %end;
         %else %if &SEND = 1 %then %do;
            if memname in ("DM","SE","CO") then class = "&trSpecial";
            else if memname in ("EX") then class = "&trInterventions";
            else if memname in ("DS") then class = "&trEvents";
            else if memname in ("BW","BG","CL","DD","FW","LB","MA","MI","OM","PM","PC","PP","SC","TF","VS","EG") then class = "&trFindings";
            else if memname in ("TE","TA","TX","TS") then class = "&trTrialDesign";
            else if memname = "RELREC" or (substr(memname,1,4) = "SUPP" and length(trim(memname)) = 6) then class = "&trRelationship";
         %end;
      run;

      *** Fill in user-defined classes ***;
      *** Delete where class missing ***;
      data sdtm_type;
         merge sdtm_type sdtm_type_other;
         by memname;
         if class = "" and class2 ne "" then class = class2;
         if class = "" then delete;
      run;

      data sdtm_type;
         set sdtm_type;
         by memname;
         retain count;
         if first.memname then count = 1;
         else count = count + 1;
         if last.memname;
      run;

      *** Delete user-defined domains where class cannot be determined ***;
      data sdtm_type;
         set sdtm_type;
         if count > 1 then delete;
      run;

      %if &faMainflag %then %do;
      	data sdtm_type;
      		set sdtm_type;
      		%if &faMainflag %then %do;
      			if substr(upcase(memname),1,2) ="FA" & length(trim(memname)) > 2 then delete;
      		%end;
      	run;
      %end;
   
      *** Keep variables for domains with defined classes ***;
      data sdtm;
         merge sdtm_type(keep = memname in = ina) sdtm;
         by memname;
         if ina;
      run;
		* handle splitting domains;
      %if &SpltDomainFlag %then %do;
			data sdtmsp;
	         set sdtmsp(drop = nobs);
         	if not (length(trim(memname)) = 4  or (substr(memname,1,4) = "SUPP" and length(trim(memname)) = 8) or memname in ("RELREC", "POOLDEF")) then delete;
            *** Labels ***;
            if memlabel = "" then memlabel = memname;
       *     if substr(memname,1,4) = "SUPP" then memname =substr(memname,1,6);
          run;
			data sdtmsp_type_other(keep = memname class2);
				length Class2 $ 15;
            set sdtmsp(where = (substr(upcase(name),3) in ("TERM","TRT","TESTCD")));
            if substr(upcase(name),3) = "TERM" then Class2 = "&trEvents";
            else if substr(upcase(name),3) = "TRT" then Class2 = "&trInterventions";
            else if substr(upcase(name),3) = "TESTCD" then Class2 = "&trFindings";
				*** delete if term does not begin with domain prefix ***;
				if substr(upcase(name),1,4) ne memname then delete;
			run;
			data sdtmsp_type(keep = memname memlabel class);
				length Class $ 50;
				set sdtmsp;
				by memname;
				if first.memname;	
				/*if substr(memname,1,2) in ("EG","LB","QS","VS","MB","PC","IE","PE","SC","DA","MS","PP") then class = "Findings Splitting";
				else*/ if substr(memname,1,2) in ("FA") then class = "&trSplit";
				else if memname = "RELREC" or (substr(memname,1,4) = "SUPPFA" and length(trim(memname)) = 8) then class = "&trRelationship";
				else class =memname;
			run;
			/*
			data outlib.sdtmsp_type;
			set sdtmsp_type;
			run;
			data outlib.sdtm_type;
				set sdtm_type;
			run;
			data outlib.sdtm;
				set sdtm;
			run;
			data outlib.sdtmsp;
			set sdtmsp;
			run; */
      	*** Delete where class missing ***;
      	data sdtmsp_type;
      	   merge sdtmsp_type sdtmsp_type_other;
      	   by memname;
      	   if class = "" and class2 ne "" then class = class2;
      	   if class = "" then delete;
      	run;
	      data sdtmsp_type;
	         set sdtmsp_type;
	         by memname;
	         retain count;
	         if first.memname then count = 1;
	         else count = count + 1;
	         if last.memname;
      	run;
	      *** Delete user-defined domains where class cannot be determined ***;
	      data sdtmsp_type;
	         set sdtmsp_type;
	         if count > 1 then delete;
	         splitflg =1;
	      run;
	      
	      *** Keep variables for domains with defined classes ***;
	      data sdtmsp;
	         merge sdtmsp_type(keep = memname in = ina) sdtmsp;
	         by memname;
	         if ina;
	         splitflg=1;
      	run;
      	
      	data sdtm;
      		set sdtm sdtmsp;
      	run;      	
      	data sdtm_type;
      		set sdtm_type sdtmsp_type;
      	run;
      	* merge with sdtmnousedDomSP;
      	data sdtmnousedDom;
      		set sdtmnousedDomSP sdtmnousedDom;
      	run;
		%end;
      data %DataWorkIt(sdtmmeta.source_tables)(keep = memname memlabel class flag rename = (memname = Table memlabel = Label));
         retain memname memlabel class flag;
         length flag $4.;
         set sdtm_type(where = (upcase(memname) not in ("POOLDEF","RELREC")));
         label memname = "&trTableName" memlabel = "&trLabel" class = "&trObservationClasswithinStand";
         %if &SEND %then %do;
            flag ="SEND";
         %end;
         %else %do;
            flag ="SDTM";
         %end;
         label flag="SDTM/SEND/ADAM Flag";
      run;

      data source_columns(keep = memname name label flag rename = (memname = Table name = Column));
         retain memname name label flag;
         length flag $4.;
         set sdtm(where = (upcase(memname) not in ("POOLDEF","RELREC")));
         name = upcase(name);
         label memname = "&trTableName" label = "&trLabel" name = "&trColumnName";
         %if &SEND %then %do;
            flag ="SEND";
         %end;
         %else %do;
            flag ="SDTM";
         %end;
         label flag="SDTM/SEND/ADAM Flag";
      run;

      proc sort data = source_columns out = %DataWorkIt(sdtmmeta.source_columns);
         by table column;
      run;
      
      proc datasets nolist;
         delete sdtm sdtm_type sdtm_type_other;
      quit;
      
      *** Findings Check. Drop those without xxTESTCD ***;  
      proc sort data = %DataWorkIt(sdtmmeta.source_tables)(where = (class = "&trFindings")) out = sdtm1;
         by table;
      run;

      proc sort data = %DataWorkIt(sdtmmeta.source_columns)(where = (index(column,"TESTCD") or index(column,"TEST"))) out = sdtm2;
         by table column;
      run;
      
      data findchk1(keep = table);
         set sdtm1;
         by table;
         if first.table;
      run;
      
      data findchk2(keep = table);
         set sdtm2;
         by table;
         if first.table;
      run;
      
      data findchk1;
         merge findchk1(in = ina) findchk2(in = inb);
         by table;
         if ina and not inb;
      run;
      %Nobsvars(findchk1);   
      %if &nobs %then %do;
         data %DataWorkIt(sdtmmeta.source_tables);
            merge findchk1(in = ina) %DataWorkIt(sdtmmeta.source_tables)(in = inb);
            by table;
            if inb and not ina;
         run;

         data %DataWorkIt(sdtmmeta.source_columns);
            merge findchk1(in = ina) %DataWorkIt(sdtmmeta.source_columns)(in = inb);
            by table;
            if inb and not ina;
         run;
      %end;
      proc datasets nolist;
         delete sdtm1 sdtm2 findchk1 findchk2;
      quit;                
   %end;

   %put [AddStudyLocal_~TOOLKITME AInPath Labels~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.08];

   %if %length(&AInPath) %then %do;
      data adam;
         set adam(drop = nobs);
         if not ((substr(memname,1,2) = "AD" and 4 <= length(trim(memname)) <= 8) or (substr(memname,1,4) = "SUPP" and length(trim(memname)) = 6) 
               or memname in ("RELREC", "POOLDEF")) then delete;
            *** Labels ***;
         if memname = "ADDM" and memlabel = "" then memlabel = "&trDemographics";
         else if memname = "ADSL" and memlabel = "" then memlabel = "&trSubjectLevel";
         else if memname = "ADSE" and memlabel = "" then memlabel = "&trSubjectElements";
         else if memname = "ADCO" and memlabel = "" then memlabel = "&trComments";
         else if memname = "ADEX" and memlabel = "" then memlabel = "&trExposure";
         else if memname = "ADDS" and memlabel = "" then memlabel = "&trDisposition";
         else if memname = "ADLB" and memlabel = "" then memlabel = "&trLaboratoryTestResults";
         else if memname = "ADVS" and memlabel = "" then memlabel = "&trVitalSigns";
         else if memname = "ADEG" and memlabel = "" then memlabel = "&trECGTestResults";
         else if memname = "ADPC" and memlabel = "" then memlabel = "&trPKConcentrations";
         else if memname = "ADPP" and memlabel = "" then memlabel = "&trPKParameters";
         else if memname = "ADSC" and memlabel = "" then memlabel = "&trSubjectCharacteristics";
         else if memname = "TA" and memlabel = "" then memlabel = "&trTrialArms";
         else if memname = "TE" and memlabel = "" then memlabel = "&trTrialElements";
         else if memname = "TS" and memlabel = "" then memlabel = "&trTrialSummary";
         else if memname = "RELREC" and memlabel = "" then memlabel = "&trRelatedRecords";
         else if substr(memname,1,4) = "SUPP" and length(trim(memname)) = 6 and memlabel = "" then memlabel = catx(" ", "&trSupplementalQualifiers", substr(memname,5,2));
         %if &SEND = 1 %then %do;
            else if memname = "ADBW" and memlabel = "" then memlabel = "&trBodyWeights";
            else if memname = "ADBG" and memlabel = "" then memlabel = "&trBodyWeightGains";
            else if memname = "ADCL" and memlabel = "" then memlabel = "&trClinicalObservations";
            else if memname = "ADDD" and memlabel = "" then memlabel = "&trDeathDiagnosis";
            else if memname = "ADFW" and memlabel = "" then memlabel = "&trFoodandWaterConsumption";
            else if memname = "ADMA" and memlabel = "" then memlabel = "&trMacroscopicFindings";
            else if memname = "ADMI" and memlabel = "" then memlabel = "&trMicroscopicFindings";
            else if memname = "ADOM" and memlabel = "" then memlabel = "&trOrganMeasurements";
            else if memname = "ADPM" and memlabel = "" then memlabel = "&trPalpableMasses";
            else if memname = "ADTF" and memlabel = "" then memlabel = "&trTumorFindings";
            else if memname = "TX" and memlabel = "" then memlabel = "&trTrialSets";
            else if memname = "POOLDEF" and memlabel = "" then memlabel = "&trPooling";
         %end;
         %if &SEND = 0 %then %do;
            else if memname = "ADSV" and memlabel = "" then memlabel = "&trSubjectVisits";
            else if memname = "ADCM" and memlabel = "" then memlabel = "&trConcomitantMedications";
            else if memname = "ADSU" and memlabel = "" then memlabel = "&trSubstanceUse";
            else if memname = "ADAE" and memlabel = "" then memlabel = "&trAdverseEvents";
            else if memname = "ADMH" and memlabel = "" then memlabel = "&trMedicalHistory";
            else if memname = "ADCE" and memlabel = "" then memlabel = "&trClinicalEvents";
            else if memname = "ADDV" and memlabel = "" then memlabel = "&trProtocolDeviations";          
            else if memname = "ADQS" and memlabel = "" then memlabel = "&trQuestionnaires";
            else if memname = "ADMB" and memlabel = "" then memlabel = "&trMicrobiologySpecimen";
            else if memname = "ADIE" and memlabel = "" then memlabel = "&trInclusionExclusionCritNotMet";
            else if memname = "ADPE" and memlabel = "" then memlabel = "&trPhysicalExamination";
            else if memname = "ADDA" and memlabel = "" then memlabel = "&trDrugAccountability"; 
            else if memname = "ADMS" and memlabel = "" then memlabel = "&trMicrobiologySuscTest";
            else if memname = "FA" and memlabel = "" then memlabel = "&trFindingsAbout";
            else if memname = "TV" and memlabel = "" then memlabel = "&trTrialVisits";
            else if memname = "TI" and memlabel = "" then memlabel = "&trTrialInclusionExclusionCrit";
            else if memname = "ADEC" and memlabel = "" then memlabel = "&trExposureasCollected";
            else if memname = "ADPR" and memlabel = "" then memlabel = "&trProcedures";
            else if memname = "ADHO" and memlabel = "" then memlabel = "&trHealthcareEncounters";
            else if memname = "ADIS" and memlabel = "" then memlabel = "&trImmunoSpecimenAssess";
            else if memname = "ADMO" and memlabel = "" then memlabel = "&trMorphology";
            else if memname = "ADRP" and memlabel = "" then memlabel = "&trReproductiveSysFind";
            else if memname = "ADTU" and memlabel = "" then memlabel = "&trTumorIdentification";
            else if memname = "ADDD" and memlabel = "" then memlabel = "&trDeathDetails";
            else if memname = "ADRS" and memlabel = "" then memlabel = "&trDiseaseResponse";
            else if memname = "ADSS" and memlabel = "" then memlabel = "&trSubjectStatus";
            else if memname = "ADTR" and memlabel = "" then memlabel = "&trTumorResults";
            else if memname = "ADSR" and memlabel = "" then memlabel = "&trSkinResponse";     
            else if memname = "TD" and memlabel = "" then memlabel = "&trTrialDiseaseAssess";                 
         %end;
         if memlabel = "" or memlabel = '" ' then memlabel = memname;
      run;

      *** Define user-defined classes ***;
      data adam_type_other(keep = memname class2);
         length Class2 $ 15;
         set adam(where = (substr(upcase(name),3) in ("TERM","TRT","TESTCD") or name = "PARAMCD"));
         if memname = "ADSL" then delete;
         if substr(upcase(name),3) = "TERM" then Class2 = "&trEvents";
         else if substr(upcase(name),3) = "TRT" then Class2 = "&trInterventions";
         else if substr(upcase(name),3) = "TESTCD" then Class2 = "&trFindings";
         else if name = "PARAMCD" then class2 = "BDS";
         if substr(upcase(name),3) in ("TERM","TRT","TESTCD") then do;
         if substr(upcase(name),1,2) ne substr(upcase(memname),3,2) then delete;
         end;
      run;

      *** Define Model Classes ***;
      data adam_type(keep = memname memlabel class);
         length Class $ 15;
         set adam;
         by memname;
         if first.memname;
         %if &SEND = 0 %then %do;
            if memname in ("ADSL","ADDM","ADSE","ADCO","ADSV") then class = "&trSpecial";
            else if memname in ("ADCM","ADSU","ADEX") then class = "&trInterventions";
            else if memname in ("ADAE","ADMH","ADCE","ADDS","ADDV","ADHO") then class = "&trEvents";
            else if memname in ("ADEG","ADLB","ADQS","ADVS","ADMB","ADPC","ADIE","ADPE","ADSC","ADDA","ADMS","ADPP","ADXA") then class = "&trFindings";
            else if memname = "RELREC" or (substr(memname,1,4) = "SUPP" and length(trim(memname)) = 6) then class = "&trRelationship";
            else if memname in ("ADAEC") then class = "&trOther";
         %end;
         %else %if &SEND = 1 %then %do;
            if memname in ("ADSL","ADDM","ADSE","ADCO") then class = "&trSpecial";
            else if memname in ("ADEX") then class = "&trInterventions";
            else if memname in ("ADDS") then class = "&trEvents";
            else if memname in ("ADBW","ADBG","ADCL","ADDD","ADFW","ADLB","ADMA","ADMI","ADOM","ADPM","ADPC","ADPP","ADSC","ADTF","ADVS","ADEG") then class = "&trFindings";
            else if memname = "RELREC" or (substr(memname,1,4) = "SUPP" and length(trim(memname)) = 6) then class = "&trRelationship";
         %end;
      run;
      *** Fill in user-defined classes ***;
      *** Delete where class missing ***;
      data adam_type;
         merge adam_type adam_type_other;
         by memname;
         if class = "" and class2 ne "" then class = class2;
         if class = "" then delete;
         /*if class2 = "BDS" & class = "&trInterventions"  then do;
         		delete;
         		call symput("EXError", trim(left(1)));
         end;*/
      run;
  
      data adam_type;
         set adam_type;
         by memname;
         retain count;
         if first.memname then count = 1;
         else count = count + 1;
         if last.memname;
      run;

      *** Delete user-defined domains where class cannot be determined ***;
      data adam_type;
         set adam_type;
         if count > 1 & class ="BDS" then delete;
      run;
      data adam_type adam_occurrence;
      	set adam_type;
      	if class2 = "BDS" & (class = "&trInterventions" or class = "&trEvents")  then output adam_occurrence;
      	else output adam_type;
      run;
		%Nobsvars(adam_occurrence);      
      %if &nobs %then %do;   
      	%global adamExcluded adamExcludedFlg;
      	proc sql noprint; 
      	   select distinct MEMNAME 
      	   into :adamExcluded separated by ' '
      	   from adam_occurrence;
			quit;
			%let adamExcludedFlg=1;
      %end;

      data bds(keep = memname);
         set adam_type(where = (class2 = "BDS"));
      run;
      
      *** determining requirements for BDS ***;
      data bds;
         merge bds(in = ina) adam(keep = memname name where = (upcase(name) in ("PARAMCD","AVISITN","AVAL","AVALC","ADTM","ADT","AVISIT","ADY")));
         by memname;
         if ina;
         avail = 1;
      run;
      
      proc transpose data = bds out = bds;
         by memname;
         var avail;
         id name;
      run;
      
      data bds(keep = memname keepit);
         set bds;
         if paramcd and (aval or avalc) then keepit = 1;    
         else keepit = 0;
      run;

      data adam_type(drop = keepit);
         merge adam_type(in = ina) bds(in = inb);
         by memname;
         BDSFlag = 0;
         if inb then do;
             if keepit = 0 then delete;
             * S1537938;
             else if keepit = 1 and Class ^= "&trSpecial" then do;
             *else if keepit = 1 then do;
                Class = "&trFindings";
                BDSFlag = 1;
             end;
         end;
      run;
      
      *** Keep variables for domains with defined classes ***;
      data adam;
         merge adam_type(keep = memname bdsflag in = ina) adam;
         by memname;
         if ina;
      run;

      data %DataWorkIt(adammeta.source_tables)(keep = memname memlabel class flag rename = (memname = Table memlabel = Label));
         retain memname memlabel class flag;
         length flag $4.;
         set adam_type(where = (upcase(memname) not in ("POOLDEF","RELREC")));
         label memname = "&trTableName" memlabel = "&trLabel" class = "&trObservationClasswithinStand";
         %if &SEND %then %do;
            flag ="SEND";
         %end;
         %else %do;
            flag ="ADAM";
         %end;
         label flag="SDTM/SEND/ADAM Flag";         
      run;

      *** drop TEST and TESTCD if avail in BDS ***;
      data source_columns(keep = memname name label flag rename = (memname = Table name = Column));
         retain memname name label flag;
         length flag $4.;
         set adam(where = (upcase(memname) not in ("POOLDEF","RELREC")));
         name = upcase(name);
         if BDSFlag = 1 then do;
            if substr(name,3) in ("TESTCD", "TEST") then delete;
         end;         
         label memname = "&trTableName" label = "&trLabel" name = "&trColumnName";
         %if &SEND %then %do;
            flag ="SEND";
         %end;
         %else %do;
            flag ="SDTM";
         %end;
         label flag="SDTM/SEND/ADAM Flag";         
      run;
      
      proc sort data = source_columns out = %DataWorkIt(adammeta.source_columns);
         by table column;
      run;

      proc datasets nolist;
         delete adam adam_type adam_type_other;
      quit;
      
      *** Findings Check. Drop those without xxTESTCD or PARAMCD ***;   
      proc sort data = %DataWorkIt(adammeta.source_tables)(where = (class = "&trFindings")) out = adam1;
         by table;
      run;
      
      proc sort data = %DataWorkIt(adammeta.source_columns)(where = (index(column,"TESTCD") or column = "PARAMCD")) out = adam2;
         by table column;
      run;     
      
      data findchk1(keep = table);
         set adam1;
         by table;
         if first.table;
      run;
      
      data findchk2(keep = table);
         set adam2;
         by table;
         if first.table;
      run;
      
      data findchk1;
         merge findchk1(in = ina) findchk2(in = inb);
         by table;
         if ina and not inb;
      run;
      %Nobsvars(findchk1);      
      %if &nobs %then %do;
         data %DataWorkIt(adammeta.source_tables);
            merge findchk1(in = ina) %DataWorkIt(adammeta.source_tables)(in = inb);
            by table;
            if inb and not ina;
         run;

         data %DataWorkIt(adammeta.source_columns);
            merge findchk1(in = ina) %DataWorkIt(adammeta.source_columns)(in = inb);
            by table;
            if inb and not ina;
         run;
      %end;      
      proc datasets nolist;
         delete adam1 adam2 findchk1 findchk2;
      quit;
   %end;
   
   %put [AddStudyLocal_~TOOLKITME Complete~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.09];
   
   %tkexit:;
   %put Exiting TOOLKITME;
   %ClockStop(TOOLKITME);
%mend TOOLKITME;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro MAKEDIR(dir = , varname =, parent = ) ;
   %put Entering MAKEDIR;
   %ClockStart(MAKEDIR);  
   %local rc fileref;
   %let rc = %sysfunc(filename(fileref,&parent.&dir)); 
   %if %sysfunc(fexist(&fileref)) %then %do;
      %put NOTE: The directory "&parent.&dir" exists;
   %end;
   %else %do; 
      %let rc = %sysfunc(dcreate(&dir, &parent));
      %if %length(&rc) %then %put NOTE: The directory &varname (&parent.&dir) has been created; 
      %else %do;
         %put [MS_S_0202];
         %put ERROR: Unable to create directory &parent.&dir;
         %let CSTERROR = 1;
      %end;
   %end; 
   %if &Server ne Local %then %do;
      %global &&varname;
      %let &&varname = &parent.&dir;
      libname &&varname "&parent.&dir";
   %end;
   %else %if &Server = Local %then %do;
      %global &varname;
      %let &varname = &parent.&dir;
      libname &varname "&parent.&dir";
   %end;   
   %let rc=%sysfunc(filename(fileref)); 
   %put Exiting MAKEDIR;
   %ClockStop(MAKEDIR);     
%mend MAKEDIR;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

*** Code based on suggestions contained in Implementing CDISC Using SAS(R): An End-to-End Guide, Second Edition ***; 

%macro TRANSSUPP;
   %put Entering TRANSSUPP;
   %ClockStart(TRANSSUPP);  
   %let i = 1; 
   %do %while(%length(%scan(&suppdomains,&i,' ')));
      %let temp = %scan(&suppdomains,&i,' ');
      %let shtemp = %substr(&temp,5);
      %let idvar = ;
      %global &shtemp.suppidvar;

      %if &SpltDomainFlag %then %do;
			%if %length(&temp)<=8 & %length(&temp)>6 %then %do;
				%let _tid_ = %sysfunc(open(SDTMSP.&temp));
			%end;
			%else %do;
				%let _tid_ = %sysfunc(open(SDTM.&temp));
			%end;
      %end;
      %else %let _tid_ = %sysfunc(open(SDTM.&temp));
		%let idvarnum = %sysfunc(varnum(&_tid_,idvar));
      %let _tid_ = %sysfunc(close(&_tid_));
      
      %if &idvarnum %then %do;
         *** if only missing, idvar will be blank ***;
         *** if missing one of levels, ~ will be in position 1 ***;
			%if &SpltDomainFlag %then %do;
         	%if %length(&temp)<=8 & %length(&temp) > 6 %then %do;
         		%GetLevels(SDTMSP.&temp,idvar,idvar,_nLvls=nidvar,_vType=vtype,_delim = %str(~));
         	%end;
         	%else %do;
         		%GetLevels(SDTM.&temp,idvar,idvar,_nLvls=nidvar,_vType=vtype,_delim = %str(~));
         	%end;
         %end;
         %else %do;
         	%GetLevels(SDTM.&temp,idvar,idvar,_nLvls=nidvar,_vType=vtype,_delim = %str(~));
         %end;

         %if ^%length(&idvar) %then %let idvar = MISSING;
         %else %if %nrbquote(%substr(&idvar,1,1)) = %nrbquote(~) %then %let idvar = MISSING&idvar;         
         %let idvar = %sysfunc(transtrn(&idvar,~,%str( )));
      %end;
      %else %do;
         %let idvar = NOIDVAR;
      %end;
               
      %let &shtemp.suppidvar = &idvar;

      data &temp;
      	%if &SpltDomainFlag %then %do;
      		%if %length(&temp)=7 or %length(&temp)=8 %then %do;
      			set SDTMSP.&temp;
      		%end;
      		%else %do;
      			set SDTM.&temp;
      		%end;
      	%end;
      	%else %do;
         	set SDTM.&temp;
         %end;
         %if &shtemp ne DM %then %do;
         	if substr(qnam, 1, 2) ne "%substr(&shtemp,1,2)" then qnam = cats("%substr(&shtemp,1,2)",qnam);
         %end;
         /*%if &shtemp ne DM %then %do;
         	%if %length(&temp)=7 or %length(&temp)=8 %then %do;
         		if substr(qnam, 1, 4) ne "&shtemp" then qnam = cats("&shtemp",qnam);
         	%end;
         	%else %do;
            	if substr(qnam, 1, 2) ne "%substr(&shtemp,1,2)" then qnam = cats("%substr(&shtemp,1,2)",qnam);
            %end;
         %end;*/
      run;
      
      %let j = 1;
      %do %while(%length(%scan(&&&shtemp.SUPPIDVAR,&j,' ')));
         %let idvartemp = %scan(&&&shtemp.SUPPIDVAR,&j,' ');
         %let varlist = ;

         %if &idvartemp = MISSING %then %do;
            proc sort data = &temp(keep = qnam qlabel idvar where = (missing(idvar))) nodupkey out = varlevels(drop = idvar);
               by qnam qlabel;
            run;
         %end;
         %else %if &idvartemp ne NOIDVAR %then %do;
            proc sort data = &temp(keep = qnam qlabel idvar where = (idvar = "&idvartemp" )) nodupkey out = varlevels(drop = idvar);
               by qnam qlabel;
            run;
         %end;         
         %else %if &idvartemp = NOIDVAR %then %do;
            proc sort data = &temp(keep = qnam qlabel) nodupkey out = varlevels;
               by qnam qlabel;
            run;                  
         %end;

         data varlevels;
            set varlevels;
            by qnam;
            if first.qnam;
         run;

         proc sql noprint;
            %let varlist = ;
            select qnam
               into :varlist separated by ' '
               from varlevels
               order by qnam;
               %let nvars = &sqlobs;
            %let sdtmdomainclass = ;
            select qlabel
               into :varlabs separated by '~'
               from varlevels
               order by qnam;
         quit;

         proc datasets nolist;
            delete varlevels;
         quit;

         %if &idvartemp = MISSING %then %do;
            proc sort data = &temp(where = (missing(idvar))) out = temp;
               by usubjid idvar idvarval;
            run;
         %end;
         %else %if &idvartemp ne NOIDVAR %then %do;
            proc sort data = &temp(where = (idvar = "&idvartemp" )) out = temp;
               by usubjid idvar idvarval;
            run;
         %end;
         %else %if &idvartemp = NOIDVAR %then %do;
            proc sort data = &temp out = temp;
               by usubjid;
            run;         
         %end;

         %if (&idvartemp ne MISSING) and (&idvartemp ne NOIDVAR) %then %do;
         	%if &SpltDomainFlag %then %do;
         		%if %length(&temp)=7 or %length(&temp)=8 %then %do;
         			%let _tid_ = %sysfunc(open(SDTMSP.&shtemp));
         		%end;
         		%else %do;
         			%let _tid_ = %sysfunc(open(SDTM.&shtemp));
         		%end;
         	%end;
         	%else %do;
         		%let _tid_ = %sysfunc(open(SDTM.&shtemp));
         	%end;
            %let _vn_ = %sysfunc(varnum(&_tid_,&idvartemp));
            %let idtype = %sysfunc(vartype(&_tid_,&_vn_));
            %let idlab = %sysfunc(varlabel(&_tid_,&_vn_));
            %let idlen = %sysfunc(varlength(&_tid_,&_vn_));
            %let _tid_ = %sysfunc(close(&_tid_));
         %end;
         %else %do;
            %let idtype = ;
            %let varlab = ;
         %end;

			%if &SpltDomainFlag %then %do;
				%if %length(&temp)=8 %then %do;
					%let _tid_ = %sysfunc(open(SDTMSP.&temp));
				%end;
				%else %do;
					%let _tid_ = %sysfunc(open(SDTM.&temp));
				%end;
			%end;
			%else %do;
         	%let _tid_ = %sysfunc(open(SDTM.&temp));
         %end;
            %let qevalchk = %sysfunc(varnum(&_tid_,QEVAL));
            %let sidchk = %sysfunc(varnum(&_tid_,STUDYID));
         %let _tid_ = %sysfunc(close(&_tid_));         

         data temp;            
            %if &idtype = C %then %do;
               length &idvartemp $ &idlen;
            %end;            
            set temp;
            by usubjid %if &idvarnum %then %do; idvar idvarval %end;;
            drop qnam qlabel qval qorig %if &idvarnum %then %do; idvarval idvar %end; i rdomain %if &qevalchk %then qeval; ;
            length &varlist $200.;
            retain &varlist;
            array vars{*} &varlist;
            %if &idvarnum %then %do;
               if first.idvarval then do i = 1 to dim(vars); 
                  vars{i} = '';
               end;
            %end;
            %else %do;
               if first.usubjid then do i = 1 to dim(vars); 
                  vars{i} = '';
               end;                        
            %end;
            do i = 1 to dim(vars);
               if upcase(qnam) = upcase(vname(vars{i})) then vars{i} = qval;
            end;
            %if &idtype = N %then %do;
               &idvartemp = input(idvarval, best.);
            %end;
            %else %if (&idvartemp ne MISSING) and (&idvartemp ne NOIDVAR) %then %do;
               &idvartemp = idvarval;
            %end;
            %if &idvarnum %then %do;
               if last.idvarval;
            %end;
            %else %do;
               if last.usubjid;
            %end;            
            label 
            %do k = 1 %to &nvars;
               %scan(&varlist,&k,' ') = "%scan(%nrbquote(&varlabs),&k,'~')"
            %end;
            %if (&idvartemp ne MISSING) and (&idvartemp ne NOIDVAR) %then %do;
               &idvartemp = &idlab
            %end;
            ;
         run;

         %SHRINKCHARS(dsn = temp, vars = &varlist, flag = 0, order = %if &sidchk %then studyid; usubjid %if (&idvartemp ne MISSING) and (&idvartemp ne NOIDVAR) %then &idvartemp; &varlist);

         %if (&idvartemp ne MISSING) and (&idvartemp ne NOIDVAR) %then %do;
            proc sort data = temp out = %DataWorkIt(suppmeta.t&temp._&idvartemp);
               by usubjid &idvartemp;
            run;                 
         %end;
         %else %do;
            proc sort data = temp out = %DataWorkIt(suppmeta.t&temp._);
               by usubjid;
            run;         
         %end;
      
         proc datasets nolist;
            delete temp;
         quit;
      
         %let j = %eval(&j+1);
      %end;
            
      %if &&&shtemp.SUPPIDVAR = NOIDVAR %then %let &shtemp.suppidvar = MISSING;
      
      proc datasets nolist;
         delete &temp;
      quit;      
      
      %let i = %eval(&i+1);
   %end;
   %put Exiting TRANSSUPP;
   %ClockStop(TRANSSUPP);     
%mend TRANSSUPP;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;
/* fdomain:          Input data: each finding domain;
   fdBaseline:    Outputput data: baseline ;
*/
%macro ComputeBaseline(fdomain,fdbaseline);
   %put Entering ComputeBaseline;
   %ClockStart(ComputeBaseline);  
   proc datasets nolist;
      delete &fdbaseline;
   quit;
   %let fdomainsn = ;
   %if %sysfunc(findw(&&&fdomain.VARS, &fdomain.STRESN)) or %sysfunc(findw(&&&fdomain.VARS, AVAL)) %then %do;
      %let fdomainsn = &fdomainsn &fdomain;

      %let modlistB = POS LOC FAST SPEC METHOD TPT TPTNUM;    
      * flag to precompute change from baseline, percent of baseline and percent change from baseline;
      %if %sysfunc(indexw(&&&fdomain.VARS, &fdomain.BLFL, ' ')) %then %let &fdomain.BlFlag = &fdomain.BLFL;
      %else %let &fdomain.BlFlag = ;

      * create ordinal variable corresponding to sorted TPTNUM variable;
      %if %sysfunc(findw(&&&fdomain.VARS, &fdomain.TPTNUM)) %then %do;
         proc sort data=&&in_&fdomain(keep=&fdomain.TPTNUM) out=tpt nodupkey;
            by &fdomain.TPTNUM;
         run;
         
         data tpt;
            set tpt;
            &fdomain.TPTN_ = _n_;
         run;
         
         data i&fdomain;
            if 0 then set tpt;
            if _n_ eq 1 then do;
               declare hash h(dataset:"tpt");
               h.definekey("&fdomain.TPTNUM");
               h.definedata(ALL:"YES");
               h.definedone();
            end;
            do until(eof);
               set &&in_&fdomain end=eof;
               if h.find()=0 then output;
               else do;
                  call missing(VSTPTN_);
                  output;
               end;
            end;
         run;         
         %let fdata = i&fdomain;
      %end;
      %else %do;
         %let fdata = &&in_&fdomain;
         %if %length(&fdata) > 5 and %upcase(%substr(&fdata,1,5)) = WORK. %then %do;
            %let fdata = %substr(&fdata,6);
         %end;
      %end;
      
      %* run this if there is BDS OR there is no DY;
      %if %sysfunc(findw(&bdsdomains, &fdomain)) or ^%sysfunc(findw(&&&fdomain.VARS, &fdomain.DY)) %then %do;
         data i&fdomain /* (keep = USUBJID &fdomain.testcd &&&fdomain.BlFlag &fdomain.dy &fdomain.STRESN) */;
            set &fdata;
            %if %sysfunc(findw(&bdsdomains, &fdomain)) %then %do;
               rename PARAMCD=&fdomain.testcd aval=&fdomain.STRESN;;
            %end;
            %if ^%sysfunc(findw(&&&fdomain.VARS, &fdomain.DY)) %then %do;
               %calculateStudyDays(&fdomain);
            %end;
         run;
         %let fdata = i&fdomain;
      %end;
      %put compute baseline fdomain = &fdomain     fdata = &fdata;
      
      proc sort data=&fdata /* (keep = USUBJID &fdomain.testcd &&&fdomain.BlFlag &fdomain.dy &fdomain.STRESN) */ out=b&fdomain;
         by USUBJID &fdomain.testcd &&&fdomain.BlFlag &fdomain.dy;
      run;
   
      data b&fdomain;
         set b&fdomain;

			if missing(&fdomain.STRESN) then delete;

         %if %length(&&&fdomain.BlFlag) %then %do;
            if index(&&&fdomain.BlFlag,"Y") > 0;
         %end;
         %else %do;
            if . < &fdomain.dy <= 1;
         %end;
      run;

      data b&fdomain(keep = USUBJID &fdomain.testcd _BASE);
         set b&fdomain;
         by USUBJID &fdomain.testcd;
         _BASE = &fdomain.stresn;
         if last.&fdomain.testcd;
      run;    

      /*proc sql noprint;
         create table &fdbaseline(drop = USUBJID1 USUBJID2 &fdomain.testcd1 &fdomain.testcd2 rfstdtc) as
         select coalesce(aa.USUBJID1, bb.USUBJID2) as USUBJID, coalesce(aa.&fdomain.testcd1, bb.&fdomain.testcd2) as &fdomain.TESTCD, aa.*, bb.*, 
         case 
            when &fdomain.dy > 1 then &fdomain.stresn - _BASE 
            else .
         end as BLCHG,
         case 
            when &fdomain.dy > 1 then round((&fdomain.stresn - _BASE) / _BASE * 100, 0.1) 
            else .
         end as PBLCHG,
         case 
            when &fdomain.dy > 1 then round(&fdomain.stresn / _BASE * 100, 0.1) 
            else .
         end as PofBL
         from &fdata(rename=(USUBJID = USUBJID1 &fdomain.testcd = &fdomain.testcd1)) as aa 
         left join b&fdomain(rename=(USUBJID = USUBJID2 &fdomain.testcd = &fdomain.testcd2)) as bb
         on aa.USUBJID1 = bb.USUBJID2 and aa.&fdomain.testcd1 = bb.&fdomain.testcd2
         order by USUBJID, &fdomain.testcd, &fdomain.dy;
      quit; */
      data &fdbaseline;
         if 0 then set b&fdomain;
         if _n_ eq 1 then do;
            declare hash h(dataset:"b&fdomain");
            h.definekey("USUBJID","&fdomain.testcd");
            h.definedata(ALL:"YES");
            h.definedone();
         end;
         do until(eof);
            set &fdata end=eof;
            if &fdomain.dy > 1 then do;
               BLCHG = &fdomain.stresn - _BASE;
               PBLCHG = round((&fdomain.stresn - _BASE) / _BASE * 100, 0.1);
               PofBL = round(&fdomain.stresn / _BASE * 100, 0.1);
            end;
            else do;
               BLCHG=.;
               PBLCHG=.; 
               PofBL=.;
            end;
            if h.find()=0 then output;
            else do;
               call missing(_BASE);
               output;
            end;
         end;
      run;
      proc datasets nolist;
         delete b&fdomain;
      quit;
   %end;
   %cmbexit:;
   %put Exiting ComputeBaseline;
   %ClockStop(ComputeBaseline);  
%mend ComputeBaseline;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;
/* fdomain:       Input data: each finding domain;
   fdBaseline:    Input data: baseline from output of %ComputeBaseline;
   findm:         Output data: in order to write to metadata base directory;
*/
%macro ComputeQuantiles(fdomain,fdBaseline,findQuant);
   %put Entering ComputeQuantiles;
   %ClockStart(ComputeQuantiles);  
   * search for test code modifier variables and build a list of them;
   /* %let modlist = POS LOC FAST SPEC METHOD TPT TPTNUM; */
   %let modlist = POS LOC FAST SPEC METHOD;
   %let modvlist = ;
   %let modvlistc = ;
   %let modvlist1 = ;
   %let modvlist2 = ;
   %do jj=1 %to %sysfunc(countw(&modlist));
      %let modifier = %scan(&modlist,&jj,' ');
      %if %sysfunc(findw(&&&fdomain.VARS, &fdomain.&modifier)) %then %do;
         %if &modifier = TPT %then %do;
            %if %sysfunc(findw(&&&fdomain.VARS, &fdomain.TPTNUM)) %then %do;
               %let modvlist = &modvlist &fdomain.TPTNUM;
               %if ^%length(&modvlistc) %then %do;
                  %let modvlistc = &fdomain.TPTNUM;
               %end;
               %else %do;
                  %let modvlistc = &modvlistc, &fdomain.TPTNUM;
               %end;
            %end;
            %else %do;
               %let modvlist = &modvlist &fdomain.&modifier;
               %if ^%length(&modvlistc) %then %do;
                  %let modvlistc = &fdomain.&modifier;
               %end;
               %else %do;
                  %let modvlistc = &modvlistc, &fdomain.&modifier;
               %end;
            %end;
            %if ^%length(&modvlist2) %then %do;
               %let modvlist2 = &fdomain.&modifier;
            %end;
            %else %do;
               %let modvlist2 = &modvlist2 &fdomain.&modifier;
            %end;
         %end;
         %else %do;
            %let modvlist = &modvlist &fdomain.&modifier;
            %if ^%length(&modvlistc) %then %do;
               %let modvlistc = &fdomain.&modifier;
            %end;
            %else %do;
               %let modvlistc = &modvlistc, &fdomain.&modifier;
            %end;
            %if ^%length(&modvlist1) %then %do;
               %let modvlist1 = &fdomain.&modifier;
            %end;
            %else %do;
               %let modvlist1 = &modvlist1 &fdomain.&modifier;
            %end;
            %if ^%length(&modvlist2) %then %do;
               %let modvlist2 = &fdomain.&modifier;
            %end;
            %else %do;
               %let modvlist2 = &modvlist2 &fdomain.&modifier;
            %end;
         %end;
      %end;
   %end;
   data _null_;
      dsid = open("&fdBaseline");
      revflag=varnum(dsid,"&fdomain.RFLG");
      if revflag =0 then call symput ("revcheck",0);
      else call symput ("revcheck",1);
   run;
   %put modvlist = &modvlist;
   %put modvlistc = &modvlistc;
   %put modvlist1 = &modvlist1;
   %put modvlist2 = &modvlist2;
   data &fdomain.tmp;
      set &fdBaseline end=eof_ds2;
      if missing(&fdomain.STRESN) or index(upcase(&fdomain.CAT),"QUALITATIVE") then delete;
      %if &revcheck %then rename &fdomain.RFLG = RevFlag;
   run;
   %NObsVars(&fdomain.tmp);
   %if &nobs =0 %then %do;
      %goto cmqexit;
   %end;

   proc sort data=&fdomain.tmp;
      by &fdomain.testcd &modvlist;
   run;
      
   * compute quantiles for all subjects;
   data allsubs;
      set &fdBaseline(keep=&temp.testcd &modvlist &fdomain.STRESN BLCHG PBLCHG PofBL);
      if missing(&fdomain.STRESN) or index(upcase(&fdomain.CAT),"QUALITATIVE") then delete;
   run;
      
   proc sort data=allsubs;
      by &fdomain.testcd &modvlist;
   run;

   proc means data=allsubs noprint;
      by &fdomain.testcd &modvlist;
      var &fdomain.STRESN BLCHG PBLCHG PofBL;
      output out=&findQuant(keep=&fdomain.testcd &modvlist YP:) 
         p10=YP10_1 YP10_2 YP10_3 YP10_4 
         p25=YP25_1 YP25_2 YP25_3 YP25_4 
         p50=YP50_1 YP50_2 YP50_3 YP50_4 
         p75=YP75_1 YP75_2 YP75_3 YP75_4
         p90=YP90_1 YP90_2 YP90_3 YP90_4;
   run;
   proc datasets nolist;
      delete &fdomain.tmp allsubs;
   quit;
   %cmqexit:;
   %put Exiting ComputeQuantiles;
   %ClockStop(ComputeQuantiles);     
%mend ComputeQuantiles;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro CREATEMETADATA;
   %put Entering CREATEMETADATA;
   %ClockStart(CREATEMETADATA);  
   %global domaindups;
   %let domaindups = ;

   %TOOLKITME;    
   %if &CSTERROR %then %goto cmdexit;
   
   %if %length(&InPath) %then %do;
      %let numdups = 0;
      proc sql noprint;
         *** Check for duplicated domains ***;
         create table dups as
            select substr(table,1,4) as dupdomain, freq(calculated dupdomain) as ndomain
            from %DataWorkIt(sdtmmeta.source_tables)(where = (substr(table,1,4) ne "SUPP"))
            group by calculated dupdomain
            having ndomain > 1;
         %let numdups = &sqlobs;
      quit;

      %if &numdups %then %do;
         %GetLevels(dups,dupdomain,domaindups,_nLvls=sqlobs,_vType=vtype,_dropmiss = 1);
      %end;

      proc datasets nolist;
         delete dups;
      quit;

      %if %length(&domaindups) %then %do;
         %goto cmdexit;
      %end;
   %end;      
   %cmdexit:;
   %put Exiting CREATEMETADATA;
   %ClockStop(CREATEMETADATA);     
%mend CREATEMETADATA;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro IDENTIFYDOMAINS;
   %put Entering IDENTIFYDOMAINS;
   %ClockStart(IDENTIFYDOMAINS);  
   options nonotes;
   %global sdtmdomains domains domainclass adslpresent findingsdomains eventsdomains interventionsdomains MedDRAdomains suppdomains cdiscmodel bdsdomains splitdomains trialdesigndomains 
   	specialdomains numsupp numsdtm numadam numbds occurrencebdsdomains numOccurbds alladamdomains splittingdomains;

   %let findingsdomains = ;
   %let eventsdomains = ;
   %let interventionsdomains = ;
   %let MedDRAdomains = ;
   %let adslpresent =; 
   %let suppdomains = ;
   %let cdiscmodel = ;
   %let bdsdomains = ;
   %let occurrencebdsdomains = ;
   %let trialdesigndomains = ;
   %let specialdomains = ;
   %let alladamdomains = ;
   %let splittingdomains = ;
   
   %let trSpecial = %nrbquote(%LocaleGet(Special_Text));
   %let trEvents = %nrbquote(%LocaleGet(Events_Text));
   %let trInterventions = %nrbquote(%LocaleGet(Interventions_Text));
   %let trFindings = %nrbquote(%LocaleGet(Findings_Text));
   %let trTrial = %nrbquote(%LocaleGet(Trial_Text));
       
   proc sql noprint;
      %if %length(&InPath) %then %do;
         *** Identify all non-supp SDTM domains ***;
         %let sdtmdomains = ;
         select table
            into :sdtmdomains separated by ' '
            from %DataWorkIt(sdtmmeta.source_tables)
            where substr(upcase(table),1,4) ne "SUPP"
            order by table;
            %let numsdtm = &sqlobs;
         %let sdtmdomainclass = ;
         select scan(class, 1, " ")
            into :sdtmdomainclass separated by ' '
            from %DataWorkIt(sdtmmeta.source_tables)
            where substr(upcase(table),1,4) ne "SUPP"
            order by table;
         %let suppdomains = ;
         select table
            into :suppdomains separated by ' '
            from %DataWorkIt(sdtmmeta.source_tables)
            where substr(upcase(table),1,4) = "SUPP"
            order by table;
            %let numsupp = &sqlobs;
         %let cdiscmodel = ;
         select column
            into :cdiscmodel separated by ' '
            from %DataWorkIt(sdtmmeta.source_columns)
            where upcase(table) = "DM" and upcase(column) = "SETCD";
         %if %length(&cdiscmodel) %then %let cdiscmodel = SEND;
         %else %let cdiscmodel = SDTM;
      %end;
      %if %length(&AInPath) %then %do;
         %if cdiscmodel =  %then %let cdiscmodel = SDTM;
         *** Identify ADSL ***;
         %let adslpresent = ;
         select table
            into :adslpresent separated by ' '
            from %DataWorkIt(adammeta.source_tables)
            where upcase(table) = "ADSL"
            order by table;
         *** Identify all non-ADSL ADAM domains ***;
         %let alladamdomains =;
         select table
            into :alladamdomains separated by ' '
            from %DataWorkIt(adammeta.source_tables)
            where upcase(table) ne "ADSL"
            order by table;
            %let numadam = &sqlobs;
         *** Identify all non-ADSL ADAM domain classes ***;
         %let adamdomainclass = ;
         select scan(class, 1, " ")
            into :adamdomainclass separated by ' '
            from %DataWorkIt(adammeta.source_tables)
            where upcase(table) ne "ADSL"
            order by table;
         *** Identify all non-ADSL ADAM BDS domains ***;
         select table
            into :bdsdomains separated by ' '
            from %DataWorkIt(adammeta.source_columns)
            where upcase(column) = "PARAMCD" and upcase(table) ne "ADSL"
            order by table;
            %let numbds = &sqlobs;
         *** Identify all Occurrence ADAM BDS domains ***;
         select table
            into :occurrencebdsdomains separated by ' '
            from %DataWorkIt(adammeta.source_columns)
            where (upcase(column) = "ASTDTM" or upcase(column) = "ASTDT" or upcase(column) ="AENDTM" or upcase(column) ="AENDT") and upcase(table) ne "ADSL"
            order by table;
            %let numOccurbds = &sqlobs;
      %end;
   quit;      

   %if %length(&InPath) %then %do;
      %let domains = &sdtmdomains;
   %end;
   %else %do;
       %let domains = ;
   %end;

   *** check to see if the parent of SUPP domains exists, if not, delete it from suppdomains list ***;
   %let i = 1;
   %let suppdomainsTemp =;
   %let suppDelDomains =;
   %do %while(%length(%scan(&suppdomains,&i,' ')));
      %let tempSupp = %scan(%upcase(&suppdomains),&i," ");
      %let tempSupp2 = %substr(&tempSupp,5);
      %put domains=&domains tempSupp2=&tempSupp2;
      %if %sysfunc(findw(&domains, &tempSupp2)) %then %do;
      	%if %length(&tempSupp) >6 & %substr(&tempSupp,1,6) ^= SUPPFA %then %do;
      		%let suppDelDomains=&suppDelDomains &tempSupp;
      	%end;
      	%else %do;
         	%let suppdomainsTemp = &suppdomainsTemp &tempSupp;
         %end;
      %end;
      %else %do;
         %let suppDelDomains=&suppDelDomains &tempSupp;
      %end;
      %let i = %eval(&i+1);
   %end;
   %let suppdomains=&suppdomainsTemp;   
   %if %length(&InPath) %then %do;
      data %DataWorkIt(sdtmmeta.source_tables);
         set %DataWorkIt(sdtmmeta.source_tables);
         %let _i_ =1;
         %do %while(%length(%scan(&suppDelDomains,&_i_,' ')));
            %let temp = %scan(%upcase(&suppDelDomains),&_i_," ");
            if table ="&temp" then delete;
            %let _i_ = %eval(&_i_+1);
         %end;
      run;
      data %DataWorkIt(sdtmmeta.source_columns);
         set %DataWorkIt(sdtmmeta.source_columns);
         %let _i_ =1;
         %do %while(%length(%scan(&suppDelDomains,&_i_,' ')));
            %let temp = %scan(%upcase(&suppDelDomains),&_i_," ");
            if table ="&temp" then delete;
            %let _i_ = %eval(&_i_+1);
         %end;
      run;
    /*  %if &SpltDomainFlag %then %do;
			%let i = 1;
			%do %while(%length(%scan(&domains,&i,' ')));
				%let tempSplit = %scan(%upcase(&domains),&i," ");
				%if %length(&tempSplit) = 4 & ^%index(%upcase(&tempSplit),SUPP) %then %do;
					%let splittingdomains=&splittingdomains &tempSplit;
				%end;
				%let i = %eval(&i+1);
			%end;
      %end;*/
   %end;
   %if %length(&AInPath) %then %do;
      data %DataWorkIt(adammeta.source_tables);
         set %DataWorkIt(adammeta.source_tables);
         %let _i_ =1;
         %do %while(%length(%scan(&suppDelDomains,&_i_,' ')));
            %let temp = %scan(%upcase(&suppDelDomains),&_i_," ");
            if table ="&temp" then delete;
            %let _i_ = %eval(&_i_+1);
         %end;
      run;
      data %DataWorkIt(adammeta.source_columns);
         set %DataWorkIt(adammeta.source_columns);
         %let _i_ =1;
         %do %while(%length(%scan(&suppDelDomains,&_i_,' ')));
            %let temp = %scan(%upcase(&suppDelDomains),&_i_," ");
            if table ="&temp" then delete;
            %let _i_ = %eval(&_i_+1);
         %end;
      run;
   %end;
      
   %if %length(&AInPath) %then %do;
      %do i = 1 %to &numadam;
         %let temp = %substr(%scan(&alladamdomains,&i,' '),3);
         %let class = %scan(&adamdomainclass,&i,' ');
         %if ^%sysfunc(findw(&domains, &temp)) and %length(&class) %then %do;
            %let domains = &domains &temp;
         %end;
      %end;
      %if %length(&bdsdomains) %then %do;
         %let templist = ;
         %do i = 1 %to &numbds;
            %let temp = %substr(%scan(&bdsdomains,&i,' '),3);           
            %let templist = &templist &temp;
         %end;
         %let bdsdomains = &templist;
      %end;
      %if %length(&occurrencebdsdomains) %then %do;
         %let tempOccurlist = ;
         %do i = 1 %to &numOccurbds;
            %let temp = %substr(%scan(&occurrencebdsdomains,&i,' '),3);     
            %if ^%sysfunc(findw(&tempOccurlist, &temp)) %then %do;
					%let tempOccurlist = &tempOccurlist &temp;
				%end;
         %end;
         %let occurrencebdsdomains = &tempOccurlist;
      %end;
   %end;
   
   *** define class with ADaM taking precedence over SDTM ***;
   %let domainclass = ;
   %let i = 1;
   %do %while(%length(%scan(&domains,&i,' ')));
      %let temp = %scan(&domains,&i,' ');
      %if %sysfunc(findw(&alladamdomains, AD&temp)) %then %do;
         %let class = %scan(&adamdomainclass,%sysfunc(findw(&alladamdomains, AD&temp, ' ', E)),' ');
         %let domainclass = &domainclass &class;
      %end;
      %else %do;
         %let class = %scan(&sdtmdomainclass,%sysfunc(findw(&sdtmdomains, &temp, ' ', E)),' ');
         %let domainclass = &domainclass &class;
      %end;
      %let i = %eval(&i+1);
   %end;

   %let i = 1;
   %do %while(%length(%scan(&domains,&i,' ')));
      %let temp = %scan(&domains,&i,' ');
      %let class = %scan(&domainclass,&i,' ');
      %if %upcase(&temp) = DM or %upcase(&temp) = CO or %upcase(&temp) = SE or %upcase(&temp) = SV %then %let specialdomains =&specialdomains &temp;
      %if ((%length(&temp) = 3 or %length(&temp) =4) and %substr(&temp,1,2)= FA) & %length(&InPath) %then %let splittingdomains = &splittingdomains &temp;
      %if %upcase(&class) = %upcase(&trEvents) %then %let eventsdomains = &eventsdomains &temp;
        %else %if %upcase(&class) = %upcase(&trFindings) %then %let findingsdomains = &findingsdomains &temp; 
        %else %if %upcase(&class) = %upcase(&trInterventions) %then %let interventionsdomains = &interventionsdomains &temp;
        %else %if %upcase(&class) = %upcase(&trTrial) %then %let trialdesigndomains = &trialdesigndomains &temp; 
        %let i = %eval(&i+1);
   %end;
   
   %let MedDRAdomains = &eventsdomains &interventionsdomains;
   
   * check for split domains, if main domain exists, no need to include split domain sets;
   %if %sysfunc(findw(&findingsdomains,FA)) %then %let splittingdomains = ;
   
   *** subset suppdomains to only those that will be used with SDTM based on ADaM precedence ***;
   %if %length(&suppdomains) %then %do;
      %let templist = ;
      %let tempcount = 0;
      %let i = 1;
      %do %while(%length(%scan(&suppdomains,&i,' ')));
         %let temp = %scan(&suppdomains,&i,' ');
         %let tempsup = %substr(&temp,5);
         %if ^%sysfunc(findw(&alladamdomains, AD&tempsup)) %then %do;
            %let tempcount = %eval(&tempcount+1);
            %let templist = &templist &temp;
         %end;
         %let i = %eval(&i+1);
      %end;
      %let suppdomains = &templist;
      %let numsupp = &tempcount;
   %end;  
   
   *** transform and store SUPP domains ***;
   %if %length(&suppdomains) %then %do;
   	%global derivedmetaSupp;
   	%let derivedmetaSupp=%jg_getPath(/user/clinical/dataderivedmetadata/supp,,1,0,1,&studynameunder); 
   	libname suppmeta "&derivedmetaSupp";
   %end;
   %TRANSSUPP;
   
   * S1537938;
   *** prevent dual registration across domain classes Special and Findings ***;
   *%EnforceExclusiveListMembership(specialdomains, findingsdomains);
   *%EnforceExclusiveListMembership(findingsdomains, specialdomains);

   options notes;

   %put NOTE: Available Domains for Analysis: &domains;
   %put NOTE: Domains with Supplemental Qualifiers: &suppdomains;
   %put NOTE: Events Domains: &eventsdomains;
   %put NOTE: Findings Domains: &findingsdomains;
   %put NOTE: Interventions Domains: &interventionsdomains;
   %put NOTE: ADaM BDS Domains: &bdsdomains;
   %put NOTE: Occurrence BDS Domains: &occurrencebdsdomains;
   %put NOTE: MedDRAdomains Domains: &MedDRAdomains;
   %if &SpltDomainFlag %then %do;
   	%put NOTE: Split Domains: &splittingdomains;
   %end;
   %if %length(&adslpresent) %then %put NOTE: ADSL Available;
   %else %put NOTE: ADSL NOT Available;
     
   %idexit:;
   %put Exiting IDENTIFYDOMAINS;
   %ClockStop(IDENTIFYDOMAINS);     
%mend IDENTIFYDOMAINS;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro MISSVARS(model = SDTM, dir = , progressStart = 0.10, progressStop = 0.35);
   %put Entering MISSVARS;
   %ClockStart(MISSVARS);     
   options nonotes;
   ods exclude all;
   ods noresults;

   proc datasets library = &model memtype = data nolist;
     ods output variables = varlist(keep = member);
     contents data = _all_;
   quit;
   %if &model =SDTM %then %do;
   	%if &SpltDomainFlag %then %do;
   		proc datasets library = sdtmsp memtype = data nolist;
				ods output variables = varlistsp(keep = member);
				contents data = _all_;
			quit;
			* stack split domains in a separate subfolder with the main varlist;
			data varlist;
				set varlist varlistsp;
			run;
		%end;
   %end;

   %let SubList =;
   %let i = 1;
   %do %while(%length(%scan(&domains,&i,' ')));
      %let temp = %scan(&domains,&i,' ');
      %if %sysfunc(findw(&alladamdomains, AD&temp)) and &model = ADAM %then %do;
         %let SubList = &SubList AD&temp;
      %end;
      %else %if ^%sysfunc(findw(&alladamdomains, AD&temp)) and &model = SDTM %then %do;
         %let SubList = &SubList &temp;
         %if %sysfunc(findw(&suppdomains, %upcase(SUPP&temp))) %then %do;
            %let SubList = &SubList SUPP&temp;
         %end;
      %end;
      %let i = %eval(&i+1);
   %end;
   %if %length(&adslpresent) and &model = ADAM %then %do; 
      %let SubList = &SubList ADSL;
   %end;

   %let quotedSubList =;   
   %let i = 1;
   %do %while(%length(%scan(&SubList,&i,' ')));
      %let temp = %upcase(%scan(&SubList,&i,' '));
      %let quotedSubList = &quotedSubList "&temp";
      %let i = %eval(&i+1);
   %end;
   
   %if %length(&quotedSubList) %then %do;
      data varlist;
         set varlist;
         if substr(member, index(member,'.')+1) in (&quotedSubList);
      run;
   %end;
   
   %let datasets = ;
   %GetLevels(varlist,member,datasets,_nLvls=sqlobs,_vType=vtype,_dropmiss = 1);
   
   %let first = 0;
   %let i = 1;
   %do %while(%length(%scan(&datasets,&i,' ')));
      %let temp = %scan(%upcase(&datasets),&i," ");

      %let progressCurrent = %sysevalf(&progressStart + %sysevalf(%sysevalf(%eval(&i - 1) / %sysfunc(countw(&datasets, ' '))) * %sysevalf(&progressStop - &progressStart)));
      %put [AddStudyLocal_~MISSVARS Datasets &temp~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=&progressCurrent];

      %nObsVars(&temp);
      %if &nobs > 0 %then %do;
         *** checking first row to remove variables with data ***;
         %let _tid_ = %sysfunc(open(&temp));
         %let _vn_ = %sysfunc(varnum(&_tid_,_name_));
         %let _tid_ = %sysfunc(close(&_tid_));  

         data temp;
            set &temp(obs = 1);
            %if &_vn_ %then %do;
              drop _name_; 
            %end;
         run;                
         
         proc transpose data = temp out = tempn(where = (missing(col1)));
            var _numeric_;
         run;
         proc transpose data = temp out = tempc(where = (missing(col1)));
            var _character_;
         run;
         
         %let missvarsn =;
         %GetLevels(tempn,_NAME_,missvarsn,_nLvls=sqlobs,_vType=vtype,_dropmiss = 1);
         %let missvarsc =;
         %GetLevels(tempc,_NAME_,missvarsc,_nLvls=sqlobs,_vType=vtype,_dropmiss = 1);
                  
         %if %length(&missvarsn) or %length(&missvarsc) %then %let missvars = %sysfunc(strip(&missvarsn &missvarsc));
         %else %let missvars =;               
      
         %if %length(&missvars) %then %do;
            proc sort data = &temp(keep = &missvars) nodupkey out = temp;
               by &missvars;
            run;

            proc freq data = temp nlevels;
               ods output nlevels=temp1;
            run;

            proc datasets nolist;
               delete temp;
            quit;

            %let _tid_ = %sysfunc(open(temp1));
            %let _vn_ = %sysfunc(varnum(&_tid_,nnonmisslevels));
            %let _tid_ = %sysfunc(close(&_tid_));  

            %if &_vn_ %then %do;
               data temp1(keep = column1 table1);
                  length column1 $ 8 table1 $ 32;
                  set temp1(where=(nnonmisslevels eq 0));
                  column1 = upcase(tablevar);
                  table1 = upcase("%scan(&temp,2,.)");
               run;

               %if ^&first %then %do;
                  data alltemp;
                    set temp1;
                  run;
                  %let first = 1;
               %end;
               %else %do;
                  proc append force base = alltemp data = temp1;
                  run;
               %end;

               proc datasets nolist;
                  delete temp temp1;
               quit;
            %end;
         %end;
      %end;
      %let i = %eval(&i+1);
   %end;
   
   %if ^&first %then %do;
      data alltemp;
         length column1 $ 8 table1 $ 32;
         stop;
      run;
   %end;
   
   proc sort data = alltemp;
      by table1 column1;
   run;
   
   data %DataWorkIt(&dir..missvars&model)(keep = column table);
      set alltemp;
      column = trim(column1);
      table = trim(table1);
   run;

   proc datasets nolist;
     delete alltemp;
   quit;
        
   %mvexit:; 
   options notes;
   ods exclude none;
   ods results;
   %put Exiting MISSVARS;
   %ClockStop(MISSVARS);        
%mend MISSVARS;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro METADATAOUTFILES;
   %put Entering METADATAOUTFILES;
   %ClockStart(METADATAOUTFILES);     
        
   %let trDescriptionofPlannedArm = %nrbquote(%LocaleGet(DescriptionofPlannedArm_Text));
   %let trNameofActualTreatment = %nrbquote(%LocaleGet(NameofActualTreatment_Text));
   %let trDoseperAdministration = %nrbquote(%LocaleGet(DoseperAdministration_Text));
   %let trBlindedTreatment = %nrbquote(%LocaleGet(BlindedTreatment_Text));   
   
   %put [AddStudyLocal_~METADATAOUTFILES Remove Null Variables~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.61];
   
   %if %length(&InPath) %then %do;
      *** Removes null variables from SDTM ***;      
      data sdtm_source_columns;
         merge %DataWorkIt(sdtmmeta.source_columns)(keep = table column where = (substr(upcase(table),1,4) ne "SUPP") in = ina) 
               %DataWorkIt(sdtmmeta.missvarssdtm)(where = (substr(upcase(table),1,4) ne "SUPP") in = inb);
         by table column;
         if ina and not inb;
      run;               
   %end;

   %if %length(&AInPath) %then %do;
      *** Removes null variables from ADAM ***;
      data adam_source_columns;
         merge %DataWorkIt(adammeta.source_columns)(keep = table column where = (substr(upcase(table),1,4) ne "SUPP") in = ina) 
               %DataWorkIt(adammeta.missvarsadam)(where = (substr(upcase(table),1,4) ne "SUPP") in = inb);
         by table column;
         if ina and not inb;
      run;               
   %end;
   
   %put [AddStudyLocal_~METADATAOUTFILES Identify Variables~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.62];
   
   options nonotes; 
   %if ^%symexist(SUBJIDFlag) %then %let SUBJIDFlag=No;

   %global DMBlind ADSLBlind EXBlind;
   %let DMBlind = 0;
   %let ADSLBlind = 0;
   %let EXBlind = 0;
   
   %if %length(&InPath) %then %do;
      *** Identify all variables within each SDTM domain ***;
      %do i = 1 %to &numsdtm;
         %let temp = %scan(&sdtmdomains,&i,' ');
         %let &temp.var = ;
         %GetLevels(sdtm_source_columns,column,&temp.var,_nLvls=sqlobs,_vType=vtype,_dropmiss = 1,_wherest = %str(upcase(table) = "&temp"),_outtab = &temp.VARLIST);
			
			data Varlabellist;
            set %DataWorkIt(sdtmmeta.source_columns);
				if upcase(table) = "&temp";
			run;
			proc sort data = Varlabellist;
				by column;
			run;
			data &temp.VARLIST;
				merge &temp.VARLIST(in=ina) Varlabellist;
				by column;
				if ina;
				keep table column label;
			run;    
         %if ^%sysfunc(findw(&alladamdomains, AD&temp)) %then %do;

            %if &temp = EX %then %do;
               %CHKBLIND(domain = EX);
            %end;         
            %else %if &temp = DM %then %do;            
               %CHKBLIND(domain = DM);
            %end;

            data _null_;
               set &temp.VARLIST;
               file "%FileWorkIt(&basemeta&_slash_.&temp.VARLIST.txt)" delimiter = "~" encoding="utf-8";
               if ^missing(label) then put column label;
               else put column;
               %if &temp = DM and &DMBlind %then %do;
                  if column in ("ACTARM","TRT01P","TRT01A") then delete;
               %end;
            run;
            
            %if &temp ne DM %then %do;
               proc datasets nolist;
                  delete &temp.VARLIST;
               quit;
            %end;
         %end;                  
      %end;
      
      *** Identify variables from supp Domains ***;
      %if %length(&suppdomains) %then %do;
         %do i = 1 %to &numsupp;
            %let temp = %scan(&suppdomains,&i,' ');
            %let &temp.var = ;
            %let tempdom = %substr(&temp,5);
            %put SpltDomainFlag=&SpltDomainFlag;
            %if &SpltDomainFlag %then %do;
            	%if %length(&temp)=7 or %length(&temp)=8 %then %do;
    					%let supplibalias =sdtmsp.&temp;
            	%end;
            	%else %do;
            		%let supplibalias =sdtm.&temp;
            	%end;
            %end;
            %else %do;
            	%let supplibalias = sdtm.&temp;           	
            %end;
				proc sort data=&supplibalias(where=(missing(qnam)=0)) nodupkey out = &temp.VARLIST(keep=qnam qlabel);
					by qnam qlabel;
				run;
            *** check to make sure all variables begin with domain code ***;
           	data &temp.VARLIST;
           	   set &temp.VARLIST;
           	   %if &tempdom ne DM %then %do;
           	      if substr(qnam, 1, 2) ne "%substr(&tempdom, 1, 2)" then qnam = cats("%substr(&tempdom,1,2)",qnam);
           	   %end;
           	run;
         	          
           	%let &temp.var = ;
				proc sql noprint; 
					select distinct qnam 
		         into :&temp.var separated by ' '
		         from &temp.VARLIST;
		      quit;

           	data _null_;
           	   set &temp.VARLIST;
               file "%FileWorkIt(&basemeta&_slash_.&tempdom.SUPPVARLIST.txt)" delimiter = "~" encoding="utf-8";
           	   put qnam qlabel;
           	run;
            
           	%if &temp ne SUPPDM %then %do;
           	   proc datasets nolist;
           	      delete &temp.VARLIST;
           	   quit;
           	%end;
         %end;
      %end;
   %end;
     
   %if %length(&AInPath) %then %do;
      *** Identify all variables within each ADaM domain ***;
      %do i = 1 %to &numadam;
         %let temp = %scan(&alladamdomains,&i,' ');
         %let &temp.var = ;
         %let tempdom = %substr(&temp,3);
         %GetLevels(adam_source_columns,column,&temp.var,_nLvls=sqlobs,_vType=vtype,_dropmiss = 1,_wherest = %str(upcase(table) = "&temp"),_outtab = &temp.VARLIST);

			data Varlabellist;
            set %DataWorkIt(adammeta.source_columns);
				if upcase(table) = "&temp";
			run;
			proc sort data = Varlabellist;
				by column;
			run;
			data &temp.VARLIST;
				merge &temp.VARLIST(in=ina) Varlabellist;
				by column;
				if ina;
				keep table column label;
			run;
			
         %if &temp = ADEX %then %do;
            %CHKBLIND(domain = EX);
         %end;         
         %else %if &temp = ADDM %then %do;         
            %CHKBLIND(domain = DM);            
         %end;

         data _null_;
            set &temp.VARLIST;
            file "%FileWorkIt(&basemeta&_slash_.&tempdom.VARLIST.txt)"  delimiter = "~" encoding="utf-8";
            put column label;
            %if &temp = ADDM and &DMBlind %then %do;
               if column in ("ACTARM","TRT01P","TRT01A") then delete;
            %end;            
         run;

         %if &temp ne ADDM %then %do;
            proc datasets nolist;
               delete &temp.VARLIST;
            quit;        
         %end;
      %end;
   %end;   
   
   %if %length(&adslpresent) %then %do;
      %let ADSLvar = ;
      %GetLevels(adam_source_columns,column,ADSLvar,_nLvls=sqlobs,_vType=vtype,_dropmiss = 1,_wherest = %str(upcase(table) = "ADSL"),_outtab = ADSLVARLIST);
		data ADSLVARLABEL;
         set %DataWorkIt(adammeta.source_columns);
			if upcase(table) = "ADSL";
		run;
		proc sort data = ADSLVARLABEL;
			by column;
		run;
		data ADSLVARLIST;
			merge ADSLVARLIST(in=ina) ADSLVARLABEL;
			by column;
			if ina;
			keep table column label;
		run;
      %CHKBLIND(domain = ADSL);
   %end;   

   *** create ADSL variable list considering ADDM, DM and SUPPDM ***;
   %if %length(&adslpresent) %then %do;
      data ADSLVARLIST;
         length column $ 32;
         set ADSLVARLIST
         %if %sysfunc(findw(%upcase(&domains), DM)) %then %do;
            %if %sysfunc(findw(&alladamdomains, ADDM)) %then %do;
               ADDMVARLIST
            %end;
            %else %do;
               DMVARLIST
               %if %sysfunc(findw(%upcase(&suppdomains), SUPPDM)) %then %do;
                  SUPPDMVARLIST(rename = (qnam = column))
               %end;
            %end;
         %end;
         ;
      run;           
   %end;
   %else %do;
      data ADSLVARLIST;
         length column $ 32;
         set
         %if %sysfunc(findw(&alladamdomains, ADDM)) %then %do;
            ADDMVARLIST
         %end;
         %else %do;
            DMVARLIST
            %if %sysfunc(findw(%upcase(&suppdomains), SUPPDM)) %then %do;
               SUPPDMVARLIST(rename = (qnam = column qlabel = label))
            %end;
         %end;
         ;
      run;
   %end;
   
   %put [AddStudyLocal_~METADATAOUTFILES Sort ADSLVARLIST~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.65];
   
   proc sort data = ADSLVARLIST nodupkey out = ADSLVARLIST;
      by column;
   run;
   
   data _null_;
      set ADSLVARLIST;
      file "%FileWorkIt(&basemeta&_slash_.ADSLVARLIST.txt)" delimiter = "~" encoding="utf-8";
      if ^missing(label) then put column label;
      else put column;
      %if &ADSLBlind %then %do;
         if column in ("ACTARM","TRT01P","TRT01A") then delete;
      %end;                  
   run;
   
   %let DelData = ;
   %if %sysfunc(findw(%upcase(&domains), DM)) %then %do;
      %if %sysfunc(findw(&alladamdomains, ADDM)) %then %do;
         %let DelData = &DelData ADDMVARLIST;
      %end;
      %else %do;
         %let DelData = &DelData DMVARLIST;
         %if %sysfunc(findw(%upcase(&suppdomains), SUPPDM)) %then %do;
            %let DelData = &DelData SUPPDMVARLIST;
         %end;
      %end;
   %end;      

   %if %length(&DelData) %then %do;
      proc datasets nolist;
         delete &DelData;
      quit;
   %end;
       
   *** Initialize macrovariable file ***;
   data _null_;
      file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)";
      put "%nrstr(%macro) libassign;";
      put "   %nrstr(%global) SDTMMETA ADAMMETA BASEMETA DERIMETA;";
      put "   %nrstr(%let) SDTMMETA = &SDTMMETA;";
      put "   %nrstr(%let) ADAMMETA = &ADAMMETA;";
      put "   %nrstr(%let) BASEMETA = &BASEMETA;";
      put "   %nrstr(%let) DERIMETA = &DERIMETA;";
      put "   libname sdtmmeta;";
      put "   %nrstr(%if %length(&SDTMMETA) %then %do;)";
      put "      %nrstr(%if %sysfunc(fileexist(&SDTMMETA)) %then %do;)"; 
      put "         libname sdtmmeta '&SDTMMETA';";
      put "      %nrstr(%end;)";
      put "   %nrstr(%end;)";
      put "   libname adammeta;";
      put "   %nrstr(%if %length(&ADAMMETA) %then %do;)";
      put "      %nrstr(%if %sysfunc(fileexist(&ADAMMETA)) %then %do;)"; 
      put "         libname adammeta '&ADAMMETA';";
      put "      %nrstr(%end;)";
      put "   %nrstr(%end;)";
      put "   libname basemeta;";
      put "   libname derimeta;";
      put "   %nrstr(%if %length(&BASEMETA) %then %do;)";
      put "      %nrstr(%if %sysfunc(fileexist(&BASEMETA)) %then %do;)"; 
      put "         libname basemeta '&BASEMETA';";
      put "      %nrstr(%end;)";
      put "   %nrstr(%end;)";
      put "   %nrstr(%if %length(&DERIMETA) %then %do;)";
      put "      %nrstr(%if %sysfunc(fileexist(&DERIMETA)) %then %do;)"; 
      put "         libname derimeta '&DERIMETA';";
      put "      %nrstr(%end;)";
      put "   %nrstr(%end;)";
      put "   libname sdtm;";
      put "   %nrstr(%if %length(&InPath) %then %do;)";
      put "      %nrstr(%if %sysfunc(fileexist(%"&InPath%")) %then %do;)"; 
      %if %symexist(SASTransport) %then %do;
         %if &SASTransport %then %do;
            put "         libname sdtm cvp '&InTmpPath';";
         %end;
         %else %do;
            put "         libname sdtm cvp '&InPath';";
         %end;
      	%if &SpltDomainFlag %then %do;
      		put "   %nrstr(%if %length(&InPathSP) %then %do;)";
      		put "         libname sdtmsp cvp '&InPathSP';";
      		put "      %nrstr(%end;)";
      	%end;
      %end;
      %else %do;
         put "         libname sdtm cvp '&InPath';";
      	%if &SpltDomainFlag %then %do;
      	/*	put "  	 	%nrstr(%if %length(&InPathSP) %then %do;)";*/
      		put "     	   libname sdtmsp cvp '&InPathSP';";
      	/*	put "     	%nrstr(%end;)";*/
      	%end;
      %end;
      put "      %nrstr(%end;)";
      put "   %nrstr(%end;)";
      put "   libname adam;";
      put "   %nrstr(%if %length(&AInPath) %then %do;)";
      put "      %nrstr(%if %sysfunc(fileexist(%"&AInPath%")) %then %do;)"; 
      %if %symexist(SASTransport) %then %do;
         %if &SASTransport %then %do;
            put "         libname adam cvp '&AInTmpPath';"; 
         %end;
         %else %do;
            put "         libname adam cvp '&AInPath';"; 
         %end;
      %end;
      %else %do;
         put "         libname adam cvp '&AInPath';"; 
      %end;
      put "      %nrstr(%end;)";
      put "   %nrstr(%end;)";
      %if %length(&suppdomains) %then %do;
      	put "         libname suppmeta '&derivedmetaSupp';"; 
      %end;
      put "%nrstr(%mend;)";
      put "%nrstr(%libassign;)";
   run;

   %ALPHABETIZE(varlist = domains);
   %ALPHABETIZE(varlist = eventsdomains);
   %ALPHABETIZE(varlist = findingsdomains);
   %ALPHABETIZE(varlist = interventionsdomains);
   %ALPHABETIZE(varlist = suppdomains);
   %ALPHABETIZE(varlist = bdsdomains);
   %ALPHABETIZE(varlist = occurrencebdsdomains);
   
   *** Create Domain Lists ***;
   data _null_;
      file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
      put "%nrstr(%global) domains adslpresent findingsdomains eventsdomains interventionsdomains suppdomains bdsdomains occurrencebdsdomains cdiscmodel specialdomains trialdesigndomains SUBJIDFlag splitdomains SplitFolderFlag;";
      put "%nrstr(%let) cdiscmodel = &cdiscmodel;";
      put "%nrstr(%let) domains = &domains;";
      put "%nrstr(%let) specialdomains = &specialdomains;";
      put "%nrstr(%let) adslpresent = &adslpresent;";
      put "%nrstr(%let) findingsdomains = &findingsdomains;";
      put "%nrstr(%let) eventsdomains = &eventsdomains;";
      put "%nrstr(%let) interventionsdomains = &interventionsdomains;";
      put "%nrstr(%let) suppdomains = &suppdomains;";
      put "%nrstr(%let) bdsdomains = &bdsdomains;";
      put "%nrstr(%let) occurrencebdsdomains = &occurrencebdsdomains;";
      put "%nrstr(%let) trialdesigndomains = &trialdesigndomains;";
      put "%nrstr(%let) splitdomains = &splittingdomains;";
      put "%nrstr(%let) SplitFolderFlag = &SpltDomainFlag;";
      put "%nrstr(%let) SUBJIDFlag = &SUBJIDFlag;";
      put "%nrstr(%global) DMBlind ADSLBlind EXBlind;";
      put "%nrstr(%let) DMBlind = &DMBlind;";
      put "%nrstr(%let) ADSLBlind = &ADSLBlind;";
      put "%nrstr(%let) EXBlind = &EXBlind;";      
      %if %length(&InPath) %then %do;
         put "%nrstr(%global) relrecpresent pooldefpresent;";   
         %if %sysfunc(fileexist(&InPath.relrec.sas7bdat)) %then %do;
            put "%nrstr(%let) relrecpresent = relrec;";
         %end;
         %else %do;
            put "%nrstr(%let) relrecpresent = ;";
         %end;
         %if %sysfunc(fileexist(&InPath.pooldef.sas7bdat)) %then %do;
            put "%nrstr(%let) pooldefpresent = pooldef;";
         %end;
         %else %do;
            put "%nrstr(%let) pooldefpresent = ;";
         %end;         
      %end;
   run;
      
   %let i = 1;
   *** Creates domain data set specifications with ADaM taking precedence ***;
   %do %while(%length(%scan(&domains,&i,' ')));
      %let temp = %scan(&domains,&i,' ');
      %if %sysfunc(findw(&alladamdomains, AD&temp)) %then %do;
         %let in_&temp = adam.AD&temp;
         data _null_;
            file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
            put "%nrstr(%global) in_&temp;";
            put "%nrstr(%let) in_&temp = adam.AD&temp;";
         run;   
      %end;
      %else %if ^%sysfunc(findw(&alladamdomains, AD&temp)) %then %do;
      	%if &SpltDomainFlag %then %do;
      		%if %length(&temp)<=4 & %length(&temp)>2 & %substr(&temp,1,4) ne SUPP %then %do;
      			%let in_&temp = sdtmsp.&temp;
        			data _null_;
                  file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
						put "%nrstr(%global) in_&temp;";
						put "%nrstr(%let) in_&temp = sdtmsp.&temp;";
					run; 
      		%end;
      		%else %do;
      			%let in_&temp = sdtm.&temp;
					data _null_;
                  file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
         		   put "%nrstr(%global) in_&temp;";
         		   put "%nrstr(%let) in_&temp = sdtm.&temp;";
         		run;  
      		%end;
      	%end;
      	%else %do;
      		%let in_&temp = sdtm.&temp;
				data _null_;
               file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
         	   put "%nrstr(%global) in_&temp;";
         	   put "%nrstr(%let) in_&temp = sdtm.&temp;";
         	run;   
         %end;
      %end;
      %let i = %eval(&i+1);
   %end;
   *** Creates adsl data set specifications. if adsl not present DM fills in ***;
   %if %length(&adslpresent) > 0 %then %do;
      %let in_ADSL = adam.ADSL;
      %let Orig_ADSL = adam.ADSL;
      data _null_;
         file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
         put "%nrstr(%global) in_ADSL;";
         put "%nrstr(%let) in_ADSL = derimeta.TADSL;";
         put "%nrstr(%global) Orig_ADSL;";
         put "%nrstr(%let) Orig_ADSL = adam.ADSL;";
         
      run;  
   %end;
   %else %if ^%length(&adslpresent) and %sysfunc(findw(&domains, DM)) %then %do;
      %let in_ADSL = &in_dm;
      %let Orig_ADSL = &in_dm;
      data _null_;
         file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
         put "%nrstr(%global) in_ADSL;";
         put "%nrstr(%let) in_ADSL = derimeta.TADSL;";
         put "%nrstr(%global) Orig_ADSL;";
         put "%nrstr(%let) Orig_ADSL = &in_dm;";
      run;
   %end;

   data bothlabels;
      length table $ 8 label $ 50;
      set %if %length(&InPath) %then %do; %DataWorkIt(sdtmmeta.source_tables)(keep = table label in = ina) %end;
          %if %length(&AInPath) %then %do; %DataWorkIt(adammeta.source_tables)(keep = table label in = inb) %end;;
      if label = "" then do;
         if ina then label = table;
         else if inb then label = substr(table,3);
      end;
      label = TRANSTRN(label,"'",TRIMN(""));
      label = TRANSTRN(label,'"',TRIMN(""));
   run;
   
   proc sort data = bothlabels;
      by table;
   run;

   *** Create TXT files of Domains ***;
   data findings;
      length domain $ 8 table $ 8;
      %let i = 1;
      %do %while(%length(%scan(&findingsdomains,&i,' ')));
         %let temp = %scan(%upcase(&findingsdomains),&i," ");
         %let prefix = %scan(&&in_&temp, 1, ".");
         domain = "&temp"; 
         %if %upcase(&prefix) = ADAM %then %do;
            table = "AD&temp";
         %end;
         %else %do;
            table = "&temp";
         %end;
         output;
         %let i = %eval(&i+1);
      %end; 
   run; 

   data events;
      length domain $ 8 table $ 8;
      %let i = 1;
      %do %while(%length(%scan(&eventsdomains,&i,' ')));
         %let temp = %scan(%upcase(&eventsdomains),&i," ");
         %let prefix = %scan(&&in_&temp, 1, ".");
         domain = "&temp"; 
         %if %upcase(&prefix) = ADAM %then %do;
            table = "AD&temp";
         %end;
         %else %do;
            table = "&temp";
         %end;
         output;
         %let i = %eval(&i+1);
      %end; 
   run; 

   data interventions;
      length domain $ 8 table $ 8;
      %let i = 1;
      %do %while(%length(%scan(&interventionsdomains,&i,' ')));
         %let temp = %scan(%upcase(&interventionsdomains),&i," ");
         %let prefix = %scan(&&in_&temp, 1, ".");
         domain = "&temp"; 
         %if %upcase(&prefix) = ADAM %then %do;
            table = "AD&temp";
         %end;
         %else %do;
            table = "&temp";
         %end;
         output;
         %let i = %eval(&i+1);
      %end; 
   run;
   
   data specials;
      length domain $ 8 table $ 8;
      %let i = 1;
      %do %while(%length(%scan(&specialdomains,&i,' ')));
         %let temp = %scan(%upcase(&specialdomains),&i," ");
         %let prefix = %scan(&&in_&temp, 1, ".");
         domain = "&temp"; 
         %if %upcase(&prefix) = ADAM %then %do;
            table = "AD&temp";
         %end;
         %else %do;
            table = "&temp";
         %end;
         output;
         %let i = %eval(&i+1);
      %end; 
   run;

   *** Prepare to create a txt file to have all of the domains ***;
   data Alldomains;
      length Name $10;
      set %if %length(&InPath) %then %do; %DataWorkIt(sdtmmeta.source_tables) %end; %if %length(&AInPath) %then %do; %DataWorkIt(adammeta.source_tables) %end;;
   run;
   data AllnoUsedDom(rename = (name = table));
      length Name $10;
      set %if %length(&AInPath) %then %do; adamnousedDom %end; %if %length(&InPath) %then %do; sdtmnousedDom %end;;
   run;

   * Exclude SDTM domains if companion ADAM data set is present;
   %if %length(&InPath) & %length(&AInPath) %then %do; 
   	data adam_table;
         set %DataWorkIt(adammeta.source_tables);
   		table2=substr(Table, 3);
   		drop Table;
   		rename table2=Table;
   	run;
   	data sdtm_table;
         set %DataWorkIt(sdtmmeta.source_tables);
   	run;
   	proc sort data =sdtm_table;
   		by Table;
   	run;
   	proc sort data =adam_table;
   		by Table;
   	run;
   	data merged_table(keep= Table);
   		merge sdtm_table(in =ina) adam_table(in=inb);
   		by Table;
   		if ina and inb;
   	run;
   	%Nobsvars(merged_table);
   	%if &nobs>0 %then %do;
   		proc sort data =Alldomains;
   			by Table;
   		run;
   		proc sort data =merged_table;
   			by Table;
   		run;
   		data Alldomains;
   			merge Alldomains(in=ina) merged_table(in=inb);
   			by Table;
   			if ina and not inb;
   		run;
   	%end;
   %end;
   
   %if %length(&InPath) %then %do; 
   	%if %sysfunc(fileexist(&InPath.relrec.sas7bdat)) %then %do;
   		data relrecdom;
   			set AllnoUsedDom;
   			if table ="RELREC";
   			Label = "RELREC";
   			class = "Relationship";
   			flag = "SDTM";
   		run;
   		data Alldomains;
   			set Alldomains relrecdom;
   		run;
   	%end;
   	%if %sysfunc(fileexist(&InPath.pooldef.sas7bdat)) %then %do;
    		data pooldefdom;
    			set AllnoUsedDom;
    			if table ="POOLDEF";
    			Label = "POOLDEF";
    			class = "Relationship";
   			flag = "SDTM";
   		run;
    		data Alldomains;
    			set Alldomains pooldefdom;
   		run;
   	%end;
   %end;

   %let findingsdomainslabel = ;
   %let eventsdomainslabel = ;
   %let interventionsdomainslabel = ;
   %let specialdomainslabel = ;
   
   %put [AddStudyLocal_~METADATAOUTFILES Get Domain Labels~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.70];
   
   *** get domain labels ***;   
   proc sql noprint;
      create table findings2(drop = table1 table2) as
         select coalesce(A.table1, B.table2) as table, A.*, B.*
         from findings(rename=(table=table1)) as A left join bothlabels(rename=(table=table2)) as B
         on A.table1 = B.table2
         order by domain;
      select label
         into :findingsdomainslabel separated by '~'
         from findings2
         order by domain;
      create table events2(drop = table1 table2) as
         select coalesce(A.table1, B.table2) as table, A.*, B.*
         from events(rename=(table=table1)) as A left join bothlabels(rename=(table=table2)) as B
         on A.table1 = B.table2
         order by domain;
      select label
         into :eventsdomainslabel separated by '~'
         from events2
         order by domain;
      create table interventions2(drop = table1 table2) as
         select coalesce(A.table1, B.table2) as table, A.*, B.*
         from interventions(rename=(table=table1)) as A left join bothlabels(rename=(table=table2)) as B
         on A.table1 = B.table2
         order by domain;
      select label
         into :interventionsdomainslabel separated by '~'
         from interventions2
         order by domain;
      create table specials2(drop = table1 table2) as
         select coalesce(A.table1, B.table2) as table, A.*, B.*
         from specials(rename=(table=table1)) as A left join bothlabels(rename=(table=table2)) as B
         on A.table1 = B.table2
         order by domain;
		select label
			into :specialdomainslabel separated by '~'
			from specials2
         order by domain;
   quit;
   
   data _null_;
      set findings2(drop = table);
      file "%FileWorkIt(&basemeta&_slash_.FINDINGS.txt)" delimiter = "~" encoding="utf-8";
      put domain label;
   run;

   data _null_;
      set events2;
      file "%FileWorkIt(&basemeta&_slash_.EVENTS.txt)" delimiter = "~" encoding="utf-8";
      put domain label;
   run; 

   data _null_;
      set interventions2;
      file "%FileWorkIt(&basemeta&_slash_.INTERVENTIONS.txt)" delimiter = "~" encoding="utf-8";
      put domain label;
   run; 
   
   data _null_;
      set Alldomains;
      file "%FileWorkIt(&basemeta&_slash_.ALLDOMAINS.txt)" delimiter = "~" encoding="utf-8";
      put table Label class flag;
   run;

   proc datasets nolist;
      delete findings events interventions events2 interventions2 ;
   quit;

   data _null_;
      file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
      put "%nrstr(%global) findingsdomainslabel eventsdomainslabel interventionsdomainslabel specialdomainslabel;";
      put "%nrstr(%let) findingsdomainslabel = &findingsdomainslabel;";
      put "%nrstr(%let) eventsdomainslabel = &eventsdomainslabel;";
      put "%nrstr(%let) interventionsdomainslabel = &interventionsdomainslabel;";
      put "%nrstr(%let) specialdomainslabel = &specialdomainslabel;";
   run;           

   *** Creates data set variables lists based on specifications.  Adds SUPP variables if available ***;
   %let i = 1;
   %global DMVariables;
   %let DMVariables=;
   %do %while(%length(%scan(&domains,&i," ")));
      %let temp = %scan(&domains,&i," ");
      %let prefix = %scan(&&in_&temp, 1, ".");
      %let supp =;
      %if %upcase(&prefix) ne ADAM and %sysfunc(findw(&suppdomains, %upcase(SUPP&temp))) %then %let supp = &&supp&temp.var;
      %global &temp.VARS;
      %if %upcase(&prefix) = ADAM %then %let &temp.VARS = %upcase(&&AD&temp.var);
      %else %let &temp.VARS = %upcase(&&&temp.var);
      %if %length(&supp) %then %do;
         %global &temp.SUPPVARS;
         %let &temp.SUPPVARS = %upcase(&supp);
      %end;      
      %put i=&i temp=&temp;
      %if %upcase(&temp) = DM %then %let DMVariables=&&&temp.VARS;      
      * S1392257 begin;
      %if %upcase(&temp) = DM and ^%length(&adslpresent) and &DMBlind %then %let &temp.VARS = &&&temp.VARS ARM;
      * S1392257 end;
      data _null_;
         file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
         put "%nrstr(%global) &temp.VARS;";
         put "%nrstr(%let) %sysfunc(trim(&temp.VARS = %upcase(&&&temp.VARS)));";
         %if %length(&supp) %then %do;
            put "%nrstr(%global) &temp.SUPPVARS;";
            put "%nrstr(%let) %sysfunc(trim(&temp.SUPPVARS = %upcase(&supp)));";
            put "%nrstr(%global) &temp.SUPPIDVAR;";
            put "%nrstr(%let) %sysfunc(trim(&temp.SUPPIDVAR = %upcase(&&&temp.SUPPIDVAR)));";
         %end;
      run;
      %if %length(&supp) %then %do;
         %if %length(&&&temp.SUPPIDVAR) %then %do;
            data _null_;
               file "%FileWorkIt(&basemeta&_slash_.&temp.SUPPIDVAR.txt)";
               put "%upcase(&&&temp.SUPPIDVAR)";            
            run;
         %end;
         %else %do;
            data _null_;
               file "%FileWorkIt(&basemeta&_slash_.&temp.SUPPIDVAR.txt)";

            run;         
         %end;
      %end;      
      %let i = %eval(&i+1);
   %end;

   *** apply blind and merge in DM and DMSupp variables ***;
   %if (%length(&adslpresent) and &ADSLBlind) or (^%length(&adslpresent) and &DMBlind) %then %let BlindedStudy = 1;
   %else %let BlindedStudy = 0;  
   
   %let DropBlind =;
   
   %let _tid_ = %sysfunc(open(&in_adsl));
      %let usubjvn = %sysfunc(varnum(&_tid_,USUBJID));
      %let SubjectLabel = %sysfunc(varlabel(&_tid_,&usubjvn));
      %if ^%length(%trim(&SubjectLabel)) %then %let SubjectLabel = USUBJID;      
      %let armchk = %sysfunc(varnum(&_tid_,ARM));
      %let pchk = %sysfunc(varnum(&_tid_,TRT01P));
      %let achk = %sysfunc(varnum(&_tid_,TRT01A));
      %let actchk = %sysfunc(varnum(&_tid_,ACTARM));
   %let _tid_ = %sysfunc(close(&_tid_));

   %if &BlindedStudy %then %do;
      %if &armchk %then %let DropBlind = &DropBlind ARM;
      %if &pchk %then %let DropBlind = &DropBlind TRT01P;
      %if &achk %then %let DropBlind = &DropBlind TRT01A;
      %if &actchk %then %let DropBlind = &DropBlind ACTARM;
      %if %length(&adslpresent) %then %let ADSLVAR = &ADSLVAR ARM;
      %else %let DMVariables = &DMVariables ARM; 
   %end;   

   %if %upcase(&in_adsl) = ADAM.ADSL %then %do;   
      %if ^%sysfunc(exist(&in_adsl)) %then %do;
         %let inDompath=%sysfunc(pathname(%scan(&in_adsl, 1, ".")));
         %let inDompath=&inDompath.\;
         %put &inDompath;
         %if %sysfunc(fileexist(&inDompath.ADSL.xpt)) %then %do;
            %XPTtoSASFile(ADSL.xpt,&inDompath);
            %let in_tadsl = adsl;
         %end;
      %end;
      %else %let in_tadsl = &in_adsl;
      
      %if %sysfunc(findw(%upcase(&domains), DM)) %then %do;
         %if %upcase(%scan(&in_dm, 1, ".")) = ADAM %then %let DMData = ADDM;
         %else %let DMData = DM;         

         %if ^%sysfunc(exist(&in_dm)) %then %do;
            %let inDompath=%sysfunc(pathname(%scan(&in_dm, 1, ".")));
            %let inDompath=&inDompath.\;
            %put inDompath=&inDompath;
            %if %sysfunc(fileexist(&inDompath.&DMData..xpt)) %then %do;
               %XPTtoSASFile(&DMData..xpt,&inDompath);
               %let in_tdm = &DMData;
            %end;
         %end;
         %else %let in_tdm = &in_dm;   

         %let DropBlindDM =;
            
         %if &BlindedStudy %then %do;
            %let _tid_ = %sysfunc(open(&in_tdm));
               %let armchkdm = %sysfunc(varnum(&_tid_,ARM));
               %let pchkdm = %sysfunc(varnum(&_tid_,TRT01P));
               %let achkdm = %sysfunc(varnum(&_tid_,TRT01A));
               %let actchkdm = %sysfunc(varnum(&_tid_,ACTARM));
            %let _tid_ = %sysfunc(close(&_tid_));
            
            %if &armchkdm %then %let DropBlindDM = &DropBlindDM ARM;
            %if &pchkdm %then %let DropBlindDM = &DropBlindDM TRT01P;
            %if &achkdm %then %let DropBlindDM = &DropBlindDM TRT01A;
            %if &actchkdm %then %let DropBlindDM = &DropBlindDM ACTARM;
            
            %if ^&armchkdm %then %do;
               %let DMVariables = &DMVariables ARM;
            %end;            
         %end;          
  
         *** SUPP if SDTM.DM ***;         
         %if &DMData = DM and %sysfunc(findw(%upcase(&suppdomains), SUPPDM)) %then %do;
            %let j = 1;
            %do %while(%length(%scan(&DMSUPPIDVAR,&j,' ')));
               %let idvartemp = %scan(&DMSUPPIDVAR,&j,' ');

               %if &j = 1 %then %let mergedata = &in_tdm;
               %else %let mergedata = &DMData;

               %if &idvartemp ne MISSING %then %do;
                  %let _tid_ = %sysfunc(open(&mergedata));
                     %let vnum = %sysfunc(varnum(&_tid_,&idvartemp));
                     %let idlab = %sysfunc(varlabel(&_tid_,&vnum));
                  %let _tid_ = %sysfunc(close(&_tid_));
               %end;

               %if &idvartemp = MISSING %then %do;
                  proc sql noprint;
                     create table &DMData.2(drop = USUBJID1 USUBJID2) as
                     select coalesce(aa.USUBJID1, bb.USUBJID2) as USUBJID label = "&SubjectLabel", aa.*, bb.*
                     %if &BlindedStudy %then %do; , "&trBlindedTreatment" as ARM length = %length(&trBlindedTreatment) label = "&trDescriptionofPlannedArm" %end;
                     from &mergedata(rename=(USUBJID = USUBJID1) %if &BlindedStudy %then drop=&DropBlindDM;) as aa
                     left join %DataWorkIt(suppmeta.tsuppdm_)(rename=(USUBJID = USUBJID2)) as bb
                     on aa.USUBJID1 = bb.USUBJID2;
                  quit;
               %end;
               %else %do;
                  proc sql noprint;
                     create table &DMData.2(drop = USUBJID1 USUBJID2 &idvartemp.1 &idvartemp.2) as
                     select coalesce(aa.USUBJID1, bb.USUBJID2) as USUBJID label = "&SubjectLabel", coalesce(aa.&idvartemp.1, bb.&idvartemp.2) as &idvartemp label = "&idlab", aa.*, bb.* 
                     %if &BlindedStudy %then %do; , "&trBlindedTreatment" as ARM length = %length(&trBlindedTreatment) label = "&trDescriptionofPlannedArm" %end;
                     from &mergedata(rename=(USUBJID = USUBJID1 &idvartemp = &idvartemp.1) %if &BlindedStudy %then drop=&DropBlindDM;) as aa
                     left join %DataWorkIt(suppmeta.tsuppdm_&idvartemp)(rename=(USUBJID = USUBJID2 &idvartemp = &idvartemp.2)) as bb
                     on aa.USUBJID1 = bb.USUBJID2 and aa.&idvartemp.1 = bb.&idvartemp.2;
                  quit;
               %end;

               proc datasets nolist;
                  delete &DMData;
                  change &DMData.2 = &DMData;
               quit;                 

               %let j = %eval(&j+1);
            %end;
         %end;
         %else %let DMData=&in_tdm;
       
         %if &DMData = DM and %sysfunc(findw(%upcase(&suppdomains), SUPPDM)) %then %let DMVariables = &DMVariables &DMSUPPVARS;
         %else %let DMVariables = &DMVariables;

         *** determine additional variables to keep ***;         
         %let DMXtra =;
         %let _i_ = 1;
         %do %while(%length(%scan(&DMVariables,&_i_," ")));
            %let DMtemp=%scan(&DMVariables,&_i_," ");
            %if ^%sysfunc(findw(&ADSLVAR, &DMtemp)) %then %do;
               %if &BlindedStudy %then %do;
                  %if ^%sysfunc(findw(&DropBlindDM, &DMtemp)) %then %do;
                     %let DMXtra = &DMXtra &DMtemp;
                  %end;
               %end;
               %else %let DMXtra = &DMXtra &DMtemp;
            %end;
            %let _i_ = %eval(&_i_+1);
         %end;         

         %if %length(&DMXtra) %then %do;
            proc sql noprint;
               create table %DataWorkIt(derimeta.tadsl)(drop = USUBJID1 USUBJID2) as
               select coalesce(aa.USUBJID1, bb.USUBJID2) as USUBJID label = "&SubjectLabel", aa.*, bb.*
               %if &BlindedStudy %then %do; , "&trBlindedTreatment" as ARM length = %length(&trBlindedTreatment) label = "&trDescriptionofPlannedArm" %end;
               from &in_tadsl(rename=(USUBJID = USUBJID1) %if &BlindedStudy %then drop=&DropBlind;) as aa               
               left join &DMData(keep = USUBJID &DMXtra rename=(USUBJID = USUBJID2)) as bb
               on aa.USUBJID1 = bb.USUBJID2
               order by usubjid;
            quit;
            
            %let ADSLVAR = &ADSLVAR &DMXtra;                        
         %end;
         %else %do;         
            proc sql noprint;
               create table %DataWorkIt(derimeta.tadsl) as
               select aa.*
               %if &BlindedStudy %then %do; , "&trBlindedTreatment" as ARM length = %length(&trBlindedTreatment) label = "&trDescriptionofPlannedArm" %end;
               from &in_tadsl(%if &BlindedStudy %then drop=&DropBlind;) as aa               
               order by usubjid;
            quit;            
         %end;                           
      %end;
      %else %do;
         proc sql noprint;
            create table %DataWorkIt(derimeta.tadsl) as
            select aa.*
            %if &BlindedStudy %then %do; , "&trBlindedTreatment" as ARM length = %length(&trBlindedTreatment) label = "&trDescriptionofPlannedArm" %end;
            from &in_tadsl(%if &BlindedStudy %then drop=&DropBlind;) as aa               
            order by usubjid;
         quit;            
      %end;   
   %end;
   %else %do;
      %if %upcase(%scan(&in_adsl, 1, ".")) = ADAM %then %let DMData = ADDM;
      %else %let DMData = DM;

      %if ^%sysfunc(exist(&in_adsl)) %then %do;
         %let inDompath=%sysfunc(pathname(%scan(&in_adsl, 1, ".")));
         %let inDompath=&inDompath.\;
         %put &inDompath;
         %if %sysfunc(fileexist(&inDompath.&DMData..xpt)) %then %do;
            %XPTtoSASFile(&DMData..xpt,&inDompath);
            %let in_tdm = &DMData;
         %end;
      %end;  
      %else %let in_tdm=&in_adsl;
   
      %if (&DMData = ADDM) or (&DMData = DM and ^%sysfunc(findw(%upcase(&suppdomains), SUPPDM))) %then %do;
         proc sql noprint;
            create table %DataWorkIt(derimeta.tadsl) as
            select aa.*
            %if &BlindedStudy %then %do; , "&trBlindedTreatment" as ARM length = %length(&trBlindedTreatment) label = "&trDescriptionofPlannedArm" %end;
            from &in_tdm(%if &BlindedStudy %then drop=&DropBlind;) as aa               
            order by usubjid;
         quit;         
      %end;     
      %else %if &DMData = DM and %sysfunc(findw(%upcase(&suppdomains), SUPPDM)) %then %do;        
         %let j = 1;
         %do %while(%length(%scan(&DMSUPPIDVAR,&j,' ')));
            %let idvartemp = %scan(&DMSUPPIDVAR,&j,' ');

            %if &j = 1 %then %let mergedata = &in_tdm;
            %else %let mergedata = &DMData;

            %if &idvartemp ne MISSING %then %do;
               %let _tid_ = %sysfunc(open(&mergedata));
                  %let vnum = %sysfunc(varnum(&_tid_,&idvartemp));
                  %let idlab = %sysfunc(varlabel(&_tid_,&vnum));
               %let _tid_ = %sysfunc(close(&_tid_));
            %end;

            %if &idvartemp = MISSING %then %do;
               proc sql noprint;
                  create table &DMData.2(drop = USUBJID1 USUBJID2) as
                  select coalesce(aa.USUBJID1, bb.USUBJID2) as USUBJID label = "&SubjectLabel", aa.*, bb.*
                  %if &BlindedStudy %then %do; , "&trBlindedTreatment" as ARM length = %length(&trBlindedTreatment) label = "&trDescriptionofPlannedArm" %end;
                  from &mergedata(rename=(USUBJID = USUBJID1) %if &BlindedStudy %then drop=&DropBlind;) as aa
                  left join %DataWorkIt(suppmeta.tsuppdm_)(rename=(USUBJID = USUBJID2)) as bb
                  on aa.USUBJID1 = bb.USUBJID2
                  order by usubjid;
               quit;
            %end;
            %else %do;
               proc sql noprint;
                  create table &DMData.2(drop = USUBJID1 USUBJID2 &idvartemp.1 &idvartemp.2) as
                  select coalesce(aa.USUBJID1, bb.USUBJID2) as USUBJID label = "&SubjectLabel", coalesce(aa.&idvartemp.1, bb.&idvartemp.2) as &idvartemp label = "&idlab", aa.*, bb.* 
                  %if &BlindedStudy %then %do; , "&trBlindedTreatment" as ARM length = %length(&trBlindedTreatment) label = "&trDescriptionofPlannedArm" %end;
                  from &mergedata(rename=(USUBJID = USUBJID1 &idvartemp = &idvartemp.1) %if &BlindedStudy %then drop=&DropBlind;) as aa
                  left join %DataWorkIt(suppmeta.tsuppdm_&idvartemp)(rename=(USUBJID = USUBJID2 &idvartemp = &idvartemp.2)) as bb
                  on aa.USUBJID1 = bb.USUBJID2 and aa.&idvartemp.1 = bb.&idvartemp.2
                  order by usubjid;
               quit;
            %end;

            proc datasets nolist;
               delete &DMData;
               change &DMData.2 = &DMData;
            quit;                 

            %let j = %eval(&j+1);               
         %end;

         data %DataWorkIt(derimeta.tadsl);
            set &DMData;
         run;                        
      %end;
      
      %if &DMData = DM and %sysfunc(findw(%upcase(&suppdomains), SUPPDM)) %then %let DMVariables = &DMVariables &DMSUPPVARS;
      %else %let DMVariables = &DMVariables;
      
      %let ADSLVAR = &DMVariables;      
   %end;
 
   %global ADSLVARS;
   %let ADSLVARS = &ADSLVAR;
   data _null_;
      file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
      put "%nrstr(%global) ADSLVARS;";
      put "%nrstr(%let) %sysfunc(trim(ADSLVARS = %upcase(&ADSLVAR)));";
   run;

   %let _tid_ = %sysfunc(open(%DataWorkIt(derimeta.TADSL)));
      %let vn = %sysfunc(varnum(&_tid_,country));
   %let _tid_ = %sysfunc(close(&_tid_));        

   *** builds cumulative list of countries for weekdays and holidays ***;
   %if &vn %then %do;
      proc sort data = %DataWorkIt(derimeta.TADSL)(keep = country where = (country ne "")) nodupkey out = countries;
         by country;
      run;
            
      %if &Server = Local %then %do;
         %let CPath = &USER_HOME.RBM/;
      %end;
      %else %do;
         %let CPath = &MetaPath.RBM/;
      %end;
      libname CPath "&CPath";
      %if %sysfunc(fileexist(&CPath.countries.sas7bdat)) %then %do;
         %let _tid_ = %sysfunc(open(CPath.countries));
            %let vn = %sysfunc(varnum(&_tid_,Country));
            %let CLen0 = %sysfunc(varlength(&_tid_,&vn));
         %let _tid_ = %sysfunc(close(&_tid_));
         %let _tid_ = %sysfunc(open(countries));
            %let vn = %sysfunc(varnum(&_tid_,Country));
            %let CLen1 = %sysfunc(varlength(&_tid_,&vn));
         %let _tid_ = %sysfunc(close(&_tid_));                                             
         
         data countries;
            length Country $ %sysfunc(max(&CLen0,&CLen1));
            set CPath.countries countries;
         run;                    

         proc sort data = countries nodupkey out = CPath.countries;
            by country;
         run;
         %if &syserr >4 %then %do;
         	%let exiterror =1;
         	%goto mdoexit;
         %end;

         proc datasets nolist;
            delete countries;
         quit;

      %end;
      %else %do;
         data CPath.countries;
            set countries;
         run;
         %if &syserr >4 %then %do;
				%let exiterror =1;
			  	%goto mdoexit;
         %end;
          
         proc datasets nolist;
            delete countries;
         quit;
      %end;
   %end; 

   %put [AddStudyLocal_~METADATAOUTFILES Create Character Numeric Findings Domains~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.75];

   *** Create separate findings domain for character and numeric ***;
   %global findingsdomainsnum findingsdomainschar;
   %let findingsdomainsnum = ;
   %let findingsdomainschar = ;
   %let i = 1;   
   %do %while(%length(%scan(&findingsdomains,&i," ")));
      %let temp = %scan(&findingsdomains,&i," ");
      %if %sysfunc(findw(%upcase(&bdsdomains), &temp)) %then %do;
         %if %index(&&&temp.VARS,AVAL) %then %let findingsdomainsnum = &findingsdomainsnum &temp;
         %if %index(&&&temp.VARS,AVALC) and ^%index(&&&temp.VARS,AVAL) %then %let findingsdomainschar = &findingsdomainschar &temp;      
      %end;
      %else %do;
         %if %index(&&&temp.VARS,&temp.STRESN) %then %let findingsdomainsnum = &findingsdomainsnum &temp;
         %if %index(&&&temp.VARS,&temp.STRESC) and ^%index(&&&temp.VARS,&temp.STRESN) %then %let findingsdomainschar = &findingsdomainschar &temp;
      %end;
      %let i = %eval(&i+1);
   %end;
   
   %if %length(&findingsdomainschar) %then %do;
      data findingschar;
         length domain $ 8 table $ 8;
         %let i = 1;
         %do %while(%length(%scan(&findingsdomainschar,&i,' ')));
            %let temp = %scan(%upcase(&findingsdomainschar),&i," ");
            domain = "&temp"; 
            output;
            %let i = %eval(&i+1);
         %end;
      run;
      
      data _null_;
         merge findingschar(in = ina) findings2(drop = table);
         by domain;
         if ina;
         file "%FileWorkIt(&basemeta&_slash_.FINDINGSCHAR.txt)" delimiter = "~" encoding="utf-8";
         put domain label;
      run;  
   %end;
   
   %if %length(&findingsdomainsnum) %then %do;
      data findingsnum;
         length domain $ 8 table $ 8;
         %let i = 1;
         %do %while(%length(%scan(&findingsdomainsnum,&i,' ')));
            %let temp = %scan(%upcase(&findingsdomainsnum),&i," ");
            domain = "&temp"; 
            output;
            %let i = %eval(&i+1);
         %end;
      run;

      data _null_;
         merge findingsnum(in = ina) findings2(drop = table);
         by domain;
         if ina;
         file "%FileWorkIt(&basemeta&_slash_.FINDINGSNUM.txt)" delimiter = "~";
         put domain label;
      run;
   %end;

   %if &cdiscmodel = SEND %then %do;
      %let pooliddomains =;
      %let i = 1;   
      %do %while(%length(%scan(&findingsdomains,&i,' ')));
         %let temp = %scan(%upcase(&findingsdomains),&i," ");
         %if %index(&&&temp.VARS,POOLID) %then %let pooliddomains = &pooliddomains &temp;
         %let i = %eval(&i+1);
      %end;
   %end;
   
   data _null_;
      file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
      put "%nrstr(%global) findingsdomainsnum findingsdomainschar;";
      put "%nrstr(%let) findingsdomainsnum = &findingsdomainsnum;";
      put "%nrstr(%let) findingsdomainschar = &findingsdomainschar;";
      %if &cdiscmodel = SEND %then %do;
         put "%nrstr(%let) pooliddomains = &pooliddomains;";
      %end;
   run;
   
   %put Entering METANOTES;
   %ClockStart(METANOTES); 

   %MAKENOTES;
   
   %put Exiting METANOTES;
   %ClockStop(METANOTES);
   
   %if &exiterror %then %goto mdoexit;
      
   proc datasets nolist;
      delete findings2 findingschar findingsnum;
   quit;

   %put Entering METATRT;
   %ClockStart(METATRT); 
   
   *** Create Treatment Macro Vars and Data Sets ***;
   %let TRTLIST = ;
   %let TRTLISTQ = ;

   %if ^&ADSLBlind %then %do;
      %if %sysfunc(findw(%upcase(&ADSLVARS), ARM)) %then %do;
         %let TRTLIST = &TRTLIST ARM;
         %let TRTLISTQ = &TRTLISTQ "ARM";
      %end;
      %if %sysfunc(findw(%upcase(&ADSLVARS), ACTARM)) %then %do;
         %let TRTLIST = &TRTLIST ACTARM;
         %if ^%sysfunc(findw(%upcase(&ADSLVARS), ARM)) %then %do;
            %let TRTLISTQ = "ACTARM";
         %end;
         %else %do;
            %let TRTLISTQ = &TRTLISTQ ,"ACTARM";
         %end;
      %end;
      %let i = 1;
      %let trtflg = 0;
      %do %while(&trtflg = 0);
         %if %index(&ADSLVARS, TRT0&i.P) > 0 %then %do;
            %let TRTLIST = &TRTLIST TRT0&i.P;
            %if ^%sysfunc(findw(%upcase(&ADSLVARS), ARM)) and ^%sysfunc(findw(%upcase(&ADSLVARS), ACTARM)) %then %do;
               %let TRTLISTQ = "TRT0&i.P";
            %end;
            %else %do;
               %let TRTLISTQ = &TRTLISTQ ,"TRT0&i.P";
            %end;
         %end;
         %else %let trtflg = 1;
         %let i = %eval(&i+1);
      %end;
      %let i = 1;
      %let trtflg = 0;
      %do %while(&trtflg = 0);
         %if %index(&ADSLVARS, TRT0&i.A) > 0 %then %do;
            %let TRTLIST = &TRTLIST TRT0&i.A;
            %let TRTLISTQ = &TRTLISTQ ,"TRT0&i.A";
         %end;
         %else %let trtflg = 1;
         %let i = %eval(&i+1);
      %end;  

      %let i = 1;
      %do %while(%length(%scan(&TRTLIST,&i," ")));
         %let temp = %scan(&TRTLIST,&i," ");
         %let &temp.CDS = ;
         %GetLevels(%DataWorkIt(derimeta.TADSL),&temp,&temp.CDS,_nLvls=sqlobs,_vType=vtype,_dropmiss = 1,_delim = %str(~),_outtab = &temp.CDS);
         %let i = %eval(&i+1);
      %end;
   %end;
   %else %if &ADSLBlind %then %do;
      %let TRTLIST = &TRTLIST ARM;
      %let TRTLISTQ = &TRTLISTQ "ARM";      
      %let ARMCDS = &trBlindedTreatment;            
   %end;
   
   %put [AddStudyLocal_~METADATAOUTFILES Text File of Treatment Variables~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.80];

   *** Text File of Treatment Variables ***;
   %if %length(&TRTLISTQ) and ^&ADSLBlind %then %do;      
      proc contents noprint data = %DataWorkIt(derimeta.tadsl) out = treatvars(keep = name label);
      run;
      
      %put [AddStudyLocal_~METADATAOUTFILES Text File of Treatment Variables Not ADSLBlind~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.81];
      
      data treatvars;
         set treatvars;
         where upcase(name) in ("ARM","ARMCD","ACTARM","ACTARMCD") or 
               (substr(name,1,3) = "TRT" and substr(name,6,1) in ("A","P")) or
                substr(name,1,6) = "TRTSEQ" or
               (substr(name,1,2) = "TR" and substr(name,5,2) in ("AG","PG"));
      run;
         
      data _null_;
         set treatvars;
         file "%FileWorkIt(&basemeta&_slash_.TREATVARS.txt)" delimiter = "~" encoding="utf-8";
         put name label;
         where upcase(name) in (&TRTLISTQ);
      run;
   %end;
   %else %if &ADSLBlind %then %do;   
   	data TREATVARS;
   		name ="&trDescriptionofPlannedArm";
   	run;
      data _null_;
         file "%FileWorkIt(&basemeta&_slash_.TREATVARS.txt)" delimiter = "~" encoding="utf-8";
         put "ARM~&trDescriptionofPlannedArm";
      run;  
   %end;
   %else %do;
      data treatvars;

      run;
   
      data _null_;
         set treatvars;
         file "%FileWorkIt(&basemeta&_slash_.TREATVARS.txt)" delimiter = "~" encoding="utf-8";
      run;  
   %end;
   
   %put [AddStudyLocal_~METADATAOUTFILES Text File of Treatment Values~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.82];   
   
   *** Create TXT files of Treatment Values ***;   
   %if ^&ADSLBlind %then %do;
      %let i = 1;
      %do %while(%length(%scan(&TRTLIST,&i,' ')));
         %let temp = %scan(&TRTLIST,&i,' ');
         data _null_;
            set &temp.CDS;
            file "%FileWorkIt(&basemeta&_slash_.&temp.CDS.txt)" delimiter = "~" encoding="utf-8";
            put &temp;
         run;
         %let i = %eval(&i+1); 
      %end;
   %end;
   %else %do;
      data _null_;
         file "%FileWorkIt(&basemeta&_slash_.ARMCDS.txt)" delimiter = "~" encoding="utf-8";
         put "&trBlindedTreatment";
      run;   
   %end;
   
   %put [AddStudyLocal_~METADATAOUTFILES CSTMacroVars TRTLIST~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.83];   
   
   data _null_;
      file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
      put "%nrstr(%global) TRTLIST;";
      put "%nrstr(%let) TRTLIST = &TRTLIST;";
      %let i = 1;
      %do %while(%length(%scan(&TRTLIST,&i," ")));
         %let temp = %scan(&TRTLIST,&i," ");
         put "%nrstr(%global) &temp.CDS;";
         put "%nrstr(%let) &temp.CDS = %nrstr(%nrbquote)(%nrbquote(&&&temp.CDS));";
         %let i = %eval(&i+1);                 
      %end;
   run;

   %put Exiting METATRT;
   %ClockStop(METATRT); 

   %put Entering METAPOPS;
   %ClockStart(METAPOPS); 
  
   *** Create Treatment Macro Vars and Data Sets ***;
   %let POPLISTQ = All Subjects Excluding Screen Failures~All Subjects;
   %let POPLISTVAR = ;

   *** Full Set ***;
   %if %sysfunc(findw(%upcase(&ADSLVARS), FASFL)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Full Analysis Set;
      %let POPLISTVAR = &POPLISTVAR FASFL;
   %end;
   %else %if %sysfunc(findw(%upcase(&ADSLVARS), FULLSET)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Full Analysis Set;
      %let POPLISTVAR = &POPLISTVAR FULLSET;
   %end;
   
   *** Safety ***;
   %if %sysfunc(findw(%upcase(&ADSLVARS), SAFFL))  %then %do;
      %let POPLISTQ = &POPLISTQ ~Safety;
      %let POPLISTVAR = &POPLISTVAR SAFFL;
   %end;
   %else %if %sysfunc(findw(%upcase(&ADSLVARS), SAFETY)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Safety;
      %let POPLISTVAR = &POPLISTVAR SAFETY;
   %end; 

   *** ITT ***;
   %if %sysfunc(findw(%upcase(&ADSLVARS), ITTFL)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Intent-to-Treat;
      %let POPLISTVAR = &POPLISTVAR ITTFL;
   %end;
   %else %if %sysfunc(findw(%upcase(&ADSLVARS), ITT)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Intent-to-Treat;
      %let POPLISTVAR = &POPLISTVAR ITT;
   %end;
   
   *** PPROT ***;
   %if %sysfunc(findw(%upcase(&ADSLVARS), PPROTFL)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Per-Protocol;
      %let POPLISTVAR = &POPLISTVAR PPROTFL;
   %end;
   %else %if %sysfunc(findw(%upcase(&ADSLVARS), PPROT)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Per-Protocol;
      %let POPLISTVAR = &POPLISTVAR PPROT;
   %end; 
   
   *** Completer ***;
   %if %sysfunc(findw(%upcase(&ADSLVARS), COMPLFL)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Completers;
      %let POPLISTVAR = &POPLISTVAR COMPLFL;
   %end;
   %else %if %sysfunc(findw(%upcase(&ADSLVARS), COMPFL)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Completers;
      %let POPLISTVAR = &POPLISTVAR COMPFL;
   %end;
   %else %if %sysfunc(findw(%upcase(&ADSLVARS), COMPLT)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Completers;
      %let POPLISTVAR = &POPLISTVAR COMPLT;
   %end;    
   %else %if %sysfunc(findw(%upcase(&ADSLVARS), COMPLETED)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Completers;
      %let POPLISTVAR = &POPLISTVAR COMPLETED;
   %end; 

   *** Randomized ***;
   %if %sysfunc(findw(%upcase(&ADSLVARS), RANDFL)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Randomized;
      %let POPLISTVAR = &POPLISTVAR RANDFL;
   %end;
   %else %if %sysfunc(findw(%upcase(&ADSLVARS), RAND)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Randomized;
      %let POPLISTVAR = &POPLISTVAR RAND;
   %end;
   %else %if %sysfunc(findw(%upcase(&ADSLVARS), RANDOMIZED)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Randomized;
      %let POPLISTVAR = &POPLISTVAR RANDOMIZED;
   %end; 
   %else %if %sysfunc(findw(%upcase(&ADSLVARS), RANDOM)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Randomized;
      %let POPLISTVAR = &POPLISTVAR RANDOM;
   %end;    

   *** Enrolled ***;
   %if %sysfunc(findw(%upcase(&ADSLVARS), ENRLFL)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Enrolled;
      %let POPLISTVAR = &POPLISTVAR ENRLFL;
   %end;
   %else %if %sysfunc(findw(%upcase(&ADSLVARS), ENRL)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Enrolled;
      %let POPLISTVAR = &POPLISTVAR ENRL;
   %end;
   %else %if %sysfunc(findw(%upcase(&ADSLVARS), ENROLLED)) %then %do;
      %let POPLISTQ = &POPLISTQ ~Enrolled;
      %let POPLISTVAR = &POPLISTVAR ENROLLED;
   %end;
   
   %put [AddStudyLocal_~METADATAOUTFILES POPDATA~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.85];
   
   data popdata;
      length varname $ 8 populate $ 38;
      %let i = 1;
      %do %while(%length(%scan(&POPLISTQ,&i,'~')));
         %let temp = %scan(&POPLISTQ,&i,"~");
         varname = cats("FakeVar","&i");
         populate = "&temp";
         output;
        %let i = %eval(&i+1);
      %end; 
   run;
      
   *** Text File of Population Variables ***;
   data _null_;
      set popdata;
      file "%FileWorkIt(&basemeta&_slash_.POPVARS.txt)" delimiter = "~" encoding="utf-8";
      put varname populate;
   run;
   
   proc datasets nolist;
      delete popdata;
   quit;
   
   data _null_;
      file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
      put "%nrstr(%global) poplistvar;";
      put "%nrstr(%let) poplistvar = &poplistvar;";
   run;  

   %put Exiting METAPOPS;
   %ClockStop(METAPOPS); 

   %put Entering METAMEDDRA;
   %ClockStart(METAMEDDRA); 

   *** MedDRA codes ***;

   %let i = 1;
   %do %while(%length(%scan(&MedDRAdomains,&i," ")));      
      %let temp = %scan(&MedDRAdomains,&i," ");  
      %let tempsub = %substr(&temp,1,2);
      %if %sysfunc(findw(%upcase(&domains), &temp)) %then %do;      
         %let temppath = %scan(&&in_&temp, 1, %str(.));
         %let temptab = %scan(&&in_&temp, 2, %str(.));
         %if %upcase(&temppath) = SDTM and %sysfunc(findw(%upcase(&suppdomains), SUPP&temp)) %then %let chksupp = 1;
         %else %let chksupp = 0;
                  
         proc sort data = %DataWorkIt(&temppath.meta.source_columns)(where = (upcase(table) = "&temptab")) nodupkey out = &temp.MEDDRA;
            by column label;
         run;
         
         %let _tid_ = %sysfunc(open(&temp.MEDDRA));
         %let labelfl = %sysfunc(varnum(&_tid_,label));
         %if &labelfl %then %let len1 = %sysfunc(varlength(&_tid_,&labelfl));
         %else %let len1 = 8;
         %let _tid_ = %sysfunc(close(&_tid_));

         data &temp.MEDDRA;
            %if ^&labelfl %then %do; length label $ &len1; %end;
            set &temp.MEDDRA;
            where upcase(column) in ("&temp.TERM","&temp.LLT","&temp.DECOD","&temp.BODSYS","&temp.SOC","&temp.HLT","&temp.HLGT","&temp.MODIFY","&temp.CAT",
            "&temp.SCAT","&temp.CLAS","&temp.TRT");
            %if ^&labelfl %then %do; label = "";  %end;
            if label = "" then label = column;
         run;

         %if &chksupp %then %do;
            %let _tid_ = %sysfunc(open(sdtm.SUPP&temp));
            %let qnamfl = %sysfunc(varnum(&_tid_,qnam));
            %let qlabelfl = %sysfunc(varnum(&_tid_,qlabel));
            %let _tid_ = %sysfunc(close(&_tid_));
            
            %if &qnamfl and &qlabelfl %then %do;
               proc sort data = sdtm.SUPP&temp(keep = qnam qlabel where = (upcase(qnam) in ("&temp.TERM","&temp.LLT","&temp.DECOD","&temp.BODSYS","&temp.SOC","&temp.HLT","&temp.HLGT","&temp.MODIFY","&temp.CAT",
                         "&temp.SCAT","&temp.CLAS","&temp.TRT","TERM","LLT","DECOD","BODSYS","SOC","HLT","HLGT","CAT","MODIFY","SCAT","CLAS","TRT" )))
                         nodupkey out = &temp.MEDDRASUPP;
                  by qnam qlabel;
               run;

               %NObsVars(&temp.MEDDRASUPP);

               %if &nobs %then %do;
                  data &temp.MEDDRASUPP(rename = (qnam = column));
                     set &temp.MEDDRASUPP;
                     by qnam;
                     if substr(upcase(qnam),1,2) ne "%upcase(&temp)" then qnam = cats("%upcase(&temp)",qnam);
                     label = trim(qlabel);
                     drop qlabel;
                     if label = "" then label = qnam;
                     if first.qnam;
                  run;

                  %let _tid_ = %sysfunc(open(&temp.MEDDRASUPP));
                  %let labelfl = %sysfunc(varnum(&_tid_,label));
                  %let len2 = %sysfunc(varlength(&_tid_,&labelfl));
                  %let _tid_ = %sysfunc(close(&_tid_));
                  %let labellength = %sysfunc(max(&len1,&len2));

                  *** only get new ones from SUPP ***;
                  proc sort data =&temp.MEDDRA;
                  	by column;
                  run;
                  proc sort data =&temp.MEDDRASUPP;
						 	by column;
                  run;
                  data &temp.MEDDRASUPP;
                     length column $ 8 label $ &labellength;
                     merge &temp.MEDDRA(in = ina) &temp.MEDDRASUPP(in = inb);
                     by column;
                     if inb and not ina;
                  run;

                  data &temp.MEDDRA;
                     length column $ 8 label $ &labellength;
                     set &temp.MEDDRA &temp.MEDDRASUPP;
                  run;

                  proc sort data = &temp.MEDDRA;
                     by column;
                  run;

                  proc datasets nolist;
                     delete &temp.MEDDRASUPP;
                  quit;
               %end;
            %end;                                         
         %end;

         data _null_;
            set &temp.MEDDRA;
            file "%FileWorkIt(&basemeta&_slash_.&temp.MEDDRA.txt)" delimiter = "~" encoding="utf-8";
            put column label;
         run;     

         proc datasets nolist;
            delete &temp.MEDDRA;
         quit;
      %end;
      %let i = %eval(&i+1);
   %end;

   %put Exiting METAMEDDRA;
   %ClockStop(METAMEDDRA); 
   
   %put [AddStudyLocal_~METADATAOUTFILES METAIT Definition~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.86];   
      
   %macro METAIT(domain =, vars = , flag = 1);
      %let EPOCH =;
      %let VISITNUM =;
      %let VISIT =;
      %let TESTCD =;
      %let TEST =;
      %let PARAMCD =;
      %let PARAM =;
      %let NRIND =;
      %let PARCAT1 =;
      %let ssubdomain = %substr(%upcase(&domain),1,1);
      %let subdomain = %substr(%upcase(&domain),1,2);
      %if &flag %then %do;
         %let j = 1;
         %let newvars =;
         %do %while(%length(%scan(&vars,&j," ")));
            %let tempvar = %scan(&vars,&j," ");
            %if %sysfunc(findw(%upcase(&&&domain.VARS), &ssubdomain.%upcase(&tempvar))) %then %let newvars = &newvars &ssubdomain.%scan(&vars,&j," ");
            %else %if %sysfunc(findw(%upcase(&&&domain.VARS), &subdomain.%upcase(&tempvar))) %then %let newvars = &newvars &subdomain.%scan(&vars,&j," ");
            %let j = %eval(&j+1);
         %end;
      %end;
      %else %do;
         %let j = 1;
         %let newvars =;
         %do %while(%length(%scan(&vars,&j," ")));
            %let tempvar = %scan(&vars,&j," ");  
            %if %sysfunc(findw(%upcase(&&&domain.VARS), %upcase(&tempvar))) %then %let newvars = &newvars %scan(&vars,&j," ");
            %let j = %eval(&j+1);
         %end;
      %end;
   
      %if %sysfunc(findw(%upcase(&&&domain.VARS), EPOCH)) %then %let EPOCH = EPOCH;
            
      %if %sysfunc(findw(%upcase(&findingsdomains), &domain)) and %sysfunc(findw(%upcase(&bdsdomains), &domain)) %then %do;
         %if %sysfunc(findw(%upcase(&&&domain.VARS), AVISITN)) %then %let VISITNUM = AVISITN;
         %if %sysfunc(findw(%upcase(&&&domain.VARS), AVISIT)) %then %let VISIT = AVISIT;         
         %if %sysfunc(findw(%upcase(&&&domain.VARS), PARAMCD)) %then %let PARAMCD = PARAMCD;
         %if %sysfunc(findw(%upcase(&&&domain.VARS), PARAM)) %then %let PARAM = PARAM;
         %if %sysfunc(findw(%upcase(&&&domain.VARS), &subdomain.NRIND)) %then %let NRIND = &subdomain.NRIND;
         %if %sysfunc(findw(%upcase(&&&domain.VARS), PARCAT1)) %then %let PARCAT1 = PARCAT1;
      %end;
      %else %if %sysfunc(findw(%upcase(&findingsdomains), &domain)) and ^%sysfunc(findw(%upcase(&bdsdomains), &domain)) %then %do;      
         %if %sysfunc(findw(%upcase(&&&domain.VARS), VISITNUM)) %then %let VISITNUM = VISITNUM;
         %if %sysfunc(findw(%upcase(&&&domain.VARS), VISIT)) %then %let VISIT = VISIT;
         %if %sysfunc(findw(%upcase(&&&domain.VARS), &subdomain.TESTCD)) %then %let TESTCD = &subdomain.TESTCD;
         %if %sysfunc(findw(%upcase(&&&domain.VARS), &subdomain.TEST)) %then %let TEST = &subdomain.TEST;
         %if %sysfunc(findw(%upcase(&&&domain.VARS), &subdomain.NRIND)) %then %let NRIND = &subdomain.NRIND;
      %end;
      
      %if &domain = ADSL and %length(&newvars &epoch &visitnum &visit) %then %do;
         proc sort data = %DataWorkIt(derimeta.tadsl)(keep = &newvars &epoch &visitnum &visit) nodupkey out = tadsl;
            by &newvars &epoch &visitnum &visit;
         run;
      %end;
      %else %if ^%sysfunc(findw(%upcase(&findingsdomains), &domain)) and %length(&newvars &epoch &visitnum &visit) %then %do;
         proc sort data = &&in_&domain(keep = &newvars &epoch &visitnum &visit) nodupkey out = &domain;
            by &newvars &epoch &visitnum &visit;
         run;
      %end;
      %else %if %sysfunc(findw(%upcase(&findingsdomains), &domain)) and %sysfunc(findw(%upcase(&bdsdomains), &domain)) and %length(&newvars &epoch &visitnum &visit &param &paramcd) %then %do;
         proc sort data = &&in_&domain(keep = &newvars &epoch &visitnum &visit &param &paramcd &nrind &PARCAT1) nodupkey out = &domain;
            by &newvars &epoch &visitnum &visit &param &paramcd;
         run;
      %end;
      %else %if %sysfunc(findw(%upcase(&findingsdomains), &domain)) and ^%sysfunc(findw(%upcase(&bdsdomains), &domain)) and %length(&newvars &epoch &visitnum &visit &test &testcd &nrind) %then %do;
         proc sort data = &&in_&domain(keep = &newvars &epoch &visitnum &visit &test &testcd &nrind) nodupkey out = &domain;
            by &newvars &epoch &visitnum &visit &test &testcd;
         run;
      %end;
                
      %let j = 1;   
      %do %while(%length(%scan(&newvars,&j," ")));         
         %let tempvar = %scan(&newvars,&j," "); 
         %let subtempvar = &domain.%substr(&tempvar,3);
         %if %sysfunc(findw(%upcase(&&&domain.VARS), %upcase(&tempvar))) %then %do;         
            %if (&domain ne EX) or (&domain = EX and ^&EXblind) or (&domain = EX and &EXblind and &tempvar ne EXTRT) %then %do;
               %if &domain = ADSL %then %do;
                  proc sort data = tadsl(keep = &tempvar where = (not missing(&tempvar))) nodupkey out = &tempvar;
                     by &tempvar;
                  run;
               %end;
               %else %do;
                  proc sort data = &domain(keep = &tempvar where = (not missing(&tempvar))) nodupkey out = &tempvar;
                     by &tempvar;
                  run;
               %end;
              
               %if &tempvar = STUDYID %then %do;
                  %let StudyList =;
                  %GetLevels(studyid,studyid,StudyList,_nLvls=nidvar,_vType=vtype,_dropmiss = 1,_delim = %str(~));

                  data _null_;
                     file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
                     put "%nrstr(%global) StudyList;";
                     put "%nrstr(%let) StudyList = %nrstr(%nrbquote)(%nrbquote(&StudyList));";
                  run;                  
               %end;
               
               data _null_;
                  set &tempvar;
                  file "%FileWorkIt(&basemeta&_slash_.&tempvar..txt)" delimiter = "~" encoding="utf-8";
                  put &tempvar;
               run;
               
               proc datasets nolist;
                  delete &tempvar;
               quit;
            %end;
         %end;
         %else %if (&domain = EX and &EXblind and &tempvar ne EXTRT) %then %do;
            data _null_;
               file "%FileWorkIt(&basemeta&_slash_.EXTRT.txt)" delimiter = "~" encoding="utf-8";
               put "&trBlindedTreatment";
            run;                        
         %end;         
         %let j = %eval(&j+1);
      %end;         
   %mend METAIT;

   %let findingsvars = CAT SCAT LOC METHOD POS SPEC TPT OBJ;
   %let eventsvars = TERM DECOD CAT SCAT LOC SER SEV ACN REL OUT TOXGR;
   %let interventionsvars = TRT DECOD CAT SCAT CLAS;
   %let dmadslvars = STUDYID USUBJID SITEID SEX RACE ETHNIC COUNTRY;
   
   *** gather metadata levels ***;
   %let i = 1;
   %do %while(%length(%scan(&domains &adslpresent,&i," ")));   
      %let temp = %scan(&domains &adslpresent,&i," "); 
   
      %let progressCurrent = %sysevalf(0.86 + %sysevalf(%sysevalf(%eval(&i - 1) / %sysfunc(countw(&domains &adslpresent, ' '))) * %sysevalf(0.88 - 0.86)));
      %put [AddStudyLocal_~METADATAOUTFILES Gather Metadata Levels &temp~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=&progressCurrent];         
      
      %if %sysfunc(findw(%upcase(&eventsdomains), &temp)) %then %do;
         %put Entering METAMETAEVENT;
         %ClockStart(METAMETAEVENT); 

         %METAIT(domain = &temp, vars = &eventsvars);
         %put Exiting METAMETAEVENT;
         %ClockStop(METAMETAEVENT); 
                  
      %end;
      %else %if %sysfunc(findw(%upcase(&interventionsdomains), &temp)) %then %do;
         %put Entering METAMETAINT;
         %ClockStart(METAMETAINT); 
         %METAIT(domain = &temp, vars = &interventionsvars);
         
         %put Exiting METAMETAINT;
         %ClockStop(METAMETAINT);          
      %end;      
      %else %if %sysfunc(findw(%upcase(&findingsdomains), &temp)) %then %do;
         %put Entering METAMETAFIND;
         %ClockStart(METAMETAFIND); 
         %METAIT(domain = &temp, vars = &findingsvars);
         %put Exiting METAMETAFIND;
         %ClockStop(METAMETAFIND);          
      %end; 
      
      *** PARCAT1 ***;
      %if %sysfunc(findw(%upcase(&bdsdomains), &temp)) %then %do;
      	%if %sysfunc(findw(%upcase(&&&temp.VARS), PARCAT1)) %then %do;
				proc sort data = &temp(keep = PARCAT1 where = (not missing(PARCAT1))) nodupkey out = PARCAT1;
					by PARCAT1;
				run;
      		data _null_;
					set PARCAT1;
               file "%FileWorkIt(&basemeta&_slash_.&temp.PARCAT1.txt)" delimiter = "~" encoding="utf-8";
					put PARCAT1;
				run;
                
				proc datasets nolist;
 					delete PARCAT1;
				quit;
			%end;
      %end;
      
      %let i = %eval(&i+1);
   %end;
      
   %put [AddStudyLocal_~METADATAOUTFILES Gather Metadata Levels ADSL~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.88];  

   %put Entering METAMETAADSL;
   %ClockStart(METAMETAADSL); 
  
   %METAIT(domain = ADSL, vars = &dmadslvars, flag = 0);
   %put Exiting METAMETAADSL;
   %ClockStop(METAMETAADSL); 
   
   %put [AddStudyLocal_~METADATAOUTFILES Findings By Groups~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.89];   
   
   %put Entering METABYGRP;
   %ClockStart(METABYGRP); 
      
   *** Findings By Groups ***;
   %let i = 1;
   %do %while(%length(%scan(&findingsdomains,&i," ")));      
      %let temp = %scan(&findingsdomains,&i," ");      
      %let temppath = %scan(&&in_&temp, 1, %str(.));
      %let temptab = %scan(&&in_&temp, 2, %str(.));
      %if &SpltDomainFlag %then %let temppath = %substr(&temppath, 1,4);
         proc sort data = %DataWorkIt(&temppath.meta.source_columns)(where = (upcase(table) = "&temptab")) nodupkey out = &temp.BYGRP;
            by column label;
         run;
         
         %let j = 1;
         %let quotedBYGRP =;
         %do %while(%length(%scan(&findingsvars,&j,' ')));
            %let tempbygrp = %scan(&findingsvars,&j," ");      
            %let quotedBYGRP = &quotedBYGRP "%substr(&temp,1,2)&tempbygrp";
            %let j = %eval(&j+1);
         %end;         
                           
         data _null_;
            set &temp.BYGRP;
            where column in (&quotedBYGRP);
            if missing(label) then label = column;
            file "%FileWorkIt(&basemeta&_slash_.&temp.BYGRP.txt)" delimiter = "~" encoding="utf-8";
            put column label;
         run;         
         
         proc datasets nolist;
            delete &temp.BYGRP;
         quit;                        
      %let i = %eval(&i+1);
   %end;        

   %put Exiting METABYGRP;
   %ClockStop(METABYGRP); 
      
   %put Entering METAEPOCH;
   %ClockStart(METAEPOCH); 
      
   *** EPOCH ***;
   %let i = 1;
   %let first = 0;
   %do %while(%length(%scan(&domains &adslpresent,&i," ")));
      %let temp = %scan(&domains &adslpresent,&i," ");
      %if %sysfunc(findw(%upcase(&&&temp.VARS), EPOCH)) %then %do;      
         %if %sysfunc(findw(%upcase(&eventsdomains &interventionsdomains &findingsdomains), &temp)) %then %do;
            proc sort data = &temp(keep = EPOCH where = (not missing(EPOCH))) nodupkey out = EPOCH;
               by EPOCH;
            run;
         %end;
         %else %if &temp = ADSL %then %do;
            proc sort data = tadsl(keep = EPOCH where = (not missing(EPOCH))) nodupkey out = EPOCH;
               by EPOCH;
            run;                
         %end;
         %else %do;
            proc sort data = &&in_&temp(keep = EPOCH where = (not missing(EPOCH))) nodupkey out = EPOCH;
               by EPOCH;
            run;                         
         %end;

         %let _tid_ = %sysfunc(open(EPOCH));
         %let EPOCHfl = %sysfunc(varnum(&_tid_,EPOCH));
         %let EPOCHlen = %sysfunc(varlength(&_tid_,&EPOCHfl));
         %let _tid_ = %sysfunc(close(&_tid_));

         %if ^&first %then %do;
            data TEPOCH;
               set EPOCH;
            run;
            %let first = 1;
            %let plen = &EPOCHlen;
         %end;
         %else %do;
            %let plen = %sysfunc(max(&EPOCHlen,&plen));
            data TEPOCH;
               length EPOCH $ &plen;
               set TEPOCH EPOCH;
            run;
         %end;

         proc datasets nolist;
            delete EPOCH;
         quit;
      %end;      
      %let i = %eval(&i+1);
   %end;
   %if &first %then %do;
      proc sort data = TEPOCH nodupkey out = TEPOCH;
         by EPOCH;
      run;      
      data _null_;
         set TEPOCH;
         file "%FileWorkIt(&basemeta&_slash_.EPOCH.txt)" delimiter = "~" encoding="utf-8";
         put EPOCH;
      run;
      proc datasets nolist;
         delete TEPOCH;
      quit;      
   %end;

   %put Exiting METAEPOCH;
   %ClockStop(METAEPOCH); 

   %put [AddStudyLocal_~METADATAOUTFILES VISITNUM VISIT~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.90];

   %put Entering METAVISIT;
   %ClockStart(METAVISIT); 

   *** VISITNUM VISIT ***;
   %let i = 1;
   %let first = 0;
   %let VISITFlag = 0;
   %if %sysfunc(findw(%upcase(&domains), SV)) %then %let SVFlag = SV;
   %else %let SVFlag = ;
   %do %while(%length(%scan(&findingsdomains &SVFlag,&i," ")));
      %let temp = %scan(&findingsdomains &SVFlag,&i," ");
      %if ^%sysfunc(findw(%upcase(&bdsdomains), &temp)) %then %do;
         %let VISITNVAL = VISITNUM;
         %let VISITVAL = VISIT;
      %end;
      %else %do;
         %let VISITNVAL = AVISITN;
         %let VISITVAL = AVISIT;      
      %end;
      
      %if %sysfunc(findw(%upcase(&&&temp.VARS), &VISITNVAL)) %then %do;
         %if %sysfunc(findw(%upcase(&&&temp.VARS), &VISITVAL)) %then %do;
            %let VISIT = &VISITVAL;
            %let VISITFlag = 1;
         %end;
         %else %let VISIT = ;

         %if %sysfunc(findw(%upcase(&eventsdomains &interventionsdomains &findingsdomains), &temp)) %then %do;         
            proc sort data = &temp(keep = &VISITNVAL &VISIT where = (not missing(&VISITNVAL))) nodupkey out = VISITNUM;
               by &VISITNVAL &VISIT;
            run;
         %end;
         %else %if &temp = ADSL %then %do;
            proc sort data = tadsl(keep = &VISITNVAL &VISIT where = (not missing(&VISITNVAL))) nodupkey out = VISITNUM;
               by &VISITNVAL &VISIT;
            run;                
         %end;
         %else %do;
            proc sort data = &&in_&temp(keep = &VISITNVAL &VISIT where = (not missing(&VISITNVAL))) nodupkey out = VISITNUM;
               by &VISITNVAL &VISIT;
            run;                         
         %end;                
			
         %if %length(&VISIT) %then %do;
            %let _tid_ = %sysfunc(open(VISITNUM));
            %let VISITfl = %sysfunc(varnum(&_tid_,&VISIT));
            %let VISITlen = %sysfunc(varlength(&_tid_,&VISITfl));
            %let _tid_ = %sysfunc(close(&_tid_));
         %end;
         %else %let VISITlen = 0;

         %if ^&first %then %do;
            %if ^%sysfunc(findw(%upcase(&bdsdomains), &temp)) %then %do;
               data TVISITNUM;
                  set VISITNUM;
               run;
            %end;
            %else %do;
               data TVISITNUM;
                  set VISITNUM(rename = (avisitn = visitnum %if &VISITfl %then %do; avisit = visit %end;));
               run;                        
            %end;
            %let first = 1;
            %let plen = &VISITlen;
         %end;
         %else %do;
            %let plen = %sysfunc(max(&VISITlen,&plen));
            %if ^%sysfunc(findw(%upcase(&bdsdomains), &temp)) %then %do;
               data TVISITNUM;
                  %if %length(&VISIT) %then %do;
                     length visit $ &plen;
                  %end;
                  set TVISITNUM VISITNUM;
               run;
            %end;
            %else %do;
               data TVISITNUM;
                  %if %length(&VISIT) %then %do;
                     length visit $ &plen;
                  %end;
                  set TVISITNUM VISITNUM(rename = (avisitn = visitnum %if &VISITfl %then %do; avisit = visit %end;));
               run;
            %end;
         %end;
 			 proc sort data = VISITNUM(keep = &VISITNVAL %if &VISITFlag %then &VISIT;) nodupkey out = &temp.VISITNUM;
				by &VISITNVAL;
			run;

      	data _null_;
      	   set &temp.VISITNUM;
            file "%FileWorkIt(&basemeta&_slash_.&temp.VISITNUM.txt)" delimiter = "~" encoding="utf-8";
      	   put &VISITNVAL %if &VISITFlag %then &VISIT;;
      	run;

         proc datasets nolist;
            delete VISITNUM &temp.VISITNUM;
         quit;
      %end;      
      %let i = %eval(&i+1);
   %end;
   
   %put [AddStudyLocal_~METADATAOUTFILES Missing Visit Correction 1~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.91];   
   
   %if &first %then %do;           
      proc sort data = TVISITNUM nodupkey out = TVISITNUM;
         by VISITNUM %if &VISITFlag %then VISIT;;
      run;

      %let trNoVisitLabel = %nrbquote(%LocaleGet(NoVisitLabel_Text));
      %let plen = %sysfunc(max(%length(&trNoVisitLabel),&plen));
      
      *** remove instances where visit missing when visitnum exists and visit info present ***;
      %if &VISITFlag %then %do;
         data hasvisit missvisit;
            set TVISITNUM;
            if missing(VISIT) then output missvisit;
            else output hasvisit;
         run;
         
         %let trNoVisitLabel = %nrbquote(%LocaleGet(NoVisitLabel_Text));
         %let plen = %sysfunc(max(%length(&trNoVisitLabel),&plen));
         data leftover;
            length VISIT $ &plen;
            merge missvisit(keep = visitnum in = ina) hasvisit(keep = visitnum in = inb);
            by visitnum;
            if ina and not inb;
            VISIT = "&trNoVisitLabel";
         run;
      
         %put [AddStudyLocal_~METADATAOUTFILES Missing Visit Correction 2~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.92];      
      
         data TVISITNUM;
            length VISIT $ &plen;
            set hasvisit leftover;
         run;
         
         proc datasets nolist;
            delete hasvisit missvisit leftover;
         quit;
      %end;

      data _null_;
         set TVISITNUM;
         file "%FileWorkIt(&basemeta&_slash_.VISITNUM.txt)" delimiter = "~" encoding="utf-8";
         put VISITNUM %if &VISITFlag %then VISIT;;
      run;
      
      proc datasets nolist;
         delete TVISITNUM;
      quit;      
   %end;   

   %put Exiting METAVISIT;
   %ClockStop(METAVISIT); 

   
   %if %length(&eventsdomains &interventionsdomains &adslpresent) %then %do;
      proc datasets nolist;
         delete &eventsdomains &interventionsdomains &adslpresent;
      quit;
   %end;
   
   %put Entering METAFINDTESTCODE;
   %ClockStart(METAFINDTESTCODE); 

   *** Create Findings Test Code data sets ***;
   %let i = 1;
   %do %while(%length(%scan(&findingsdomains,&i," ")));
      %let temp = %scan(&findingsdomains,&i," ");
      %let tempsub = %substr(&temp,1,2);
   
      %if (%sysfunc(findw(%upcase(&bdsdomains), &temp)) and %sysfunc(findw(&&&temp.VARS, PARAMCD))) or (^%sysfunc(findw(%upcase(&bdsdomains), &temp)) and %sysfunc(findw(&&&temp.VARS, &tempsub.TESTCD))) %then %do;      
         %if %sysfunc(findw(%upcase(&bdsdomains), &temp)) %then %do;
            proc sort data = &temp(keep = PARAMCD %if %sysfunc(findw(&&&temp.VARS, PARAM)) %then PARAM; %if %sysfunc(findw(&&&temp.VARS, &tempsub.NRIND)) %then &tempsub.NRIND;) nodupkey out = &temp.TESTCD;
               by PARAMCD %if %sysfunc(findw(&&&temp.VARS, PARAM)) %then PARAM;;
            run;
         %end;
         %else %do;

            proc sort data = &temp(keep = &tempsub.TESTCD %if %sysfunc(findw(&&&temp.VARS, &tempsub.TEST)) %then &tempsub.TEST;) nodupkey out = &temp.TESTCD;
               by &tempsub.TESTCD %if %sysfunc(findw(&&&temp.VARS, &tempsub.TEST)) %then &tempsub.TEST;;
            run;      
         %end;

         *** Create TXT files of Findings Test Codes ***;
         data _null_;
            %if %sysfunc(findw(%upcase(&bdsdomains), &temp)) %then %do;
               set &temp.testcd(rename = (paramcd = &tempsub.testcd param = &tempsub.test));
            %end;
            %else %do;  
               set &temp.testcd;
            %end;
            &tempsub.testcd = transtrn(strip(&tempsub.testcd), " ", "_");
            file "%FileWorkIt(&basemeta&_slash_.&temp.TESTCD.txt)" delimiter = "~" encoding="utf-8";
            put &tempsub.testcd &tempsub.test;
         run;
         
         %if %sysfunc(findw(&&&temp.VARS, &tempsub.NRIND)) %then %do;
         	proc sort data =&temp(keep= &tempsub.NRIND) nodupkey out =&temp.NRIND;
         		by &tempsub.NRIND; 
         	run;
         	data _null_;
         		set &temp.NRIND;
         		&tempsub.nrind = transtrn(strip(&tempsub.nrind), " ", "_");
               file "%FileWorkIt(&basemeta&_slash_.&temp.NRIND.txt)" delimiter = "~" encoding="utf-8";
         		put &tempsub.nrind;
         	run;
         %end;

         proc datasets nolist;
            delete &temp;
         quit;
      %end;

      *** compute quantile during add study process ***;
      %ComputeBaseline(&temp,_blD&temp);
      %if %sysfunc(exist(work._blD&temp)) %then %do;
         %NObsVars(_blD&temp); 
         %if &nobs >0 %then %do;
            %ComputeQuantiles(&temp,_blD&temp,fdQuantile);
            %if %sysfunc(exist(work.fdQuantile)) %then %do;
               %NObsVars(fdQuantile); 
               %if &nobs >0 & (&ProcessName = AddStudyLocal or &ProcessName = ManageStudies) %then %do;
                  data %DataWorkIt(basemeta.&temp.QUANTILES);
                     set fdQuantile;
                  run;
                  proc datasets nolist;
                     delete fdQuantile;
                  quit;
               %end;
            %end;
         %end;
         proc datasets nolist;
            delete _blD&temp;
         quit;
      %end;
      %let i = %eval(&i+1);
   %end;      
   %if &exiterror %then %goto mdoexit;

   %put Exiting METAFINDTESTCODE;
   %ClockStop(METAFINDTESTCODE); 
   
   %if ^%symexist(NeedDelta) %then %do;
      %global NeedDelta;
      %let NeedDelta = NO;
   %end;
   
   %include "&MacroPath./UtilityPathMacros.sas" / nosource;
   
   %if &ProcessName = AddStudyLocal %then %do;
      data _null_;
         file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
         put "%nrstr(%global) ReviewsEnabled ;";
         %if &SnpComp = Yes %then %do;          
            put "%nrstr(%let) ReviewsEnabled = 1;";         
         %end;
         %else %do;
            put "%nrstr(%let) ReviewsEnabled = 0;";    
         %end;
      run;
      
      %put [AddStudyLocal_~METADATAOUTFILES Snapshot Comparison Information~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.93];      
      
      *create a .sas dataset to save the snapshot comparison information for managestudies;
      libname metalib "%jg_getPath(/user/clinical/metadata,,0,0,3,&studynameunder)";
      data metalib.SNAPSHOT;
         %if &SnpComp = Yes %then %do; 
            ReviewsEnabled= 1;
         %end;
         %else %do;
            ReviewsEnabled= 0;
         %end; 
      run;
   %end;
   %if &ProcessName = AddStudyLocal or (&ProcessName = ManageStudies and &NeedDelta = YES) %then %do;
      data _null_;
         file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
         %if (&ProcessName = ManageStudies and &NeedDelta = YES) %then %do;
            put "%nrstr(%global) ReviewsEnabled ;";         
            put "%nrstr(%let) ReviewsEnabled = &ReviewsEnabled;";
         %end;
         put "%nrstr(%global) TransportFlag;";
         put "%nrstr(%let) TransportFlag = &SASTransport;";
         put "%nrstr(%global) ReviewNumber;";
         put "%nrstr(%let) ReviewNumber = 0;";
         put "%nrstr(%global) TrtStartDate;";
         %if %sysfunc(findw(%upcase(&ADSLVARS), RFSTDTC)) %then %do;      
         	put "%nrstr(%let) TrtStartDate = RFSTDTC;";
         %end;
         %else %if %sysfunc(findw(%upcase(&ADSLVARS), TRTSDT)) %then %do; 
         	put "%nrstr(%let) TrtStartDate = TRTSDT;";
         %end;
      run;   
   %end;
   %else %if &ProcessName = ManageStudies %then %do;
      data _null_;
         file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
         put "%nrstr(%global) ReviewsEnabled ;";         
         put "%nrstr(%let) ReviewsEnabled = &ReviewsEnabled;";
         put "%nrstr(%global) TransportFlag;";
         put "%nrstr(%let) TransportFlag = &SASTransport;";
      run;
      %if &NewSnap = YES %then %let CurrentReview = %eval(&CurrentReview + 1);
      %else %if &NewSnap = NO %then %let CurrentReview = &CurrentReview;
      
		%if &NewSnap = YES %then %do;
         *** Copy File to Metadata Folder ***;
         data getprev;
            set RevLib.DeltaFile&CurrentReview;
         run;
         
         data aa;
            length text $ 200;
            file "%jg_getPath(/user/clinical/metadata/base, DeltaFile&CurrentReview..sas, 0, 0, 3, &studynameunder)";
            set getprev;
            put text;
         run;  
         
         proc datasets nolist;
            delete getprev;
         quit;
         
         *** Delete File from Output Folder ***;
         data _null_;
            fname = "tempfile";
            rc = filename(fname,"&ServerOutPath.DeltaFile&CurrentReview..sas7bdat");
            if rc = 0 and fexist(fname) then rc = fdelete(fname);
            rc = filename(fname);
         run;   
		%end;  
   %end;   

   %put Entering METAKEYS;
   %ClockStart(METAKEYS); 

   *** Generate Data Set Keys ***;
   %KEYS;

   %put Exiting METAKEYS;
   %ClockStop(METAKEYS); 
   
   %if ^%symexist(unmatchKeys) %then %let unmatchKeys=0;
   %if &exiterror %then %do;
		* for mismatched keys from previous snapshot, reviewnumber should not be updated; 
   	%if &unmatchKeys =1 %then %do;
   		%let CurrentReviewtmp = %eval( &CurrentReview -1);
			data _null_;
            file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
				put "%nrstr(%global) ReviewNumber;";
				put "%nrstr(%let) ReviewNumber = &CurrentReviewtmp;";
	      run;
   	%end;
   	%else %do;
	      data _null_;
            file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
	         put "%nrstr(%global) ReviewNumber;";
	         put "%nrstr(%let) ReviewNumber = &CurrentReview;";
	      run;
   	%end;
   %end;
	%else %do;
	   %if &ProcessName = ManageStudies %then %do;
	      data _null_;
            file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
	         put "%nrstr(%global) ReviewNumber;";
	         put "%nrstr(%let) ReviewNumber = &CurrentReview;";
	      run;
	   %end;
	%end;
   
   %put [AddStudyLocal_~METADATAOUTFILES COMPARE~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.94];
   
   %put Entering METACOMPARE;
   %ClockStart(METACOMPARE); 
   
   *** S1561901 ***;
   /*%if ^&exiterror %then %do;*/
      %if &ProcessName = AddStudyLocal or (&ProcessName = ManageStudies and &NeedDelta = YES) %then %do;
         %if &ProcessName = AddStudyLocal %then %do; 
            %if &SnpComp =Yes %then %do;
               %COMPARE(managetwo = 0);
            %end;
         %end;
         %else %do;
            %let meta=%jg_getPath(/user/clinical/metadata,,0,0,3,&studynameunder);
            libname metalib "&meta";
            %let snapfile=SNAPSHOT.sas7bdat;
            %if %sysfunc(fileexist(&meta.&snapfile)) %then %do;
               %global ReviewsEnabled;
               data _null_;
                  set metalib.SNAPSHOT;
                  call symput('ReviewsEnabled',ReviewsEnabled);
               run;
            %end;
            %else %do;
               * for previous added study: there is no ReviewsEnabled variable;
               %if ^%symexist(ReviewsEnabled) %then %do;
                  %global ReviewsEnabled;
                  %let ReviewsEnabled=1;
               %end;
            %end;
            %if &ReviewsEnabled %then %do;
               %COMPARE(managetwo = 0);
            %end;
         %end;
         %DOMAINLISTADD;
      %end; 
      %else %if &ProcessName = ManageStudies %then %do;
         %if &NewSnap = YES %then %do;
            %if &unmatchKeys = 0 %then %do;
               %COMPARE(managetwo = 1);
            %end;
         %end;
         %else %do;
            data _null_;
               file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
               put "libname DeltaLib %nrstr(%')%jg_getPath(/user/clinical/delta,,0,0,3,&studynameunder)%nrstr(%');";
               put "%nrstr(%let) DeltaDir = %jg_getPath(/user/clinical/delta,,0,0,3,&studynameunder);";
            run;  
         %end;
         %if %index(&Task,Update) or %index(&Task,Refresh) %then %do;
            %DOMAINLISTADD;
         %end;
      %end;
   /*%end;*/
   %if &exiterror %then %do;
   	%if &unmatchKeys = 1 %then %do;
         *** Delete File delta DeltaFile&CurrentReview from BASE folder ***;
         data _null_;
            fname = "tempfile";
            rc = filename(fname,"&basemeta&_slash_.DeltaFile&CurrentReview..sas");
            if rc = 0 and fexist(fname) then rc = fdelete(fname);
            rc = filename(fname);
         run; 
			%put [MS_S_0373];
			%put ERROR: A new key &unmatchdmKey in &unmatchdomain domain, has been detected that did not get assigned at add study.;
			%put ERROR: This key will need to be added the first time add study is run.;
         %put NOTE;
			%goto mdoexit;
   	%end;
   %end;

   %put Exiting METACOMPARE;
   %ClockStop(METACOMPARE); 

   %put [AddStudyLocal_~METADATAOUTFILES Complete~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.95];

   options notes;
   %put exiting METADATAOUTFILES;
   %mdoexit:;       
   %ClockStop(METADATAOUTFILES);
%mend METADATAOUTFILES;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro GENERATEMETA(studname = &studyname);
   %put Entering GENERATEMETA;
   %ClockStart(GENERATEMETA);  
   %global CSTERROR;
   %let CSTERROR = 0;
   
   %InitWorkedDataAndFiles();
   
	%if ^%symexist(SpltDomainFlag) %then %do;
		%global SpltDomainFlag;
		%let SpltDomainFlag=0;
   %end;

   %if %length(&InPath) %then %do;
      libname sdtm cvp "&InPath";
   	%if &SpltDomainFlag %then %do;
   		libname sdtmsp cvp "&InPathsp";
   	%end;
   %end; 
   %if %length(&AInPath) %then %do;    
      libname adam cvp "&AInPath";
   %end;
   libname clinical "&CLINICAL_HOME";
   *** Replaces spaces in studname with underscores;
   %let studynameunder = %sysfunc(transtrn(&studname, %str( ), _));
   
   %put Metapath = &Metapath;

   %include "&MacroPath./UtilityPathMacros.sas" / nosource;
   %jg_getPath(/user/clinical/metadata,,3,0,0,&studynameunder);  
   %global DERIMETA;
   %let DERIMETA=%jg_getPath(/user/clinical/dataderivedmetadata,,1,0,1,&studynameunder); 
   libname derimeta "&DERIMETA";
   
   %if %length(&InPath) %then %do;
      %MAKEDIR(dir=SDTM, varname = SDTMMETA, parent = %jg_getPath(/user/clinical/metadata,,0,0,3,&studynameunder));
   %end;
   %else %do;
      %global SDTMMETA;
      %let SDTMMETA = ;
   %end;
   %if %length(&AInPath) %then %do;
      %MAKEDIR(dir=ADAM, varname = ADAMMETA, parent = %jg_getPath(/user/clinical/metadata,,0,0,3,&studynameunder)); 
   %end;
   %else %do;
      %global ADAMMETA;
      %let ADAMMETA = ;
   %end;
   %MAKEDIR(dir=BASE, varname = BASEMETA, parent = %jg_getPath(/user/clinical/metadata,,0,0,3,&studynameunder)); 
   %if %symexist(STUDY_HOME)=0 %then %do;
      %global STUDY_HOME;
      %let STUDY_HOME = %jg_getPath(/user/clinical/metadata,,0,0,3,&studynameunder);
   %end;
   
   %CREATEMETADATA; 
   %if &CSTERROR %then %goto mdexit;
   
   %if %length(&domaindups) %then %do;
      %let CSTERROR = 1;
      %put [MS_S_0203];
      %put ERROR: The following domains are duplicated in at least two datasets: &domaindups;
      %goto mdexit;
   %end;

   %IDENTIFYDOMAINS;
  
   %put [AddStudyLocal_~GENERATEMETA MISSVARS InPath~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.10];
   
   %if %length(&InPath) %then %do;
      %MISSVARS(model = SDTM, dir = SDTMMETA, progressStart = 0.10, progressStop = 0.35); 
      %if &CSTERROR %then %goto mdexit;
   %end;
   
   %put [AddStudyLocal_~GENERATEMETA MISSVARS AInPath~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.35];   
   
   %if %length(&AInPath) %then %do;
      %MISSVARS(model = ADAM, dir = ADAMMETA, progressStart = 0.35, progressStop = 0.60); 
      %if &CSTERROR %then %goto mdexit;
   %end;
   
   %put [AddStudyLocal_~GENERATEMETA METADATAOUTFILES~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.60];
   
   %METADATAOUTFILES;
   %if &exiterror %then %goto mdexit;
  
   %put [AddStudyLocal_~GENERATEMETA Complete~_PROGRESS_INDICATOR_ESTIMATED_FRACTION=0.95];
   
   %ClockStart(SaveWorkedDataAndFiles);
   %SaveWorkedDataAndFiles();
   %ClockStop(SaveWorkedDataAndFiles);
   
   %put CSTERROR = &CSTERROR; 
   %put Exiting GENERATEMETA;
   %mdexit:;
   %ClockStop(GENERATEMETA);     
%mend GENERATEMETA;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro CHKSTUDYNAME;
   %put Entering CHKSTUDYNAME;
   %ClockStart(CHKSTUDYNAME);  
   %let StudyName = %nrbquote(&StudyName);
   %let numlist = 0 1 2 3 4 5 6 7 8 9;

   %let symlist = %nrstr(< > { } [ ] * | ? / \ , : = ; ` ~ ! $ ^);
   %do i = 1 %to 26;
      %if &i < 21 %then %let temp = %scan(&symlist,&i,' ');
      %else %if &i = 21 %then %let temp = %nrstr(&);
      %else %if &i = 22 %then %let temp = %nrstr(%%);
      %else %if &i = 23 %then %let temp = %nrstr(%');
      %else %if &i = 24 %then %let temp = %nrstr(%");
      %else %if &i = 25 %then %let temp = %nrstr(%();
      %else %if &i = 26 %then %let temp = %nrstr(%));
      %if %index(&StudyName, %nrbquote(&temp)) %then %do;
         %put [MS_S_0205];
         %put ERROR: Study Name must not contain the symbol &temp.;
         %let exiterror = 1;
      %end;
   %end;
   
   %if q&StudyName = q%nrstr(.) or q&StudyName = q%nrstr(..) %then %do;
      %put [MS_S_0374];
      %put ERROR: Study Name cannot be . or .. .;
      %let exiterror = 1;
   %end;
   %put Exiting CHKSTUDYNAME;
   %ClockStop(CHKSTUDYNAME);     
%mend CHKSTUDYNAME;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro KEYS(domlist = DM CO SE SV &findingsdomains &eventsdomains &interventionsdomains &splittingdomains &adslpresent);
   %put Entering KEYS;
   %ClockStart(KEYS);  
   %include "&MacroPath./UtilityPathMacros.sas" / nosource;
   %let notesDataset=;
   %jg_getNotesDatasetName(notesDataset);
   %let domlist = %sysfunc(compbl(&domlist));
   %let dflg = 0;
      
   %let trSortedby = %nrbquote(%LocaleGet(SortedbyNS_Text));
   %let notesDataset=;
   %jg_getNotesDatasetName(notesDataset);
   %let studynameunder = %sysfunc(transtrn(&studyname, %str( ), _));

   %let trProcessName = %nrbquote(%LocaleGet(&ProcessName._Label));
   %let trJMPClinical = %nrbquote(%LocaleGet(JMPClinical_Text));
   %let trSAtJC = %nrbquote(%LocaleGet(StudyAddedtoJMPClinical_Text));
   %let trMRDoIDC = %nrbquote(%LocaleGet(MostRecentDatetimeofInputDataCreation_Text));
   %let trSnapEnabled = %nrbquote(%LocaleGet(SnapShotComparisonisEnabled_Text));
   %let trSnapDisabled = %nrbquote(%LocaleGet(SnapShotComparisonisDisabled_Text));
   %let trStudyName = %nrbquote(%LocaleGet(StudyName_Text));
   %let trKeysValues = %nrbquote(%LocaleGet(KeysValues_Text));
   %let trReport = %nrbquote(%LocaleGet(Report_Text));
   %let trDateofNote = %nrbquote(%LocaleGet(DateofNote_Text));
   %let trSnapshotNumber = %nrbquote(%LocaleGet(SnapshotNumber_Text));
   %let trSnapshot = %nrbquote(%LocaleGet(Snapshot_Text));
   %let trType = %nrbquote(%LocaleGet(Type_Text));
   %let _trKeys = %nrbquote(%LocaleGet(Keys_Text));
   %let trDomain = %nrbquote(%LocaleGet(Domain_Text));
   %let trUser = %nrbquote(%LocaleGet(User_Text));
   %let trNote = %nrbquote(%LocaleGet(Note_Text));
   %let trSDTMFolder = %nrbquote(%LocaleGet(SDTMorSENDFolder_Text));
   %let trADaMFolder = %nrbquote(%LocaleGet(ADaMFolder_Text));
   %let trSystemGenerated = %nrbquote(%LocaleGet(SystemGenerated_Text));
   %let trUSAtJC = %nrbquote(%LocaleGet(UpdatedSnapshotAppliedtoJMPClinical_Text));
   %let trSMtNVoJC = %nrbquote(%LocaleGet(StudyMigratedtoNewVersionofJMPClinical_Text));

   *** Check for presence of define file in SDTM/ADaM for keys ***;
   *** Missing means no define file ***; 
   *** 0 means def:DomainKeys is not present meaning that Define-XML is Version 2 ***;
   *** >0 means def:DomainKeys is present meaning that Define-XML is Version 1 ***;
   
   /*%if %length(&InPath) %then %do;
      %if %sysfunc(fileexist(&InPath.define.xml)) or %sysfunc(fileexist(&InTmpPath.define.xml)) %then %do;
         %let DomainKeysSDTM = 0;
         data _null_;
         	%if &SASTransport %then %do;
         		infile "&InTmpPath.define.xml" linesize = 500 truncover scanover;
         	%end;
         	%else %do;
           		infile "&InPath.define.xml" linesize = 500 truncover scanover;
           	%end;
           input @"def:DomainKeys" text $ 1;
           retain i;
           i + 1;
           call symput("DomainKeysSDTM", left(max(i)));  
         run;
      %end;
      %else %let DomainKeysSDTM =;
   %end;
   %else*/ %let DomainKeysSDTM =;

   %let DefineVersSDTM =;
   %if &DomainKeysSDTM = 0 %then %let DefineVersSDTM = 2;
   %else %if %length(&DomainKeysSDTM) %then %let DefineVersSDTM = 1;

   /*%if %length(&AInPath) %then %do;
      %if %sysfunc(fileexist(&AInPath.define.xml)) or %sysfunc(fileexist(&AInTmpPath.define.xml)) %then %do;
         %let DomainKeysADaM = 0;
         data _null_;
			  %if &SASTransport %then %do;
			  	infile "&AInTmpPath.define.xml" linesize = 500 truncover scanover;
			  %end;
			  %else %do;
           	infile "&AInPath.define.xml" linesize = 500 truncover scanover;
           %end;
           input @"def:DomainKeys" text $ 1;
           retain i;
           i + 1;
           call symput("DomainKeysADaM", left(max(i)));  
         run;
      %end;
      %else %let DomainKeysADaM =;
   %end;
   %else*/ %let DomainKeysADaM =;

   %let DefineVersADAM =;
   %if &DomainKeysADAM = 0 %then %let DefineVersADAM = 2;
   %else %if %length(&DomainKeysADAM) %then %let DefineVersADAM = 1;
   
   %let i = 1;   
   %do %while(%length(%scan(&domlist,&i,' ')));
      %let temp = %scan(&domlist,&i,' ');
      %let templib = %upcase(%scan(&&in_&temp, 1, "."));
      %if %sysfunc(findw(%upcase(&domains), &temp)) or &temp = ADSL %then %do;
         %put getting keys for &temp;
         %global &temp.KEYS &temp.KEYSMISS;      
         %let &temp.KEYS =; 
         %let &temp.KEYSMISS =; 
      
         *** step 1 - check from define file ***;         
         
         /*%if &templib = SDTM and %length(&DefineVersSDTM) %then %do;
         	%if &SASTransport %then %do;
         		%GetDatasetKeys(DefineFile=&InTmpPath.define.xml, MapFile=&MacroPath./define&DefineVersSDTM..map, Dataset=&temp, MacVar=&temp.KEYS);
         	%end;
         	%else %do;
            %GetDatasetKeys(DefineFile=&InPath.define.xml, MapFile=&MacroPath./define&DefineVersSDTM..map, Dataset=&temp, MacVar=&temp.KEYS);
            %end;
         %end;
         %else %if &templib = ADAM and %length(&DefineVersADAM) %then %do;
         	%if &SASTransport %then %do;
         		%GetDatasetKeys(DefineFile=&AInTmpPath.define.xml, MapFile=&MacroPath./define&DefineVersADAM..map, Dataset=&temp, MacVar=&temp.KEYS);
         	%end;
         	%else %do;
            	%GetDatasetKeys(DefineFile=&AInPath.define.xml, MapFile=&MacroPath./define&DefineVersADAM..map, Dataset=&temp, MacVar=&temp.KEYS);
            %end;
         %end;*/
         
             
         *** step 2 - check for keys files ***;
         *** expect one per domain file in each CDISC library - a text file with just a set of variables in order of importance ***;

         %if ^%length(&&&temp.KEYS) %then %do;
            %if &templib = SDTM %then %do;
            	%if &SASTransport %then %do;
            		%let keyfile = &InTmpPath.keys/&temp..txt;
            	%end;
            	%else %do;
               	%let keyfile = &InPath.keys/&temp..txt;
               %end;
            %end;
            %else %if &templib = ADAM %then %do;
            	%if &SASTransport %then %do;
               	%if &temp = ADSL %then %let keyfile = &AInTmpPath.keys/ADSL.txt;
               	%else %let keyfile = &AInTmpPath.keys/AD&temp..txt;
            	%end;
            	%else %do;
               	%if &temp = ADSL %then %let keyfile = &AInPath.keys/ADSL.txt;
               	%else %let keyfile = &AInPath.keys/AD&temp..txt;
               %end;
            %end;
            %else %if &templib = SDTMSP %then %do;
            	%if &SASTransport %then %do;
            		%let keyfile = &InTmpPath.keys/&temp..txt;
            	%end;
            	%else %do;
               	%let keyfile = &InPathSP.keys/&temp..txt;
               %end;
            %end;

            %if %sysfunc(fileexist(&keyfile)) %then %do;
               data keys;
                  infile "&keyfile" linesize = 32 pad;
                  input keys $ 1-32;
               run;
               %NObsVars(keys);
               %if &nobs %then %do;
                  %GetLevels(keys,keys,&temp.KEYS,_nLvls=nidvar,_vType=vtype,_dropmiss = 1);
               %end;
               proc datasets nolist;
                  delete keys;
               quit;
            %end;
         %end;
         
         *** step 3 - check for sort metadata ***;
         
         proc contents data = &&in_&temp;
            ods exclude all;
            ods output sortedby = sortvars(where = (upcase(label1) = upcase("&trSortedby")));         
         run;
         ods select all;

         %let _tid_ = %sysfunc(open(&&in_&temp));
         %let tCRDate = %sysfunc(attrn(&_tid_,CRDTE));      
         %let _tid_ = %sysfunc(close(&_tid_));

         %if ^&dflg %then %do; 
            %let CRDate = &tCRDate;
         %end;
         %else %if &dflg %then %do;
            %if %sysevalf(&tCRDate > &CRDate) %then %let CRDate = &tCRDate;         
         %end;         

         **** S0992169 for Chinese, data sortvars is generated,but no observations ****;
         %let nobsSortVars=0;
         %if %sysfunc(exist(sortvars)) %then %do;
            %NObsVars(sortvars); 
            %let nobsSortVars=&nobs;   
         %end;

         %if %sysfunc(exist(sortvars)) & &nobs>0 %then %do;         
            %if ^%length(&&&temp.KEYS) %then %do;         
               data _null_;
                  set sortvars;
                  cvalue1 = compbl(transtrn(cvalue1, "DESCENDING", ""));
                  call symput("&temp.KEYS", strip(cvalue1));
               run;
            %end;

            proc datasets nolist;
               delete sortvars;
            quit;
         %end;

         *** step 4 - attempt to derive ***;
         
         %if ^%length(&&&temp.KEYS) %then %do;                             
            %if %sysfunc(findw(%upcase(&&&temp.vars), STUDYID)) %then %let _STUDYID = STUDYID;
            %else %do;
               %let _STUDYID =;
               %let &temp.KEYSMISS = &&&temp.KEYSMISS STUDYID; 
            %end;
            %if %sysfunc(findw(%upcase(&&&temp.vars), USUBJID)) %then %let _USUBJID = USUBJID;
            %else %do;
               %let _USUBJID =;
               %let &temp.KEYSMISS = &&&temp.KEYSMISS USUBJID; 
            %end;
            %if &temp = SV %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), VISITNUM)) %then %let _VISITNUM = VISITNUM;
               %else %do;
                  %let _VISITNUM =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS VISITNUM; 
               %end;
            %end;          
            %else %if &temp = CO %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), COSEQ)) %then %let _COSEQ = COSEQ;
               %else %do;
                  %let _COSEQ =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS COSEQ; 
               %end;
            %end;
            %else %if &temp = SE %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), SESTDTC)) %then %let _SESTDTC = SESTDTC;
               %else %do;
                  %let _SESTDTC =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS SESTDTC; 
               %end;
               %if %sysfunc(findw(%upcase(&&&temp.vars), ETCD)) %then %let _ETCD = ETCD;
               %else %do;
                  %let _ETCD =;              
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS ETCD; 
               %end;
            %end;
            %else %if %sysfunc(findw(%upcase(&interventionsdomains), &temp)) and ^%sysfunc(findw(%upcase(&occurrencebdsdomains), &temp)) %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), &temp.STDTC)) %then %let _&temp.STDTC = &temp.STDTC;
               %else %do;
                  %let _&temp.STDTC =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS &temp.STDTC; 
               %end;
               %if %sysfunc(findw(%upcase(&&&temp.vars), &temp.TRT)) %then %let _&temp.TRT = &temp.TRT;
               %else %do;
                  %let _&temp.TRT =;                                       
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS &temp.TRT; 
               %end;
            %end;
            %else %if %sysfunc(findw(%upcase(&interventionsdomains), &temp)) and %sysfunc(findw(%upcase(&occurrencebdsdomains), &temp)) %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), ASTDTM)) %then %let _&temp.STDTC = ASTDTM;
               %else %if %sysfunc(findw(%upcase(&&&temp.vars), ASTDT)) %then %let _&temp.STDTC = ASTDT;
               %else %do;
                  %let _&temp.STDTC =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS ASTDT; 
               %end;
               %if %sysfunc(findw(%upcase(&&&temp.vars), &temp.TRT)) %then %let _&temp.TRT = &temp.TRT;
               %else %do;
                  %let _&temp.TRT =;                                       
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS &temp.TRT; 
               %end;
            %end;
            %else %if %sysfunc(findw(%upcase(&eventsdomains), &temp)) and ^%sysfunc(findw(%upcase(&occurrencebdsdomains), &temp)) %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), &temp.STDTC)) %then %let _&temp.STDTC = &temp.STDTC;
               %else %do;
                  %let _&temp.STDTC =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS &temp.STDTC; 
               %end;             
               %if %sysfunc(findw(%upcase(&&&temp.vars), &temp.TERM)) %then %let _&temp.TERM = &temp.TERM;
               %else %do;
                  %let _&temp.TERM =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS &temp.TERM; 
               %end;
            %end;
            %else %if %sysfunc(findw(%upcase(&eventsdomains), &temp)) and %sysfunc(findw(%upcase(&occurrencebdsdomains), &temp)) %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), ASTDTM)) %then %let _&temp.STDTC = ASTDTM;
               %else %if %sysfunc(findw(%upcase(&&&temp.vars), ASTDT)) %then %let _&temp.STDTC = ASTDT;
               %else %do;
                  %let _&temp.STDTC =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS ASTDT; 
               %end;             
               %if %sysfunc(findw(%upcase(&&&temp.vars), &temp.TERM)) %then %let _&temp.TERM = &temp.TERM;
               %else %do;
                  %let _&temp.TERM =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS &temp.TERM; 
               %end;
            %end;     
            %else %if %sysfunc(findw(%upcase(&findingsdomains), &temp)) and ^%sysfunc(findw(%upcase(&bdsdomains), &temp)) %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), &temp.TESTCD)) %then %let _&temp.TESTCD = &temp.TESTCD;
               %else %do;
                  %let _&temp.TESTCD =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS &temp.TESTCD; 
               %end;
               %if &temp ne IE and &temp ne DA %then %do;   
                  %if %sysfunc(findw(%upcase(&&&temp.vars), VISITNUM)) %then %let _VISITNUM = VISITNUM;
                  %else %do;
                     %let _VISITNUM =;          
                     %let &temp.KEYSMISS = &&&temp.KEYSMISS VISITNUM; 
                  %end;
                  %if %sysfunc(findw(%upcase(&&&temp.vars), &temp.TPTREF)) %then %let _&temp.TPTREF = &temp.TPTREF;
                  %else %do;
                     %let _&temp.TPTREF =;
                     %let &temp.KEYSMISS = &&&temp.KEYSMISS &temp.TPTREF; 
                  %end;
                  %if %sysfunc(findw(%upcase(&&&temp.vars), &temp.TPTNUM)) %then %let _&temp.TPTNUM = &temp.TPTNUM;
                  %else %do;
                     %let _&temp.TPTNUM =;
                     %let &temp.KEYSMISS = &&&temp.KEYSMISS &temp.TPTNUM; 
                  %end;
               %end;
            %end;
            %else %if %sysfunc(findw(%upcase(&findingsdomains), &temp)) and %sysfunc(findw(%upcase(&bdsdomains), &temp)) %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), PARAMCD)) %then %let _&temp.TESTCD = PARAMCD;
               %else %do;
                  %let _&temp.TESTCD =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS PARAMCD; 
               %end;
               %if &temp ne IE and &temp ne DA %then %do;   
                  %if %sysfunc(findw(%upcase(&&&temp.vars), AVISITN)) %then %let _VISITNUM = AVISITN;
                  %else %do;
                     %let _VISITNUM =;          
                     %let &temp.KEYSMISS = &&&temp.KEYSMISS AVISITN; 
                  %end;
                  %let _&temp.TPTREF =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS &temp.TPTREF; 
                  %if %sysfunc(findw(%upcase(&&&temp.vars), ATPTN)) %then %let _&temp.TPTNUM = ATPTN;
                  %else %do;
                     %let _&temp.TPTNUM =;
                     %let &temp.KEYSMISS = &&&temp.KEYSMISS ATPTN; 
                  %end;
               %end;
            %end; 
            %else %if (%length(&temp) =4 and %substr(&temp,1,2) = FA) %then %do;
            * for split FA domains;
            	%if %sysfunc(findw(%upcase(&&&temp.vars), %substr(&temp,1,2)TESTCD)) %then %let _&temp.TESTCD = %substr(&temp,1,2)TESTCD;
               %else %do;
                  %let _&temp.TESTCD =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS %substr(&temp,1,2)TESTCD; 
               %end;  
					%if %sysfunc(findw(%upcase(&&&temp.vars), VISITNUM)) %then %let _VISITNUM = VISITNUM;
					%else %do;
						%let _VISITNUM =;          
						%let &temp.KEYSMISS = &&&temp.KEYSMISS VISITNUM; 
					%end;
					%if %sysfunc(findw(%upcase(&&&temp.vars), %substr(&temp,1,2)TPTREF)) %then %let _&temp.TPTREF = %substr(&temp,1,2)TPTREF;
					%else %do;
						%let _&temp.TPTREF =;
						%let &temp.KEYSMISS = &&&temp.KEYSMISS %substr(&temp,1,2)TPTREF; 
					%end;
					%if %sysfunc(findw(%upcase(&&&temp.vars), %substr(&temp,1,2)TPTNUM)) %then %let _&temp.TPTNUM = %substr(&temp,1,2)TPTNUM;
					%else %do;
						%let _&temp.TPTNUM =;
						%let &temp.KEYSMISS = &&&temp.KEYSMISS %substr(&temp,1,2)TPTNUM; 
					%end;
              %if %sysfunc(findw(%upcase(&&&temp.vars), FAOBJ)) %then %let _&temp.OBJ = FAOBJ;
               %else %do;
                  %let _&temp.OBJ =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS FAOBJ;
               %end;
            %end;
            %if &temp = FA %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), FAOBJ)) %then %let _FAOBJ = FAOBJ;
               %else %do;
                  %let _FAOBJ =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS FAOBJ;
               %end;
            %end;
            %if &temp = LB %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), &temp.SPEC)) %then %let _&temp.SPEC = &temp.SPEC;
               %else %do;
                  %let _&temp.SPEC =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS &temp.SPEC;
               %end;
            %end;
            %if &temp = DA %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), DADTC)) %then %let _DADTC = DADTC;
               %else %do;
                  %let _DADTC =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS DADTC;
               %end;
            %end;
            %if &temp = QS or &temp = PP %then %do;
               %if %sysfunc(findw(%upcase(&&&temp.vars), &temp.CAT)) %then %let _&temp.CAT = &temp.CAT;
               %else %do;
                  %let _&temp.CAT =;
                  %let &temp.KEYSMISS = &&&temp.KEYSMISS &temp.CAT;
               %end;             
            %end; 
            
            %if &temp = DM %then %let DMKEYS = &_STUDYID &_USUBJID;
            %else %if &temp = CO %then %let COKEYS = &_STUDYID &_USUBJID &_COSEQ;
            %else %if &temp = SE %then %let SEKEYS = &_STUDYID &_USUBJID &_ETCD &_SESTDTC;
            %else %if &temp = SV %then %let SVKEYS = &_STUDYID &_USUBJID &_VISITNUM;
            %else %if %sysfunc(findw(%upcase(&interventionsdomains), &temp)) %then %let &temp.KEYS = &_STUDYID &_USUBJID &&_&temp.TRT &&_&temp.STDTC;                
            %else %if %sysfunc(findw(%upcase(&eventsdomains), &temp)) %then %let &temp.KEYS = &_STUDYID &_USUBJID &&_&temp.TERM &&_&temp.STDTC;
            %else %if &temp = ADSL %then %let ADSLKEYS = &_STUDYID &_USUBJID;
            %else %if %sysfunc(findw(%upcase(&findingsdomains), &temp)) %then %do;
               %if &temp = FA %then %let &temp.KEYS = &_STUDYID &_USUBJID &&_&temp.TESTCD &&_&temp.OBJ &_VISITNUM &&_&temp.TPTREF &&_&temp.TPTNUM;
               %else %if &temp = LB %then %let &temp.KEYS = &_STUDYID &_USUBJID &&_&temp.TESTCD &&_&temp.SPEC &_VISITNUM &&_&temp.TPTREF &&_&temp.TPTNUM;
               %else %if &temp = IE %then %let &temp.KEYS = &_STUDYID &_USUBJID &&_&temp.TESTCD;
               %else %if &temp = DA %then %let &temp.KEYS = &_STUDYID &_USUBJID &&_&temp.TESTCD &_DADTC;
               %else %if &temp = QS %then %let &temp.KEYS = &_STUDYID &_USUBJID &&_&temp.CAT &&_&temp.TESTCD &_VISITNUM &&_&temp.TPTREF &&_&temp.TPTNUM;
               %else %if &temp = PP %then %let &temp.KEYS = &_STUDYID &_USUBJID &&_&temp.TESTCD &&_&temp.CAT &_VISITNUM &&_&temp.TPTREF &&_&temp.TPTNUM;
               %else %let &temp.KEYS = &_STUDYID &_USUBJID &&_&temp.TESTCD &_VISITNUM &&_&temp.TPTREF &&_&temp.TPTNUM;
            %end; 
            %else %if (%length(&temp) =4 and %substr(&temp,1,2) = FA) %then %let &temp.KEYS = &_STUDYID &_USUBJID &&_&temp.TESTCD &&_&temp.OBJ &_VISITNUM &&_&temp.TPTREF &&_&temp.TPTNUM;
            %if %length(%scan(&&&temp.KEYS,1,' ')) %then %do;
               %let &temp.KEYS = %sysfunc(compbl(&&&temp.KEYS));
            %end;
         %end; 
         * check if new keys exist in prevsious snapshot;
			%if &ProcessName = ManageStudies %then %do;
				%if &NewSnap = YES %then %do;
					%let studynameunder = %sysfunc(transtrn(&studyname, %str( ), _));
					%let mbd = %jg_getPath(/user/clinical/metadata/base, DeltaFile&CurrentReview..sas, 0, 0, 3, &studynameunder);
					%include "&mbd" / nosource;
					%if %symexist(prev_&temp) %then %do;
						%let j=1;
						%do %while(%length(%scan(&&&temp.KEYS,&j)));
							%let tempKey =%scan(&&&temp.KEYS,&j);
							* check if the key matchs the previous snapshot;
							%if %symexist(prev_&temp.KEYS) %then %do;
								%if ^%sysfunc(findw(%upcase(&&&&prev_&temp.KEYS), &tempKey)) %then %do;
									%let &temp.KEYS = &&&&prev_&temp.KEYS;
									%let exiterror =1;
									%global unmatchKeys unmatchdomain unmatchdmKey;
									%let unmatchKeys =1;
									%let unmatchdomain = &temp;
									%let unmatchdmKey = &tempKey;
									%put Note: A new key &tempKey in &temp domain, has been detected that did not get assigned at add study.;
								%end;
							%end;
							%let j = %eval(&j+1);
						%end;
						
					%end;
				%end;
			%end;

         data _null_;
            file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
            put "%nrstr(%global) &temp.KEYS;";
            put "%nrstr(%let) &temp.KEYS = &&&temp.KEYS;";
         run;
         
         data _null_;
            file "%FileWorkIt(&basemeta&_slash_.&temp.KEYS.txt)";
            %let j = 1;
            %do %while(%length(%scan(&&&temp.KEYS,&j," ")));
               %let tempvar = %scan(&&&temp.KEYS,&j," ");
               put "&tempvar";
               %let j = %eval(&j+1);                 
            %end;
         run;         
         
         %if ^&dflg %then %let dflg = 1;
      %end;
      %let i = %eval(&i+1);
   %end;

   data _null_;
      date = &CRDate;
      call symput("CRDateC", put(date, DATETIME19.));
      call symput("RDateC", put(datetime(), DATETIME19.));
   run;
   
   data _null_;
      file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
      put "%nrstr(%global) CRDate CRDateC RDateC;";
      put "%nrstr(%let) CRDate = &CRDate;";
      put "%nrstr(%let) CRDateC = %nrstr(%nrbquote)(&CRDateC);";
      put "%nrstr(%let) RDateC = %nrstr(%nrbquote)(&RDateC);";
   run;
   
   %global USUBJIDLabel COUNTRYLabel SITEIDLabel USUBJIDlength SITEIDlength COUNTRYlength SITEID COUNTRY;
   %let _tid_ = %sysfunc(open(%DataWorkIt(derimeta.TADSL)));
   %let vn = %sysfunc(varnum(&_tid_,USUBJID));
   %let vn2 = %sysfunc(varnum(&_tid_,SITEID));
   %let vn3 = %sysfunc(varnum(&_tid_,COUNTRY));
   %let USUBJIDlength = %sysfunc(varlength(&_tid_,&vn));
   %if &vn2 %then %let SITEIDlength = %sysfunc(varlength(&_tid_,&vn2));
   %else %let SITEIDlength = 0;
   %if &vn3 %then %let Countrylength = %sysfunc(varlength(&_tid_,&vn3));
   %else %let COUNTRYlength = 0;
   %let _tid_ = %sysfunc(close(&_tid_));
   %let USUBJIDLabel = USUBJID;
   %CheckLabel(%DataWorkIt(derimeta.TADSL),USUBJIDLabel);
   %let SITEID = ;
   %let COUNTRY = ;
   %if &vn2 %then %do;
      %let SITEIDLabel = SITEID;
      %CheckLabel(%DataWorkIt(derimeta.TADSL),SITEIDLabel);
      %let SITEID = SITEID;
   %end;
   %if &vn3 %then %do;
      %let COUNTRYLabel = COUNTRY;
      %CheckLabel(%DataWorkIt(derimeta.TADSL),COUNTRYLabel);
      %let COUNTRY = COUNTRY;
   %end;
   
   %if &ProcessName = AddStudyLocal %then %do;      
      data notes (encoding=utf8);
         length usubjid $ &USUBJIDlength 
            %if %length(&SiteID) %then %do; siteid $ &SITEIDlength %end; 
            %if %length(&country) %then %do; country $ &COUNTRYlength %end; 
            Study_Name $ 32 Report $ 60 Domain $ 8 Keys $ 200 Keys_Values $ 500 User $ 50 Note $ 1024 Type $ 24 SystemGenerated $ 1;
         Study_Name = "&StudyName";
         Report = "&trProcessName";
         User = "&sysuserid";
         Date_of_Note = datetime();
         SnapshotNumber = 0;
         Type = "&trSnapshot";
         Note = "&trSAtJC: &RDateC";
         SystemGenerated = "Y";
         output;
         Note = "&trMRDoIDC: &CRDateC";
         output;
         %if &SnpComp =Yes %then %do;
            Note = "&trSnapEnabled";
         %end;
         %else %do;
            Note = "&trSnapDisabled";
         %end;
         output;
         %if %length(&InPath) %then %do;
            Note = "&trSDTMFolder: &InPath";
            output;
         %end;
         %if %length(&AInPath) %then %do;
            Note = "&trADaMFolder: &AInPath";
            output;
         %end;
         format Date_of_Note DATETIME19.;
         label usubjid = "&USUBJIDLabel" 
            %if %length(&SiteID) %then %do; siteid = "&SITEIDlabel" %end; 
            %if %length(&Country) %then %do; Country = "&Countrylabel" %end;  
            Study_Name = "&trStudyName" Keys_Values = "&trKeysValues" Report = "&trReport" 
            Date_of_Note = "&trDateofNote" SnapshotNumber = "&trSnapshotNumber" Type = "&trType" Keys = "&_trKeys" 
            Domain = "&trDomain" User = "&trUser" Note = "&trNote" SystemGenerated = "&trSystemGenerated";
      run;   
      %if ^%sysfunc(fileexist(&NotesDir.&notesDataset..sas7bdat)) %then %do;
         data NotesLib.&notesDataset (encoding=utf8);
            retain SnapshotNumber Type usubjid %if %length(&SiteID) %then %do; siteid %end; 
               %if %length(&Country) %then %do; Country %end; Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated;
            set notes;
            %if %length(&SiteID) %then %do; 
               label siteid = "&SiteIDLabel";
            %end; 
            %if %length(&Country) %then %do; 
               label country = "&CountryLabel";
            %end; 
         run;
      %end;
      %else %do;      
         %UPDATELENGTH;         
         
         data notes (encoding=utf8);
            retain SnapshotNumber Type usubjid %if &notessiteid or %length(&SiteID) %then %do; siteid %end; 
               Study_Name %if &notescountry or %length(&Country) %then %do; country %end; Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated;
            length usubjid $ &USUBJIDlength 
                   %if &notessiteid or %length(&SiteID) %then %do; siteid $ &SITEIDlength %end;
                   %if &notescountry or %length(&Country) %then %do; country $ &COUNTRYlength %end;
                   ;               
            set notes NotesLib.&notesDataset;
            %if &notessiteid or %length(&SiteID) %then %do; 
               label siteid = "&SiteIDLabel";
            %end;
            %if &notescountry or %length(&Country) %then %do;
               label country = "&CountryLabel";
            %end;
         run;
         
         proc sort data = notes out = NotesLib.&notesDataset;
            by SnapshotNumber Date_of_Note;
         run;
      %end;    
         
      proc datasets nolist;
         delete notes;
      quit;                      
   %end;
   %else %if &ProcessName = ManageStudies and &NewSnap = YES %then %do;       
      *** S1561901 ***;
      %if ^%symexist(unmatchKeys) %then %let unmatchKeys = 0;
      %if &unmatchKeys = 0 %then %do;
         %let trReviewCR = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(ReviewX_Text)), f1=%nrbquote(&CurrentReview)));

         data notes (encoding=utf8);
            length usubjid $ &USUBJIDlength %if %length(&SiteID) %then %do; siteid $ &SITEIDlength %end; %if %length(&Country) %then %do; Country $ &Countrylength %end; 
               Study_Name $ 32 Report $ 60 Domain $ 8 Keys $ 200 Keys_Values $ 500 User $ 50 Note $ 1024 Type $ 24 SystemGenerated $ 1;
            Study_Name = "&StudyName";
            Report = "&trProcessName";
            User = "&sysuserid";
            Date_of_Note = datetime();
            SnapshotNumber = &CurrentReview;
            Type = "&trSnapshot";
            SystemGenerated = "Y";
            Note = "&trUSAtJC (&trReviewCR): &RDateC";
            output;
            Note = "&trMRDoIDC (&trReviewCR): &CRDateC";
            output;
            %if %length(&InPath) %then %do;
               Note = "&trSDTMFolder: &InPath";
               output;
            %end;
            %if %length(&AInPath) %then %do;
               Note = "&trADaMFolder: &AInPath";
               output;
            %end;            
            format Date_of_Note DATETIME19.;
            label usubjid = "&USUBJIDLabel" %if %length(&SiteID) %then %do; siteid = "&SITEIDlabel" %end; %if %length(&Country) %then %do; Country = "&Countrylabel" %end; 
               Study_Name = "&trStudyName" Keys_Values = "&trKeysValues" Report = "&trReport" Date_of_Note = "&trDateofNote" Type = "&trType" SnapshotNumber = "&trSnapshotNumber"
               Keys = "&_trKeys" Domain = "&trDomain" User = "&trUser" Note = "&trNote" SystemGenerated = "&trSystemGenerated";
         run;   

         %if ^%sysfunc(fileexist(&NotesDir.&notesDataset..sas7bdat)) %then %do;
            data NotesLib.&notesDataset (encoding=utf8);
               retain SnapshotNumber Type usubjid %if %length(&SiteID) %then %do; siteid %end; %if %length(&Country) %then %do; country %end; 
                  Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated;
               set notes;
               %if %length(&SiteID) %then %do; 
                  label siteid = "&SiteIDLabel";
               %end;                   
               %if %length(&Country) %then %do; 
                  label Country = "&CountryLabel";
               %end;                   
            run;
         %end;
         %else %do;
            %UPDATELENGTH;

            data notes (encoding=utf8);
               retain SnapshotNumber Type usubjid %if &notessiteid or %length(&SiteID) %then %do; siteid %end; %if &notescountry or %length(&country) %then %do; country %end; 
                  Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated;
               length usubjid $ &USUBJIDlength 
                      %if &notessiteid or %length(&SiteID) %then %do; siteid $ &SITEIDlength %end;
                      %if &notescountry or %length(&Country) %then %do; country $ &COUNTRYlength %end;
                      ;               
               set notes NotesLib.&notesDataset;
               %if &notessiteid or %length(&SiteID) %then %do; 
                  label siteid = "&SiteIDLabel";
               %end;
               %if &notescountry or %length(&country) %then %do; 
                  label Country = "&CountryLabel";
               %end;    
            run;

            proc sort data = notes out = NotesLib.&notesDataset;
               by SnapshotNumber Date_of_Note;
            run;
         %end;

         proc datasets nolist;
            delete notes;
         quit;
      %end;
   %end;
   %else %if &ProcessName = ManageStudies and &MigrateFlag = Y %then %do;      
      data notes (encoding=utf8);
         length usubjid $ &USUBJIDlength %if %length(&SiteID) %then %do; siteid $ &SITEIDlength %end; %if %length(&Country) %then %do; Country $ &Countrylength %end; 
            Study_Name $ 32 Report $ 60 Domain $ 8 Keys $ 200 Keys_Values $ 500 User $ 50 Note $ 1024 Type $ 24 SystemGenerated $ 1;
         Study_Name = "&StudyName";
         Report = "&trProcessName";
         User = "&sysuserid";
         SystemGenerated = "Y";
         Date_of_Note = datetime();
         SnapshotNumber = 0;
         Type = "&trSnapshot";
         Note = "&trSMtNVoJC: &RDateC";
         output;
         format Date_of_Note DATETIME19.;
         label usubjid = "&USUBJIDLabel" %if %length(&SiteID) %then %do; siteid = "&SITEIDlabel" %end; %if %length(&Country) %then %do; Country = "&Countrylabel" %end; 
            Study_Name = "&trStudyName" Keys_Values = "&trKeysValues" Report = "&trReport" Date_of_Note = "&trDateofNote" 
            SnapshotNumber = "&trSnapshotNumber" Type = "&trType" Keys = "&_trKeys" Domain = "&trDomain" User = "&trUser" Note = "&trNote" SystemGenerated = "&trSystemGenerated";
      run;   
         
      %if ^%sysfunc(fileexist(&NotesDir.&notesDataset..sas7bdat)) %then %do;
         data NotesLib.&notesDataset (encoding=utf8);
            retain SnapshotNumber Type usubjid %if %length(&SiteID) %then %do; siteid %end; %if %length(&country) %then %do; country %end; 
               Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated;
            set notes;
            %if %length(&SiteID) %then %do; 
               label siteid = "&SiteIDLabel";
            %end;
            %if %length(&Country) %then %do; 
               label Country = "&CountryLabel";
            %end;          
         run;
      %end;
      %else %do;
         %UPDATELENGTH;
         
         data notes (encoding=utf8);
            retain SnapshotNumber Type usubjid %if &notessiteid or %length(&SiteID) %then %do; siteid %end; %if &notescountry or %length(&country) %then %do; country %end; 
               Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated;
            length usubjid $ &USUBJIDlength 
                   %if &notessiteid or %length(&SiteID) %then %do; siteid $ &SITEIDlength %end;
                   %if &notescountry or %length(&Country) %then %do; country $ &COUNTRYlength %end;
                   ;               
            set notes NotesLib.&notesDataset;
            %if &notessiteid or %length(&SiteID) %then %do; 
               label siteid = "&SiteIDLabel";
            %end;
            %if &notescountry or %length(&country) %then %do;
               label Country = "&CountryLabel";
            %end;
         run;
         
         proc sort data = notes out = NotesLib.&notesDataset;
            by SnapshotNumber Date_of_Note;
         run;
      %end;
               
      proc datasets nolist;
         delete &notesDataset;
      quit;    
   %end;
   %exit:;
   %put Exiting KEYS;
   %ClockStop(KEYS);     
%mend KEYS; 

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro UPDATESUBJECTFLAGS(domlist = DM CO SE SV &findingsdomains &eventsdomains &interventionsdomains &adslpresent);
   %put Entering UPDATESUBJECTFLAGS;
   %ClockStart(UPDATESUBJECTFLAGS);        
   %include "&MacroPath./UtilityPathMacros.sas" / nosource;
   %let notesDataset=;
   %jg_getNotesDatasetName(notesDataset);
   %let domlist = %sysfunc(compbl(&domlist));
   %let studynameunder = %sysfunc(transtrn(&studyname, %str( ), _));
   %let availdom = ;
   %let i = 1;
   
   %let trNew = %nrbquote(%LocaleGet(New_Text));
   %let trModified = %nrbquote(%LocaleGet(Modified_Text));
   %let trStable = %nrbquote(%LocaleGet(Stable_Text));
   %let trDropped = %nrbquote(%LocaleGet(Dropped_Text));
   %let trNonUnique = %nrbquote(%LocaleGet(NonUnique_Text));
   %let trIntroduced = %nrbquote(%LocaleGet(Introduced_Text));
   %let trNewRecords = %nrbquote(%LocaleGet(NewRecords_Text));
   %let trManageStudies = %nrbquote(%LocaleGet(ManageStudies_Text));
   %let trJMPClinical = %nrbquote(%LocaleGet(JMPClinical_Text));
   %let trSubjHasNewRecs = %nrbquote(%LocaleGet(Subjecthasnewrecords_Text));
   %let trStudyName = %nrbquote(%LocaleGet(StudyName_Text));
   %let trKeysValues = %nrbquote(%LocaleGet(KeysValues_Text));
   %let trReport = %nrbquote(%LocaleGet(Report_Text));
   %let trDateofNote = %nrbquote(%LocaleGet(DateofNote_Text));
   %let trSnapshotNumber = %nrbquote(%LocaleGet(SnapshotNumber_Text));
   %let trType = %nrbquote(%LocaleGet(Type_Text));
   %let _trKeys = %nrbquote(%LocaleGet(Keys_Text));
   %let trDomain = %nrbquote(%LocaleGet(Domain_Text));
   %let trUser = %nrbquote(%LocaleGet(User_Text));
   %let trNote = %nrbquote(%LocaleGet(Note_Text));
   %let trSystemGenerated = %nrbquote(%LocaleGet(SystemGenerated_Text));
   
   *** identify subjects with new or modified data ***; 
   %do %while(%length(%scan(&domlist,&i,' ')));
      %let temp = %scan(&domlist,&i,' ');
         %if %sysfunc(findw(%upcase(&domains), &temp)) or &temp = ADSL %then %do;
            %let availdom = &availdom &temp;
            
            proc sort data = DeltaLib.&temp(keep = usubjid &temp.RFlg where = (&temp.RFlg in ("&trNew", "&trModified"))) nodupkey out = &temp(rename = (&temp.RFlg = Rflg));
               by usubjid &temp.RFlg;
            run;

            data &temp;
               set &temp;
               by usubjid RFlg;
               if last.usubjid;
            run;                                
         %end;
      %let i = %eval(&i+1);
   %end;
   
   data alldom;
      length usubjid $ &USUBJIDlength;
      set &availdom;
   run;
   
   proc datasets nolist;
      delete &availdom;
   quit;
   
   proc sort nodupkey data = alldom;
      by usubjid RFlg;
   run;
   
   data alldom;
      set alldom;
      by usubjid RFlg;
      if last.usubjid;
   run;
   
   proc sort data = NotesLib.adslrs out = adslrs;
      by usubjid;
   run;
   
   data _null_;
      set NotesLib.adslrsl(obs=1);
      call symput('defaultrs',trim(left(RSTATUS)));
   run;  

   data adslrs(drop = RFlg);
      merge adslrs(in = ina) alldom;
      by usubjid;
      if ina;
      if ReviewFlag ne "Introduced" & ReviewFlag ne "&trIntroduced" then do;
         if RFlg ne "" then do;
            ReviewFlag = catx(" ", RFlg, "Records");
            RSTATUS = "&defaultrs";
            DateUpdated = put(datetime(),E8601DT19.);
            User = "&sysuserid";
         end;
         else if RFlg = "" then ReviewFlag = "&trStable";
      end;
   run;
      
   data snotes(keep = SnapshotNumber Type usubjid Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated);
      length Study_Name $ 32 Report $ 60 Domain $ 8 Keys $ 200 Keys_Values $ 500 User $ 50 Note $ 1024 Type $ 24 SystemGenerated $ 1;
      set adslrs(where = (ReviewFlag = "&trNewRecords"));
      Study_Name = "&StudyName";
      Report = "&trManageStudies";
      SystemGenerated = "Y";
      Domain = "";
      Keys = "";
      SnapshotNumber = &CurrentReview;
      Type = "&trNewRecords";
      Keys_Values = "";
      User = "&sysuserid";
      Note = "&trSubjHasNewRecs";
      Date_of_Note = datetime();             
      format Date_of_Note DATETIME19.;
      label usubjid = "&USUBJIDLabel" Study_Name = "&trStudyName" Keys_Values = "&trKeysValues" Report = "&trReport" 
         Date_of_Note = "&trDateofNote" SnapshotNumber = "&trSnapshotNumber" Type = "&trType" Keys = "&_trKeys" Domain = "&trDomain" User = "&trUser" Note = "&trNote" SystemGenerated = "&trSystemGenerated";
   run;

   %if ^%sysfunc(fileexist(&NotesDir.&notesDataset..sas7bdat)) %then %do;
      data NotesLib.&notesDataset (encoding=utf8);
         retain SnapshotNumber Type usubjid %if %length(&SiteID) %then %do; siteid %end; %if %length(&country) %then %do; country %end; Study_Name Keys Keys_Values 
            Domain Report User Note Date_of_Note SystemGenerated;
         set snotes;
         %if %length(&SiteID) %then %do; 
            label siteid = "&SiteIDLabel";
         %end;                
         %if %length(&country) %then %do; 
            label country = "&countryLabel";
         %end;                
      run;
   %end;
   %else %do;
      %UPDATELENGTH;

      data snotes;
         retain SnapshotNumber Type usubjid %if %length(&SiteID) or &notessiteid %then %do; siteid %end; %if %length(&country) or &notescountry %then %do; country %end; 
            Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated;
         length usubjid $ &USUBJIDlength 
                %if &notessiteid or %length(&SiteID) %then %do; siteid $ &SITEIDlength %end;
                %if &notescountry or %length(&Country) %then %do; country $ &COUNTRYlength %end;
                ;            
         set snotes NotesLib.&notesDataset;
         %if &notessiteid or %length(&SiteID) %then %do; 
            label siteid = "&SiteIDLabel";
         %end;
         %if %length(&country) or &notescountry %then %do;
            label country = "&countryLabel";
         %end;
      run;

      proc sort data = snotes out = NotesLib.&notesDataset;
         by SnapshotNumber Date_of_Note;
      run;  
   %end;    
         
   proc datasets nolist;
      delete alldom;
   quit;
   
   *** Check if Dropped ***;
   proc sort data = &in_adsl out = adsl(keep = usubjid);
      by usubjid;
   run;
   
   data NotesLib.adslrs (encoding=utf8);
      retain USUBJID RSTATUS ReviewFlag DateAdded;
      merge adslrs(in = ina) adsl(in = inb);
      by usubjid;
      if ina;
      if ina and not inb then ReviewFlag = "&trDropped";
   run;     
   
   proc datasets nolist;
      delete adsl;
   quit;   
   %put Exiting UPDATESUBJECTFLAGS;
   %ClockStop(UPDATESUBJECTFLAGS);           
%mend UPDATESUBJECTFLAGS;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro DROPVARS;
   %if &ExclTrt = YES %then %do;
      %if ^%sysfunc(findw(%upcase(&&&temp.keys), ARM)) %then %do;
         if _name_ = "ARM" then delete;
      %end;
      %if ^%sysfunc(findw(%upcase(&&&temp.keys), ARMCD)) %then %do;
         if _name_ = "ARMCD" then delete;
      %end;
      %if ^%sysfunc(findw(%upcase(&&&temp.keys), ACTARM)) %then %do;
         if _name_ = "ACTARM" then delete;
      %end;
      %if ^%sysfunc(findw(%upcase(&&&temp.keys), ACTARMCD)) %then %do;
         if _name_ = "ACTARMCD" then delete;
      %end;                                                               
      %if &temp = EX %then %do;
         %if ^%sysfunc(findw(%upcase(&EXKEYS), EXTRT)) %then %do;
            if _name_ = "EXTRT" then delete;
         %end;
      %end;
      %if &temp = ADSL %then %do;
         %let j = 1;
         %do %while(%length(%scan(&ADSLTRTS,&j,' ')));
            %let temptrt = %upcase(%scan(&ADSLTRTS,&j,' '));
            %if ^%sysfunc(findw(%upcase(&ADSLKEYS), &temptrt)) %then %do;
               if _name_ = "&temptrt" then delete;
            %end;
            %let j = %eval(&j+1);
         %end;                        
      %end;                               
   %end;
   %if &ExclSpid = YES %then %do;
      %if ^%sysfunc(findw(%upcase(&&&temp.keys), &temp.SPID)) %then %do;
         if _name_ = "&temp.SPID" then delete;
      %end;                                       
   %end;
   %if &ExclSeq = YES %then %do;
      %if ^%sysfunc(findw(%upcase(&&&temp.keys), &temp.SEQ)) %then %do;
         if _name_ = "&temp.SEQ" then delete;
      %end;                                       
   %end;                  
   %if &ExclDom = YES %then %do;
      %if ^%sysfunc(findw(%upcase(&&&temp.keys), DOMAIN)) %then %do;
         if _name_ = "DOMAIN" then delete;
      %end;                                       
   %end;                  
   %if &ExclGrp = YES %then %do;
      %if ^%sysfunc(findw(%upcase(&&&temp.keys), &temp.GRPID)) %then %do;
         if _name_ = "&temp.GRPID" then delete;
      %end;                                       
   %end;
   %if &ExclRef = YES %then %do;
      %if ^%sysfunc(findw(%upcase(&&&temp.keys), &temp.REFID)) %then %do;
         if _name_ = "&temp.REFID" then delete;
      %end;                                       
   %end;                                    
   %if &ExclLnk = YES %then %do;
      %if ^%sysfunc(findw(%upcase(&&&temp.keys), &temp.LNKID)) %then %do;
         if _name_ = "&temp.LNKID" then delete;
      %end;                                       
   %end;
   %if &ExclLnkg = YES %then %do;
      %if ^%sysfunc(findw(%upcase(&&&temp.keys), &temp.LNKGRP)) %then %do;
         if _name_ = "&temp.LNKGRP" then delete;
      %end;                                       
   %end;
%mend DROPVARS;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro COMPARE(domlist = DM CO SE SV &findingsdomains &eventsdomains &interventionsdomains &adslpresent, managetwo = 0);
   %put Entering COMPARE;
   %ClockStart(COMPARE);        
   %let domlist = %sysfunc(compbl(&domlist));
   %let studynameunder = %sysfunc(transtrn(&studyname, %str( ), _));   
   %include "&MacroPath./UtilityPathMacros.sas" / nosource;   
   %let notesDataset=;
   %jg_getNotesDatasetName(notesDataset);

   %if &managetwo %then %do;
      %let mbd = %jg_getPath(/user/clinical/metadata/base, DeltaFile&CurrentReview..sas, 0, 0, 3, &studynameunder);
      %include "&mbd" / nosource;
   %end;
   
   %let trNew = %nrbquote(%LocaleGet(New_Text));
   %let trModified = %nrbquote(%LocaleGet(Modified_Text));
   %let trStable = %nrbquote(%LocaleGet(Stable_Text));
   %let trDropped = %nrbquote(%LocaleGet(Dropped_Text));
   %let trNonUnique = %nrbquote(%LocaleGet(NonUnique_Text));
   %let trNewSnapFreq = %nrbquote(%LocaleGet(NewSnapshotFrequency_Text));
   %let trManageStudies = %nrbquote(%LocaleGet(ManageStudies_Text));
   %let trJMPClinical = %nrbquote(%LocaleGet(JMPClinical_Text));
   %let trDuplicate = %nrbquote(%LocaleGet(Duplicate_Text));
   %let trStudyName = %nrbquote(%LocaleGet(StudyName_Text));
   %let trKeysValues = %nrbquote(%LocaleGet(KeysValues_Text));
   %let trReport = %nrbquote(%LocaleGet(Report_Text));
   %let trDateofNote = %nrbquote(%LocaleGet(DateofNote_Text));
   %let trSnapshotNumber = %nrbquote(%LocaleGet(SnapshotNumber_Text));
   %let trType = %nrbquote(%LocaleGet(Type_Text));
   %let _trKeys = %nrbquote(%LocaleGet(Keys_Text));
   %let trDomain = %nrbquote(%LocaleGet(Domain_Text));
   %let trUser = %nrbquote(%LocaleGet(User_Text));
   %let trNote = %nrbquote(%LocaleGet(Note_Text));
   %let trSystemGenerated = %nrbquote(%LocaleGet(SystemGenerated_Text));
   %let trXReviewFlag = %nrbquote(%LocaleGet(XReviewFlag_Text));
   %let trprevious = %nrbquote(%LocaleGet(previous_Text));
   %let trtimes = %nrbquote(%LocaleGet(times_Text));
   %let trlcnew = %nrbquote(%LocaleGet(new_Text));
   %let trDeftpk = %nrbquote(%LocaleGet(Duplicatesexistforthisparticularkey_Text));

   %if &managetwo %then %do;
      %let trDiffRforStudy = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(DifferencesReportforX_Text)), f1=%nrbquote(&StudyName)));
      %let trYes = %nrbquote(%LocaleGet(Yes_Text));
      %let trPrevSnapFreq = %nrbquote(%LocaleGet(PreviousSnapshotFrequency_Text));
      %let trMissing = %nrbquote(%LocaleGet(Missing_Text));
      %let trVciXfXtX = %nrbquote(%LocaleGet(ValuechangeinXfromXtoX_Text));
      %let trNCPBS = %nrbquote(%LocaleGet(Nocomparisonsperformedbetweensnapshots_Text));
      %let trVariable = %nrbquote(%LocaleGet(Variable_Text));
      %let trLabel = %nrbquote(%LocaleGet(Label_Text));
      %let trTPKWAIPDBNND = %nrbquote(%LocaleGet(ThisparticularkeywasAvailinPrevdatabutnotnewdata_Text));
      %let trRepX1 = %nrbquote(%LocaleGet(XColonDiffsinVarsBetwNewSnapAndPrevForModKeys_Text));
      %let trRepX2 = %nrbquote(%LocaleGet(XColonKeysWithDupsNoCompWereMadeifXNonUniq_Text));
      %let trRepX3 = %nrbquote(%LocaleGet(XColonDroppedKeysAvailInPrevDataButNotNewSnap_Text));
      %let trRepX4 = %nrbquote(%LocaleGet(NoteTheXdomainisnewlyavailable_Text));
      %let trRepX5 = %nrbquote(%LocaleGet(NoteXNewRecordsHaveBeenAddedintheXDomain_Text));
   %end;
   %else %do;
      %let trDKRforStudy = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(DuplicateandKeysReportforX_Text)), f1=%nrbquote(&StudyName)));
      %let trDKR1 = %nrbquote(%LocaleGet(DupKeysReportIntroMsgPart1_Text));
      %let trDKR2 = %nrbquote(%LocaleGet(DupKeysReportIntroMsgPart2_Text));
      %let trDKR3 = %nrbquote(%LocaleGet(DupKeysReportIntroMsgPart3_Text));
      %let trDKR4 = %nrbquote(%LocaleGet(DupKeysReportIntroMsgPart4_Text));
      %let trDKR5 = %nrbquote(%LocaleGet(DupKeysReportIntroMsgPart5_Text));
      %let trDKR6 = %nrbquote(%LocaleGet(DupKeysReportIntroMsgPart6_Text));
      %let trDKRIntro = &trDKR1 &trDKR2 &trDKR3 &trDKR4 &trDKR5 &trDKR6;
      %let trRep10 = %nrbquote(%LocaleGet(NoteKeysfortheXdomainColon_Text));
      %let trRep11 = %nrbquote(%LocaleGet(NoteKeysSuggAndUnavailForXDomainColon_Text));
      %let trRep12 = %nrbquote(%LocaleGet(XColonKeysWithDupsNoCompWereMadeifXNonUniq_Text));
      %let trRep13 = %nrbquote(%LocaleGet(NoteTherearenoduplicaterecordsfortheXdomain_Text));
   %end;
   
   *** Check for Directories ***;
   %jg_getPath(/user/clinical/delta,,3,0,0,&studynameunder);
   *** Delete Previous if Available ***;
   %let rc = %sysfunc(filename(fileref,%jg_getPath(/user/clinical/delta/dropped,,0,0,3,&studynameunder))) ;
   %if %sysfunc(fexist(&fileref)) %then %do;
      %RemoveDir(%jg_getPath(/user/clinical/delta/dropped,,0,0,3,&studynameunder));
      %let rc = %sysfunc(filename(fileref,%jg_getPath(/user/clinical/delta/dropped,,0,0,3,&studynameunder))) ;    
   %end;
   %let rc = %sysfunc(filename(fileref,%jg_getPath(/user/clinical/delta/modified,,0,0,3,&studynameunder))) ;
   %if %sysfunc(fexist(&fileref)) %then %do;
      %RemoveDir(%jg_getPath(/user/clinical/delta/modified,,0,0,3,&studynameunder));
      %let rc = %sysfunc(filename(fileref,%jg_getPath(/user/clinical/delta/modified,,0,0,3,&studynameunder))) ;   
   %end;
   %RemoveDir(%jg_getPath(/user/clinical/delta,,0,0,3,&studynameunder));
   libname DeltaLib "%jg_getPath(/user/clinical/delta,,3,0,3,&studynameunder)";
   
   data _null_;
      file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
      put "libname DeltaLib %nrstr(%')%jg_getPath(/user/clinical/delta,,0,0,3,&studynameunder)%nrstr(%');";
      put "%nrstr(%let) DeltaDir = %jg_getPath(/user/clinical/delta,,0,0,3,&studynameunder);";
   run;  

   options orientation = landscape nodate missing = "" sysprint="";
   ods escapechar = "^";
   ods listing close;

   %let ADSLpre = ;
   %let ADSLpost = ;
  
   %if &managetwo %then %do;   
      ods pdf file = "&ServerOutPath.&StudyName SnapShotDiffs.pdf" style = journal;

      *** get ADSL treatment list ***;
      %global ADSLTRTS;
      %let ADSLTRTS = ;
            
      %GetLevels(treatvars,name,ADSLTRTS,_nLvls=nidvar,_vType=vtype,_dropmiss = 1);        
   %end;
   %else %do;
      ods pdf file = "&ServerOutPath.&StudyName SnapShotDups.pdf" style = journal;
   %end;
      
   options notes;
   
   %let i = 1;
   %let first = 0;            
   %do %while(%length(%scan(&domlist,&i,' ')));
      %let temp = %scan(%upcase(&domlist),&i,' ');      
      %let trxrf = %nrbquote(%LocaleFill(%nrbquote(&trXReviewFlag), f1=%nrbquote(&temp)));
      %let predupcnt = 0;
      %let postdupcnt = 0;
      %let &temp.newcount = 0;
      
      %if %sysfunc(findw(%upcase(&domains), &temp)) or &temp = ADSL %then %do;      
         %let keyquote = %sysfunc(transtrn(&&&temp.keys, %str( ), %str(",")));      
         
         %if &managetwo %then %do;   
            %if &temp = ADSL %then %do;
               %if %scan(&in_adsl,2,'.') = DM %then %let ADSLpost = DM;
               %if %symexist(prev_adsl) %then %do;
                  %if %scan(&prev_adsl,2,'.') = DM %then %let ADSLpre = DM;
               %end;
            %end;
         %end;
         
         %if %symexist(in_&temp) and %symexist(prev_&temp) and ^%length(&ADSLpre) and ^%length(&ADSLpost) and &managetwo %then %do;         
            %if &temp = ADSL %then %do;
            	%let lib1 = %scan(&&Orig_&temp, 1, ".");
            %end;
            %else %do;
            	%let lib1 = %scan(&&in_&temp, 1, ".");
            %end;
            %let lib0 = %scan(&&prev_&temp, 1, ".");

            %if &InclSuppComp = YES %then %do;            
               %if &sysscp = WIN %then %do;
                  %let _slash_ = \;
               %end;
               %else %do;
                  %let _slash_ = /;
               %end;

               %if ^%sysfunc(findw(&suppdomains, %upcase(SUPP&temp))) %then %let tsuppprev = 0;
               %else %do;
                  %let rc = %sysfunc(filename(filrf,&basemeta));                                                                                                
                  %let did = %sysfunc(dopen(&filrf.));                                                                                                      
                     %let nfile = %sysfunc(dnum(&did.));                                                                                                  
                     %let tsuppprev = 0;
                     %do j = 1 %to &nfile.;
                         %if %index(%qupcase(%qsysfunc(dread(&did.,&j.))),TSUPP&temp) %then %let tsuppprev = 1;
                     %end;
                  %let rc=%sysfunc(dclose(&did.));
               %end;

               %if &tsuppprev %then %do;
                  %let j = 1;
                  %do %while(%length(%scan(&&&temp.SUPPIDVAR,&j,' ')));
                     %let idvartemp = %scan(&&&temp.SUPPIDVAR,&j,' ');               

                     %if &j = 1 %then %do;                        
                        %if &idvartemp = MISSING %then %do;
                        	* check if previous snapshot has transport files; 
                        	%let prev_domfolder = %scan(&&prev_&temp,1,'.');
                        	%let prev_dom = %scan(&&prev_&temp,2,'.');
                        	%let prev_domfolder_path=%sysfunc(pathname(&prev_domfolder));
                        	%let prev_domfolder_path=&prev_domfolder_path.\;
									
									%if ^%sysfunc(fileexist(&prev_domfolder_path.&prev_dom..sas7bdat)) %then %do;
										%if %sysfunc(fileexist(&prev_domfolder_path.&prev_dom..xpt)) %then %do;
											* transport previous xpt files ;											
											%if &prev_domfolder =prevsdtm %then %let prev_&temp = PrSDlib.&temp;
											%else %if &prev_domfolder =prevadsl %then %let prev_&temp = PrADlib.&temp;
										%end;
									%end;
                          	proc sort data = &&prev_&temp out = pre; 
                          	   by usubjid;
                          	run;                                             
                        %end;
                        %else %do;
                       		* check if previous snapshot has transport files; 
									%let prev_domfolder = %scan(&&prev_&temp,1,'.');
									%let prev_dom = %scan(&&prev_&temp,2,'.');
                        	%let prev_domfolder_path=%sysfunc(pathname(&prev_domfolder));
                        	%let prev_domfolder_path=&prev_domfolder_path.\;
                        	%if ^%sysfunc(fileexist(&prev_domfolder_path.&prev_dom..sas7bdat)) %then %do;
                        		%if %sysfunc(fileexist(&prev_domfolder_path.&prev_dom..xpt)) %then %do;
											%if &prev_domfolder =prevsdtm %then %let prev_&temp = PrSDlib.&temp;
											%else %if &prev_domfolder =prevadsl %then %let prev_&temp = PrADlib.&temp;
                        		%end;
                        	%end;
                           proc sort data = &&prev_&temp out = pre;
                              by usubjid &idvartemp;
                           run;                     
                        %end;
                     %end;
                     %else %do;
                        %if &idvartemp = MISSING %then %do;
                           proc sort data = pre out = pre;
                              by usubjid;
                           run;                                                
                        %end;
                        %else %do;
                           proc sort data = pre out = pre;
                              by usubjid &idvartemp;
                           run;                                                
                        %end;
                     %end;

                     %if &idvartemp = MISSING %then %do;                    
                        data pre;
                           merge pre(in = ina) %DataWorkIt(suppmeta.tsupp&temp._);
                           by usubjid;
                           if ina;
                        run;
                     %end;
                     %else %do;
                        data pre;
                           merge pre(in = ina) %DataWorkIt(suppmeta.tsupp&temp._&idvartemp);
                           by usubjid &idvartemp;
                           if ina;
                        run;
                     %end;
                     %let j = %eval(&j+1);
                  %end;

                  proc sort data = pre nouniquekey out = predup(keep = &&&temp.keys) uniqueout = prekeys;
                     by &&&temp.keys;
                  run;

                  proc datasets nolist;
                     delete pre;
                  quit;                                    
               %end;
               %else %do;  
						* check if previous snapshot has transport files; 
						%let prev_domfolder = %scan(&&prev_&temp,1,'.');
						%let prev_dom = %scan(&&prev_&temp,2,'.');
						%let prev_domfolder_path=%sysfunc(pathname(&prev_domfolder));
						%let prev_domfolder_path=&prev_domfolder_path.\;
						
						%if ^%sysfunc(fileexist(&prev_domfolder_path.&prev_dom..sas7bdat)) %then %do;
							%if %sysfunc(fileexist(&prev_domfolder_path.&prev_dom..xpt)) %then %do;
								%if &prev_domfolder =prevsdtm %then %let prev_&temp = PrSDlib.&temp;
								%else %if &prev_domfolder =prevadsl %then %let prev_&temp = PrADlib.&temp;
							%end;
						%end;						
                 	proc sort data = &&prev_&temp nouniquekey out = predup(keep = &&&temp.keys) uniqueout = prekeys;
                 	   by &&&temp.keys;
                 	run;                              
               %end;
               
               %if ^%sysfunc(findw(&suppdomains, %upcase(SUPP&temp))) %then %let tsupppost = 0;
               %else %do;
                  %let rc = %sysfunc(filename(filrf,&sdtmmeta));                                                                                                
                  %let did = %sysfunc(dopen(&filrf.));                                                                                                      
                     %let nfile = %sysfunc(dnum(&did.));                                                                                                  
                     %let tsupppost = 0;
                     %do j = 1 %to &nfile.;
                         %if %index(%qupcase(%qsysfunc(dread(&did.,&j.))),TSUPP&temp) %then %let tsupppost = 1;
                     %end;
                  %let rc=%sysfunc(dclose(&did.));
               %end;
               
               %if &tsupppost %then %do;
                  %let j = 1;
                  %do %while(%length(%scan(&&&temp.SUPPIDVAR,&j,' ')));
                     %let idvartemp = %scan(&&&temp.SUPPIDVAR,&j,' ');               

                     %if &j = 1 %then %do;
                        %if &idvartemp = MISSING %then %do;
                           proc sort data = %if &temp = ADSL %then &&Orig_&temp; %else &&in_&temp; out = post;
                              by usubjid;
                           run;
                        %end;
                        %else %do;
                           proc sort data = %if &temp = ADSL %then &&Orig_&temp; %else &&in_&temp; out = post;
                              by usubjid &idvartemp;
                           run;
                        %end;
                     %end;
                     %else %do;
                        %if &idvartemp = MISSING %then %do;
                           proc sort data = post out = post;
                              by usubjid;
                           run;
                        %end;
                        %else %do;
                           proc sort data = post out = post;
                              by usubjid &idvartemp;
                           run;
                        %end;
                     %end;

                     %if &idvartemp = MISSING %then %do;
                        data post;
                           merge post(in = ina) %DataWorkIt(suppmeta.tsupp&temp._);
                           by usubjid;
                           if ina;
                        run;
                     %end;
                     %else %do;
                        data post;
                           merge post(in = ina) %DataWorkIt(suppmeta.tsupp&temp._&idvartemp);
                           by usubjid &idvartemp;
                           if ina;
                        run;
                     %end;

                     %let j = %eval(&j+1);
                  %end;

                  proc sort data = post nouniquekey out = postdup(keep = &&&temp.keys) uniqueout = postkeys;
                     by &&&temp.keys;
                  run;

                  proc datasets nolist;
                     delete post;
                  quit;                                    
               %end;
               %else %do;               
                  proc sort data = %if &temp = ADSL %then &&Orig_&temp; %else &&in_&temp; nouniquekey out = postdup(keep = &&&temp.keys) uniqueout = postkeys;
                     by &&&temp.keys;
                  run;                              
               %end;               
            %end;
            %else %do;
               *** Only Keys ***;
               *** Separate Duplicates ***;
               *** Unique Set of Previous Keys (Excluding Dups) ***;
               
               * check if previous snapshot has transport files; 
					%let prev_domfolder = %scan(&&prev_&temp,1,'.');
					%let prev_dom = %scan(&&prev_&temp,2,'.');
					%let prev_domfolder_path=%sysfunc(pathname(&prev_domfolder));
					%let prev_domfolder_path=&prev_domfolder_path.\;
					%if ^%sysfunc(fileexist(&prev_domfolder_path.&prev_dom..sas7bdat)) %then %do;
						%if %sysfunc(fileexist(&prev_domfolder_path.&prev_dom..xpt)) %then %do;
							%if &prev_domfolder =prevsdtm %then %let prev_&temp = PrSDlib.&temp;
							%else %if &prev_domfolder =prevadsl %then %let prev_&temp = PrADlib.&temp;
						%end;
					%end;
					
               proc sort data = &&prev_&temp nouniquekey out = predup(keep = &&&temp.keys) uniqueout = prekeys;
                  by &&&temp.keys;
               run;

               *** Only Keys ***;
               *** Separate Duplicates ***;
               *** Unique Set of Post Keys (Excluding Dups) ***;
               proc sort data = %if &temp = ADSL %then &&Orig_&temp; %else &&in_&temp; nouniquekey out = postdup(keep = &&&temp.keys) uniqueout = postkeys;
                  by &&&temp.keys;
               run;
            %end;
                        
            *** Get Keys with Differences ***;
            proc compare base = prekeys compare = postkeys noprint outnoequal out = diffies(keep = &&&temp.keys);
               id &&&temp.keys;
            run;
            
            *** Subset Data to Keys with Differences ***;
            data pre;
               if 0 then set diffies;
               if _n_ = 1 then do;
               declare hash h(dataset:"diffies");
                  h.defineKey("&keyquote");
                  h.defineData(ALL:"YES");
                  h.defineDone();
               end;
               set prekeys;
               if h.find() = 0;
            run;
            %Nobsvars(pre);
            %let precnt = &nobs;

            data post;
               if 0 then set diffies;
               if _n_ = 1 then do;
               declare hash h(dataset:"diffies");
                  h.defineKey("&keyquote");
                  h.defineData(ALL:"YES");
                  h.defineDone();
               end;
               set postkeys;
               if h.find() = 0;
            run;            
            %Nobsvars(post);
            %let postcnt = &nobs;
   
            %if %upcase(%substr(%sysfunc(getoption(locale)),1,2)) = ZH %then %do;
               proc sort data =predup force;
                  by &&&temp.keys;
               run;
               
               proc sort data =prekeys force;
                  by &&&temp.keys;
               run;

               proc sort data =pre force;
                  by &&&temp.keys;
               run;

               proc sort data =postdup force;
                  by &&&temp.keys;
               run;

               proc sort data =postkeys force;
                  by &&&temp.keys;
               run;

               proc sort data =post force;
                  by &&&temp.keys;
               run;                              
            %end;

            *** Get Count of Previous Duplicates ***;
            data predup;
               set predup;
               by &&&temp.keys;
               retain PreCount;
               if first.%scan(&&&temp.keys, -1, ' ') then PreCount = 1;
               else PreCount = PreCount + 1;
               if last.%scan(&&&temp.keys, -1, ' ');
               keep &&&temp.keys PreCount;
               label PreCount = "&trPrevSnapFreq";
            run;
            %Nobsvars(predup);
            %let predupcnt = &nobs;
            
            proc transpose data = pre out = prec(%if &precnt %then %do; rename = (col1 = prec) %end;);
               by &&&temp.keys;
               var _character_;
            run;

            proc transpose data = pre out = pren(%if &precnt %then %do; rename = (col1 = pren) %end;);
               by &&&temp.keys;
               var _numeric_;
            run;

            *** Previous Data ***;
            data pre;
               set prec(in = ina) pren(in = inb);
               if ina then Ptype = "C";
               else if inb then Ptype = "N";
               label prec = "Previous Character Values" pren = "Previous Numeric Values" _name_ = "Variable Name" 
                  _label_ = "Variable Label" Ptype = "Previous Type";
            run;

            proc datasets nolist;
               delete prec pren;
            quit;

            proc sort data = pre;
               by &&&temp.keys _name_;
            run;

            *** Get Count of Post Duplicates ***;
            data postdup;
               set postdup;
               by &&&temp.keys;
               retain PostCount;
               if first.%scan(&&&temp.keys, -1, ' ') then PostCount = 1;
               else PostCount = PostCount + 1;
               if last.%scan(&&&temp.keys, -1, ' ');
               keep &&&temp.keys PostCount;
               label PostCount = "&trNewSnapFreq";
            run;
            %Nobsvars(postdup);
            %let postdupcnt = &nobs;            

            proc transpose data = post out = postc(%if &postcnt %then %do; rename = (col1 = postc) %end;);
               by &&&temp.keys;
               var _character_;
            run;

            proc transpose data = post out = postn(%if &postcnt %then %do; rename = (col1 = postn) %end;);
               by &&&temp.keys;
               var _numeric_;
            run;

            *** Post Data ***;
            data post;
               set postc(in = ina) postn(in = inb);
               if ina then Ntype = "C";
               else if inb then Ntype = "N";
               label postc = "New Character Values" postn = "New Numeric Values" _name_ = "Variable Name" 
                   _label_ = "Variable Label" Ntype = "New Type";
            run;

            proc datasets nolist;
               delete postc postn;
            quit;

            proc sort data = post;
               by &&&temp.keys _name_;
            run;

            /*%if %nrbquote(%lowcase(%substr(%sysfunc(getoption(locale)),1,2))) = %nrbquote(zh) %then %do;*/
            * In Chinese, the column length for prekeys and postkeys are different, then create problem S1010544;
            * Also a problem for English S1561902 21Feb2020(b);
               %let tempkeyflag=0;
                  %let _i_=1;             
               %do %while (%length(%scan(&&&temp.keys,&_i_)));
                  %let tempkeyScan = %scan(&&&temp.keys,&_i_);
                  %let ds = %sysfunc(open(prekeys));
                  %let PreLen&_i_ = %sysfunc(varlen(&ds,%sysfunc(varnum(&ds,&tempkeyScan))));
                  %let tempKeysType&_i_=%sysfunc(vartype(&ds,&_i_));
                  %let rc = %sysfunc(close(&ds)); 
                  %let _i_ = %eval(&_i_+1);
               %end; 
               %let _i_=1;             
               %do %while (%length(%scan(&&&temp.keys,&_i_)));
                  %let tempkeyScan = %scan(&&&temp.keys,&_i_);
                  %let ds = %sysfunc(open(postkeys));
                  %let PostLen&_i_ = %sysfunc(varlen(&ds,%sysfunc(varnum(&ds,&tempkeyScan))));
                  %let rc = %sysfunc(close(&ds)); 
                  %let _i_ = %eval(&_i_+1);
               %end;
               %let tempLen=;
               %let _i_=1; 
               %do %while (%length(%scan(&&&temp.keys,&_i_)));
                  %if &&tempKeysType&_i_ = C %then %do;
                     %if %length(&&PreLen&_i_) & %length(&&PostLen&_i_) & &&PreLen&_i_ < &&PostLen&_i_ %then %do;
                        %let tempLen=&tempLen  %scan(&&&temp.keys,&_i_);
                        %let tempLen= &tempLen $ &&PostLen&_i_;
                        %let tempkeyflag=1;
                     %end;
                  %end;
                  %let _i_= %eval(&_i_+1);
               %end;
               data keys;
                  length &temp.RFlg $ 16 %if &tempkeyflag %then &tempLen;;
                     merge prekeys(in = ina keep = &&&temp.keys) postkeys(in = inb keep = &&&temp.keys);
                  by &&&temp.keys;
                  if ina and not inb then &temp.RFlg = "&trDropped";
                  else if inb and not ina then &temp.RFlg = "&trNew"; 
                  label &temp.RFlg = "&trxrf";
               run;
            /*%end;
            %else %do;
               *** Identify Keys that are New or Dropped (Excluding Dups)***;
               data keys;
                  length &temp.RFlg $ 16;
                     merge prekeys(in = ina keep = &&&temp.keys) postkeys(in = inb keep = &&&temp.keys);
                  by &&&temp.keys;
                  if ina and not inb then &temp.RFlg = "&trDropped";
                  else if inb and not ina then &temp.RFlg = "&trNew"; 
                  label &temp.RFlg = "&trxrf";
               run;
            %end;*/

            %if %nrbquote(%lowcase(%substr(%sysfunc(getoption(locale)),1,2))) = %nrbquote(zh) %then %do;
            * In Chinese, the column length for prepost and keys are different, then create problem S1010544;
               %let tempkeyflg=0;
                  %let _i_=1;             
               %do %while (%length(%scan(&&&temp.keys,&_i_)));
                  %let tempkeyScan = %scan(&&&temp.keys,&_i_);
                  %let ds = %sysfunc(open(pre));
                  %if %sysfunc(varnum(&ds,&tempkeyScan)) %then %do;
                     %let PreLen&_i_ = %sysfunc(varlen(&ds,%sysfunc(varnum(&ds,&tempkeyScan))));
                     %let tempKeysType&_i_=%sysfunc(vartype(&ds,&_i_));
                  %end;
                  %let rc = %sysfunc(close(&ds)); 
                  %let _i_ = %eval(&_i_+1);
               %end; 
               %let _i_=1;             
               %do %while (%length(%scan(&&&temp.keys,&_i_)));
                  %let tempkeyScan = %scan(&&&temp.keys,&_i_);
                  %let ds = %sysfunc(open(post));
                  %if %sysfunc(varnum(&ds,&tempkeyScan)) %then %do;
                     %let PostLen&_i_ = %sysfunc(varlen(&ds,%sysfunc(varnum(&ds,&tempkeyScan))));
                     %let tempKeysType&_i_=%sysfunc(vartype(&ds,&_i_));
                  %end;
                  %let rc = %sysfunc(close(&ds)); 
                  %let _i_ = %eval(&_i_+1);
               %end;
               %let tempLen=;
               %let _i_=1; 
               %do %while (%length(%scan(&&&temp.keys,&_i_)));
                  %if &&tempKeysType&_i_ = C %then %do;
                     %if %symexist(PreLen&_i_) & %symexist(PostLen&_i_) %then %do;
                        %if %length(&&PreLen&_i_) & %length(&&PostLen&_i_) & &&PreLen&_i_ < &&PostLen&_i_ %then %do;
                           %let tempLen=&tempLen  %scan(&&&temp.keys,&_i_);
                           %let tempLen= &tempLen $ &&PostLen&_i_;
                           %let tempkeyflg=1;
                        %end;
                     %end;
                  %end;
                  %let _i_= %eval(&_i_+1);
               %end;
               data prepost;
                  %if &tempkeyflg %then %do;
                     length &tempLen;
                  %end;
                  merge pre(in = ina) post(in = inb);
                  by &&&temp.keys _name_;
                  if (ntype = "C" and prec ne postc) or (ntype = "N" and pren ne postn);
                  %DROPVARS;
               run;
            %end;
            %else %do;
               *** Identify Any Differences Between Variables ***;
               data prepost;
                  merge pre(in = ina) post(in = inb);
                  by &&&temp.keys _name_;
                  if (ntype = "C" and prec ne postc) or (ntype = "N" and pren ne postn);
                  %DROPVARS;
               run;
            %end;

            *** Identify Keys with Differences Between Variables ***;
            proc sort data = prepost(keep = &&&temp.keys) nodupkey out = ppkeys;
               by &&&temp.keys;
            run;

            *** Combine Duplicates to get Pre-Post Counts ***;
            %if %nrbquote(%lowcase(%substr(%sysfunc(getoption(locale)),1,2))) = %nrbquote(zh) %then %do;
               %let tempkeyflg=0;
               %let _i_=1;             
               %do %while (%length(%scan(&&&temp.keys,&_i_)));
                  %let tempkeyScan = %scan(&&&temp.keys,&_i_);
                  %let ds = %sysfunc(open(predup));
                  %if %sysfunc(varnum(&ds,&tempkeyScan)) %then %do;
                     %let PreLen&_i_ = %sysfunc(varlen(&ds,%sysfunc(varnum(&ds,&tempkeyScan))));
                     %let tempKeysType&_i_=%sysfunc(vartype(&ds,&_i_));
                  %end;
                  %let rc = %sysfunc(close(&ds)); 
                  %let _i_ = %eval(&_i_+1);
               %end; 
               %let _i_=1;             
               %do %while (%length(%scan(&&&temp.keys,&_i_)));
                  %let tempkeyScan = %scan(&&&temp.keys,&_i_);
                  %let ds = %sysfunc(open(postdup));
                  %if %sysfunc(varnum(&ds,&tempkeyScan)) %then %do;
                     %let PostLen&_i_ = %sysfunc(varlen(&ds,%sysfunc(varnum(&ds,&tempkeyScan))));
                     %let tempKeysType&_i_=%sysfunc(vartype(&ds,&_i_));
                  %end;
                  %let rc = %sysfunc(close(&ds)); 
                  %let _i_ = %eval(&_i_+1);
               %end;
               %let tempLen=;
               %let _i_=1; 
               %do %while (%length(%scan(&&&temp.keys,&_i_)));
                  %if &&tempKeysType&_i_ = C %then %do;
                     %if %symexist(PreLen&_i_) & %symexist(PostLen&_i_) %then %do;
                        %if %length(&&PreLen&_i_) & %length(&&PostLen&_i_) & &&PreLen&_i_ < &&PostLen&_i_ %then %do;
                           %let tempLen=&tempLen  %scan(&&&temp.keys,&_i_);
                           %let tempLen= &tempLen $ &&PostLen&_i_;
                           %let tempkeyflg=1;
                        %end;
                     %end;
                  %end;
                  %let _i_= %eval(&_i_+1);
               %end;
               data dupkeys;
                  %if &tempkeyflg %then %do;
                     length &tempLen;
                  %end;
                  merge predup postdup;
                  by &&&temp.keys;
                  if PreCount = . then PreCount = 0;
                  if PostCount = . then PostCount = 0;
               run;
            %end;
            %else %do;
               data dupkeys;
                  merge predup postdup;
                  by &&&temp.keys;
                  if PreCount = . then PreCount = 0;
                  if PostCount = . then PostCount = 0;
               run;
            %end;

            *** Identify Any Differences Between Variables (Excluding Dups) ***;
            data keys;
               merge keys(in = ina) ppkeys(in = inb);
               by &&&temp.keys;
               if inb and &temp.RFlg = "" then &temp.RFlg = "&trModified";
               else if not inb and &temp.RFlg = "" then &temp.RFlg = "&trStable";

            run;

            *** Define Duplicate Type ***;
            data keys;
               retain Domain &&&temp.keys PreCount PostCount &temp.RFlg;
               length domain $ 8 &temp.RFlg $ 16;
               merge keys(in = ina) dupkeys(in = inb);
               by &&&temp.keys;
               Domain = "&temp";
               if inb then do;
                 if PreCount = 0 then &temp.RFlg = "&trNew";
                 else if PostCount = 0 then &temp.RFlg = "&trDropped";
                 else &temp.RFlg = "&trNonUnique";
               end;
               %if ^&predupcnt %then %do;
                  drop PreCount;
               %end;
               %if ^&postdupcnt %then %do;
                  drop PostCount;
               %end;
            run;

            proc datasets nolist;
               delete postkeys post postdup prekeys pre predup ppkeys dupkeys;
            quit;
         %end;
         %else %if (((&temp ne ADSL and ^%symexist(prev_&temp)) or (&temp = ADSL and %length(&ADSLpre) and ^%length(&ADSLpost)) or 
            (&temp = ADSL and ^%length(&ADSLpre) and ^%length(&ADSLpost))) and &managetwo) or (((&temp ne ADSL) or (&temp = ADSL and %length(&adslpresent))) and ^&managetwo) %then %do;
        
            %if &temp = ADSL and &managetwo %then %do;         
               data _null_;
                  file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
                  put "%nrstr(%global) ADSLNewFlag;";
                  put "%nrstr(%let) ADSLNewFlag = &trYes;";
               run;
            %end;
         
            *** Only Keys ***;
            *** Separate Duplicates ***;
            *** Unique Set of Post Keys (Excluding Dups) ***;
            proc sort data = &&in_&temp(keep = &&&temp.keys) nouniquekey out = postdup uniqueout = postkeys;
               by &&&temp.keys;
            run;
                  
            %if %upcase(%substr(%sysfunc(getoption(locale)),1,2)) = ZH %then %do;
               proc sort data =postdup force;
                  by &&&temp.keys;
               run;

               proc sort data =postkeys force;
                  by &&&temp.keys;
               run;
            %end;            

            *** Get Count of Post Duplicates ***;
            data postdup;
               set postdup;
               by &&&temp.keys;
               retain PostCount;
               if first.%scan(&&&temp.keys, -1, ' ') then PostCount = 1;
               else PostCount = PostCount + 1;
               if last.%scan(&&&temp.keys, -1, ' ');
               keep &&&temp.keys PostCount;
               label PostCount = "&trNewSnapFreq";
            run;
            %Nobsvars(postdup);
            %let postdupcnt = &nobs;
            
            %if ^&managetwo %then %do;
               %if &postdupcnt > 2000 %then %do;
                  %global snpCompDup;
                  %let snpCompDup=&postdupcnt;
               %end;
            %end;

            *** Identify Keys that are New (Excluding Dups)***;
            data keys;
               length &temp.RFlg $ 16;
                  set postkeys;
               &temp.RFlg = "&trNew"; 
               label &temp.RFlg = "&trxrf";
            run;

            *** Define Duplicate Type ***;
            data keys;
               retain Domain &&&temp.keys PostCount &temp.RFlg;
               length domain $ 8 &temp.RFlg $ 16;
               merge keys(in = ina) postdup(in = inb);
               by &&&temp.keys;
               Domain = "&temp";
               if inb then &temp.RFlg = "&trNew";
               %if ^&postdupcnt %then %do;
                  drop PostCount;
               %end;
            run;

            proc datasets nolist;
               delete postkeys post postdup;
            quit;
         %end;

         %if ((&temp ne ADSL) or (&temp = ADSL and %length(&ADSLpre) and ^%length(&ADSLpost)) or (&temp = ADSL and ^%length(&ADSLpre) and ^%length(&ADSLpost))) and &managetwo %then %do;
            *** Save Keys ***;         
            data DeltaLib.&temp;
               set keys;
            run;

            %let rschk = %sysfunc(open(keys));
            %let prechk = %sysfunc(varnum(&rschk,PreCount));
            %let postchk = %sysfunc(varnum(&rschk,PostCount));
            %let rschk = %sysfunc(close(&rschk));
            %let PreCount =;
            %let PostCount =;
            %if &PreChk %then %let PreCount = PreCount; 
            %if &PostChk %then %let PostCount = PostCount; 

            data dropped(keep = &&&temp.keys);
               set keys(where = (&temp.RFlg = "&trDropped"));
            run; 
            %Nobsvars(dropped);

            %if &nobs %then %do;
               %jg_getPath(/user/clinical/delta/dropped,,3,0,0,&studynameunder);  
               libname Dropped "%jg_getPath(/user/clinical/delta/dropped,,0,0,3,&studynameunder)";

               *** Subset Data to Dropped Records ***;
               data Dropped.&temp;
                  if 0 then set dropped;
                  if _n_ = 1 then do;
                  declare hash h(dataset:"dropped");
                     h.defineKey("&keyquote");
                     h.defineData(ALL:"YES");
                     h.defineDone();
                  end;
                  set &&prev_&temp;
                  if h.find() = 0;
               run;           
            %end;

            proc datasets nolist;
               delete dropped;
            quit;
         %end;

         %if %symexist(in_&temp) and %symexist(prev_&temp) and ^%length(&ADSLpre) and ^%length(&ADSLpost) and &managetwo %then %do;
            %if %nrbquote(%lowcase(%substr(%sysfunc(getoption(locale)),1,2))) = %nrbquote(zh) %then %do;
            * In Chinese, the column length for prepost and keys are different, then create problem S1010544;
               %let tempkeyflg=0;
                  %let _i_=1;             
               %do %while (%length(%scan(&&&temp.keys,&_i_)));
                  %let tempkeyScan = %scan(&&&temp.keys,&_i_);
                  %let ds = %sysfunc(open(prepost));
                  %if %sysfunc(varnum(&ds,&tempkeyScan)) %then %do;
                     %let PreLen&_i_ = %sysfunc(varlen(&ds,%sysfunc(varnum(&ds,&tempkeyScan))));
                     %let tempKeysType&_i_=%sysfunc(vartype(&ds,&_i_));
                  %end;
                  %let rc = %sysfunc(close(&ds)); 
                  %let _i_ = %eval(&_i_+1);
               %end; 
               %let _i_=1;             
               %do %while (%length(%scan(&&&temp.keys,&_i_)));
                  %let tempkeyScan = %scan(&&&temp.keys,&_i_);
                  %let ds = %sysfunc(open(keys));
                  %if %sysfunc(varnum(&ds,&tempkeyScan)) %then %do;
                     %let PostLen&_i_ = %sysfunc(varlen(&ds,%sysfunc(varnum(&ds,&tempkeyScan))));
                     %let tempKeysType&_i_=%sysfunc(vartype(&ds,&_i_));
                  %end;
                  %let rc = %sysfunc(close(&ds)); 
                  %let _i_ = %eval(&_i_+1);
               %end;
               %let tempLen=;
               %let _i_=1; 
               %do %while (%length(%scan(&&&temp.keys,&_i_)));
                  %if &&tempKeysType&_i_ = C %then %do;
                     %if %symexist(PreLen&_i_) & %symexist(PostLen&_i_) %then %do;
                        %if %length(&&PreLen&_i_) & %length(&&PostLen&_i_) & &&PreLen&_i_ < &&PostLen&_i_ %then %do;
                           %let tempLen=&tempLen  %scan(&&&temp.keys,&_i_);
                           %let tempLen= &tempLen $ &&PostLen&_i_;
                           %let tempkeyflg=1;
                        %end;
                     %end;
                  %end;
                  %let _i_= %eval(&_i_+1);
               %end;
               data prepost;
                  %if &tempkeyflg %then %do;
                  length &tempLen;
                  %end;
                  merge prepost keys(keep = &&&temp.keys &temp.RFlg);
                  by &&&temp.keys;
               run;
            %end;
            %else %do;
               data prepost;
                  merge prepost keys(keep = &&&temp.keys &temp.RFlg);
                  by &&&temp.keys;
               run;
            %end;

            %let _tid_ = %sysfunc(open(prepost));
            %let vn = %sysfunc(varnum(&_tid_,_label_));
            %let _label_len = %sysfunc(varlength(&_tid_,&vn));
            %let _tid_ = %sysfunc(close(&_tid_));

            %let trXDiffsVarsNPMK = %nrbquote(%LocaleFill(%nrbquote(&trRepX1), f1=%nrbquote(&temp)));
            %let HasRows = 0;
            data _null_;
               set prepost;
               if &temp.RFlg = "&trModified" then do;
                  call symput('HasRows',1);
                  stop;
               end;
            run;
            %if &HasRows %then %do;
               ods startpage = now;
               /*ods pdf text = "^S={font=('Arial',9pt,bold italic) just=center} &trXDiffsVarsNPMK";
               ods pdf text = "^S={font=('Arial')}";*/
               title "&trXDiffsVarsNPMK";
               proc print width = min noobs label data = prepost 
                  style(bylabel) = [fontsize = 7pt] style(header) = [fontsize = 7pt] style(obs) = [font_size = 7pt] style(obsheader) = [font_size = 7pt];
                  var &&&temp.keys _name_ %if %length(&_label_len) %then _label_; prec postc pren postn / style(data) = [font_size = 7pt] style(header) = [background=white font_size = 7pt];                           
                  where &temp.RFlg = "&trModified";
               run;
               title;
            %end;

            %let trXKWDupsNCXNU = %nrbquote(%LocaleFill(%nrbquote(&trRepX2), f1=%nrbquote(&temp), f2=%nrbquote(&temp.RFlg)));
            %let HasRows = 0;
            data _null_;
               set keys;
               if index(&temp.RFlg, "&trNonUnique")
                  %if %length(&PostCount) %then %do;
                     or &PostCount > .
                  %end;          
                  %if %length(&PreCount) %then %do;
                     or &PreCount > .
                  %end;
                     then do;
                        call symput('HasRows',1);
                        stop;
               end;
            run;
            %if &HasRows %then %do;
               ods startpage = now;
               /*ods pdf text = "^S={font=('Arial',9pt,bold italic) just=center} &trXKWDupsNCXNU";
               ods pdf text = "^S={font=('Arial')}";*/
               title "&trXKWDupsNCXNU";
               proc print width = min noobs label data = keys 
                  style(bylabel) = [font_size = 7pt] style(obs) = [font_size = 7pt] style(obsheader) = [font_size = 7pt];
                  var &&&temp.keys &temp.RFlg &PreCount &PostCount / style(data) = [font_size = 7pt] style(header) = [background=white font_size = 7pt];          
                  where index(&temp.RFlg, "&trNonUnique")
                  %if %length(&PostCount) %then %do;
                     or &PostCount > .
                  %end;          
                  %if %length(&PreCount) %then %do;
                     or &PreCount > .
                  %end;          
                  ;
               run;
               title;
            %end;

            %let trXDroppedKeys = %nrbquote(%LocaleFill(%nrbquote(&trRepX3), f1=%nrbquote(&temp)));
            %let HasRows = 0;
            data _null_;
               set keys;
               if index(&temp.RFlg, "&trDropped") then do;
                  call symput('HasRows',1);
                  stop;
               end;
            run;
            %if &HasRows %then %do;
               ods startpage = now;
               /*ods pdf text = "^S={font=('Arial',9pt,bold italic) just=center} &trXDroppedKeys";
               ods pdf text = "^S={font=('Arial')}";*/
               title "&trXDroppedKeys";
               proc print width = min noobs label data = keys 
                  style(bylabel) = [font_size = 7pt] style(obs) = [font_size = 7pt] style(obsheader) = [font_size = 7pt];
                  var &&&temp.keys &temp.RFlg / style(data) = [font_size = 7pt] style(header) = [background=white font_size = 7pt];          
                  where index(&temp.RFlg, "&trDropped");
               run;
               title;
            %end;

				*** Get the count of new records ***;
				data new_prepost;
					set prepost(where = (&temp.RFlg = "&trNew"));
				run;
				%Nobsvars(new_prepost);
				%let &temp.newCount = &nobs;
				%put new record count= &&&temp.newCount;
				%if &nobs %then %do;
					%let trNXDomNewRec = %nrbquote(%LocaleFill(%nrbquote(&trRepX5), f1=%nrbquote(&nobs),f2=%nrbquote(&temp)));
					title;
					ods pdf text = "^S={font=('Arial')}";
            	ods pdf text = "^S={font=('Arial')}";
            	ods pdf text = "^S={font=('Arial') just=center} ----------------------------------------------------------------------";
            	ods pdf text = "^S={font=('Arial') just=center} &trNXDomNewRec";
            	ods pdf text = "^S={font=('Arial') just=center} ----------------------------------------------------------------------";
            	ods pdf text = "^S={font=('Arial')}";
            	ods pdf text = "^S={font=('Arial')}";
            %end;
				
            *** Save Notes of Modifications ***;

            data mnotes(keep = SnapshotNumber Type usubjid Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated &&&temp.keys _name_ _label_);
               length Study_Name $ 32 Report $ 60 Domain $ 8 Keys $ 200 Keys_Values $ 500 User $ 50 Note $ 1024 Type $ 24 SystemGenerated $ 1;
               set prepost(where = (&temp.RFlg = "&trModified"));
               Study_Name = "&StudyName";
               Report = "&trManageStudies";
               Domain = "&temp";
               Keys = "&&&temp.keys";
               SnapshotNumber = &CurrentReview;
               Type = "&trModified";
               Keys_Values = catx("~", %sysfunc(transtrn(%str(&&&temp.keys), %str( ), %str(,))));   
               User = "&sysuserid";               
               if prec = "" then prec = "&trMissing";
               if postc = "" then postc = "&trMissing";
               call symput('flcn', catx(" ", _label_, cats("(",_name_,")")));
               if ntype = "C" then do;
                  call symput('fprec', prec);
                  call symput('fpostc', postc);
                  Note = resolve('%LocaleFill(&trVciXfXtX, &flcn, &fprec, &fpostc)');
               end;
               else if ntype = "N" and pren = . and postn > . then do;
                  call symput('flpostn', left(postn));
                  Note = resolve('%LocaleFill(&trVciXfXtX, &flcn, &trMissing, &flpostn)');
               end;
               else if ntype = "N" and postn = . and pren > . then do;
                  call symput('flp', left(pren));
                  Note = resolve('%LocaleFill(&trVciXfXtX, &flcn, &flp, &trMissing)'); 
               end;
               else if ntype = "N" and postn > . and pren > . then do;
                  call symput('flp', left(pren));
                  call symput('flpostn', left(postn));
                  Note = resolve('%LocaleFill(&trVciXfXtX, &flcn, &flp, &flpostn)');
               end;
               SystemGenerated = "Y";
               Date_of_Note = datetime();             
               format Date_of_Note DATETIME19.;
               label usubjid = "&USUBJIDLabel" Study_Name = "&trStudyName" Keys_Values = "&trKeysValues" Report = "&trReport" 
                  Date_of_Note = "&trDateofNote" SnapshotNumber = "&trSnapshotNumber" Type = "&trType" Keys = "&_trKeys" Domain = "&trDomain" User = "&trUser" Note = "&trNote" SystemGenerated = "&trSystemGenerated";
            run;
            %Nobsvars(mnotes);
            
            %if &nobs %then %do;
               %jg_getPath(/user/clinical/delta/modified,,3,0,0,&studynameunder);
               libname modified "%jg_getPath(/user/clinical/delta/modified,,0,0,3,&studynameunder)";
               data modified.&temp;
                  set mnotes(keep = usubjid study_name &&&temp.keys _name_ _label_ rename = (_name_ = Variable _label_ = Label));
                  label variable = "&trVariable";
                  label label = "&trLabel";
               run;
            %end;
            
            data dnotes(keep = SnapshotNumber Type usubjid Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated);
               length Study_Name $ 32 Report $ 60 Domain $ 8 Keys $ 200 Keys_Values $ 500 User $ 50 Note $ 1024 Type $ 24 SystemGenerated $ 1;
               set keys(where = (index(&temp.RFlg,"&trNonUnique") 
                  %if %length(&PostCount) %then %do;
                     or &PostCount > .
                  %end;          
                  %if %length(&PreCount) %then %do;
                     or &PreCount > .
                  %end;          
               ));
               Study_Name = "&StudyName";
               Report = "&trManageStudies";
               Domain = "&temp";
               Keys = "&&&temp.keys";
               SnapshotNumber = &CurrentReview;
               Type = "&trDuplicate";
               %if ^%length(&PreCount) %then %do;
                  PreCount = 0;
               %end;
               %if ^%length(&PostCount) %then %do;
                  PostCount = 0;
               %end;                             
               Keys_Values = catx("~", %sysfunc(transtrn(%str(&&&temp.keys), %str( ), %str(,))));   
               User = "&sysuserid";
               SystemGenerated = "Y";
               if PreCount = 0 or PostCount = 0 then Note = catx(" ", "&trDeftpk [&trprevious:",left(PreCount),"&trtimes, &trlcnew:", cats(left(PostCount), "]."));
               else Note = catx(" ", "&trDeftpk [&trprevious:",left(PreCount),"&trtimes, &trlcnew:", cats(left(PostCount), "]."), "&trNCPBS");
               Date_of_Note = datetime();             
               format Date_of_Note DATETIME19.;
               label usubjid = "&USUBJIDLabel" Study_Name = "&trStudyName" Keys_Values = "&trKeysValues" Report = "&trReport" 
                  Date_of_Note = "&trDateofNote" SnapshotNumber = "&trSnapshotNumber" Type = "&trType" Keys = "&_trKeys" Domain = "&trDomain" User = "&trUser" Note = "&trNote" SystemGenerated = "&trSystemGenerated";
            run;

            data drnotes(keep = SnapshotNumber Type usubjid Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated);
               length Study_Name $ 32 Report $ 60 Domain $ 8 Keys $ 200 Keys_Values $ 500 User $ 50 Note $ 1024 Type $ 24 SystemGenerated $ 1;
               set keys(where = (&temp.RFlg = "&trDropped"));
               Study_Name = "&StudyName";
               Report = "&trManageStudies";
               Domain = "&temp";
               Keys = "&&&temp.keys";
               SnapshotNumber = &CurrentReview;
               Type = "&trDropped";
               Keys_Values = catx("~", %sysfunc(transtrn(%str(&&&temp.keys), %str( ), %str(,))));   
               User = "&sysuserid";
               Note = "&trTPKWAIPDBNND";
               SystemGenerated = "Y";
               Date_of_Note = datetime();             
               format Date_of_Note DATETIME19.;
               label usubjid = "&USUBJIDLabel" Study_Name = "&trStudyName" Keys_Values = "&trKeysValues" Report = "&trReport" 
                  Date_of_Note = "&trDateofNote" SnapshotNumber = "&trSnapshotNumber" Type = "&trType" Keys = "&_trKeys" Domain = "&trDomain" User = "&trUser" Note = "&trNote" SystemGenerated = "&trSystemGenerated";
            run;
            
            %if ^%sysfunc(fileexist(&NotesDir.&notesDataset..sas7bdat)) %then %do;
               data NotesLib.&notesDataset (encoding=utf8);
                  retain SnapshotNumber Type usubjid %if %length(&Siteid) %then %do; siteid %end; %if %length(&country) %then %do; country %end; Study_Name Keys Keys_Values 
                     Domain Report User Note Date_of_Note SystemGenerated;
                  set mnotes(keep = SnapshotNumber Type usubjid Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated) dnotes drnotes;
                  %if %length(&Siteid) %then %do; 
                     label siteid = "&SiteIDLabel";
                  %end;                
                  %if %length(&country) %then %do; 
                     label country = "&countryLabel";
                  %end;                
               run;           
            %end;
            %else %do;
               %UPDATELENGTH;
               
               data mnotes;
                  retain SnapshotNumber Type usubjid %if %length(&Siteid) or %length(&notessiteid) %then %do; siteid %end; %if %length(&country) or %length(&notescountry) %then %do; country %end; 
                     Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated;
                  length usubjid $ &USUBJIDlength 
                         %if &notessiteid or %length(&SiteID) %then %do; siteid $ &SITEIDlength %end;
                         %if &notescountry or %length(&Country) %then %do; country $ &COUNTRYlength %end;
                         ;                     
                  set mnotes(keep = SnapshotNumber Type usubjid Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated) dnotes drnotes NotesLib.&notesDataset;
                  %if %length(&notessiteid) or %length(&SiteID) %then %do; 
                     label siteid = "&SiteIDLabel";
                  %end;
                  %if %length(&country) or %length(&notescountry) %then %do;
                     label country = "&countryLabel";
                  %end;
               run;

               proc sort data = mnotes out = NotesLib.&notesDataset;
                  by SnapshotNumber Date_of_Note;
               run;           
            %end;
            
            proc datasets nolist;
               delete mnotes dnotes drnotes;
            quit;
         %end;
         %else %if ((&temp ne ADSL and ^%symexist(prev_&temp)) or (&temp = ADSL and %length(&ADSLpre) and ^%length(&ADSLpost))) and &managetwo %then %do;
            %if ^&first %then %do;
               title;
               ods pdf text = "^S={font=('Arial')}";
               ods pdf text = "^S={font=('Arial')}";
               ods pdf text = "^S={font=('Arial') just=center} ----------------------------------------------------------------------";
               ods pdf text = "^S={font=('Arial') just=center} &trDiffRforStudy";
               ods pdf text = "^S={font=('Arial') just=center} ----------------------------------------------------------------------";
               ods pdf text = "^S={font=('Arial')}";
               ods pdf text = "^S={font=('Arial')}";  
               %let first = 1;
            %end;

            %let trNXDomNewAv = %nrbquote(%LocaleFill(%nrbquote(&trRepX4), f1=%nrbquote(&temp)));
            title;
            ods pdf text = "^S={font=('Arial')}";
            ods pdf text = "^S={font=('Arial')}";
            ods pdf text = "^S={font=('Arial') just=center} ----------------------------------------------------------------------";
            ods pdf text = "^S={font=('Arial') just=center} &trNXDomNewAv";
            ods pdf text = "^S={font=('Arial') just=center} ----------------------------------------------------------------------";
            ods pdf text = "^S={font=('Arial')}";
            ods pdf text = "^S={font=('Arial')}";           
         %end;
         %else %if (((&temp ne ADSL) or (&temp = ADSL and %length(&adslpresent))) and ^&managetwo) %then %do;
            *** Save Keys ***;         
            data DeltaLib.&temp;
               set keys;
            run;

            %let rschk = %sysfunc(open(keys));
            %let prechk = %sysfunc(varnum(&rschk,PreCount));
            %let postchk = %sysfunc(varnum(&rschk,PostCount));
            %let rschk = %sysfunc(close(&rschk));
            %let PreCount =;
            %let PostCount =;
            %if &PreChk %then %let PreCount = PreCount; 
            %if &PostChk %then %let PostCount = PostCount;
            
            %if ^&first %then %do;
               title;
               ods pdf text = "^S={font=('Arial')}";
               ods pdf text = "^S={font=('Arial')}";
               ods pdf text = "^S={font=('Arial') just=center} ----------------------------------------------------------------------";
               ods pdf text = "^S={font=('Arial') just=center} &trDKRforStudy";
               ods pdf text = "^S={font=('Arial')}";
               %LocaleWrap(%nrbquote(&trDKRIntro), _width=65, _lineprefix=%nrbquote(^S={font=('Arial') just=center} ), _format=pdf);
               ods pdf text = "^S={font=('Arial') just=center} ----------------------------------------------------------------------";
               ods pdf text = "^S={font=('Arial')}";
               ods pdf text = "^S={font=('Arial')}";  
               %let first = 1;
            %end;

            %let trNKFXD = %nrbquote(%LocaleFill(%nrbquote(&trRep10), f1=%nrbquote(&temp)));
            %let trNKSAUFXD = %nrbquote(%LocaleFill(%nrbquote(&trRep11), f1=%nrbquote(&temp)));
            %let trXKWDupsNCXNU = %nrbquote(%LocaleFill(%nrbquote(&trRep12), f1=%nrbquote(&temp), f2=%nrbquote(&temp.RFlg)));
            title;
            ods pdf text = "^S={font=('Arial')}";
            ods pdf text = "^S={font=('Arial')}";
            ods pdf text = "^S={font=('Arial') just=center} ----------------------------------------------------------------------";
            ods pdf text = "^S={font=('Arial') just=center} &trNKFXD";
            ods pdf text = "^S={font=('Arial') just=center} &&&temp.keys";
            %if %length(&&&temp.keysmiss) %then %do;           
               ods pdf text = "^S={font=('Arial')}";
               ods pdf text = "^S={font=('Arial') just=center} &trNKSAUFXD";
               ods pdf text = "^S={font=('Arial') just=center} &&&temp.keysmiss";            
            %end;
            ods pdf text = "^S={font=('Arial') just=center} ----------------------------------------------------------------------";
            ods pdf text = "^S={font=('Arial')}";
            ods pdf text = "^S={font=('Arial')}";              

            title "&trXKWDupsNCXNU";
            proc print width = min noobs label data = keys 
               style(bylabel) = [font_size = 7pt] style(obs) = [font_size = 7pt] style(obsheader) = [font_size = 7pt];
               var &&&temp.keys &temp.RFlg &PreCount &PostCount / style(data) = [font_size = 7pt] style(header) = [background=white font_size = 7pt];
               where index(&temp.RFlg, "&trNonUnique") 
               %if %length(&PostCount) %then %do;
                  or &PostCount > .
               %end;
               ;
            run;           
            
            data dnotes(keep = SnapshotNumber Type usubjid Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated);
               length Study_Name $ 32 Report $ 60 Domain $ 8 Keys $ 200 Keys_Values $ 500 User $ 50 Note $ 1024 Type $ 24 SystemGenerated $ 1;
               set keys(where = (index(&temp.RFlg,"&trNonUnique")
                  %if %length(&PostCount) %then %do;
                     or &PostCount > .
                  %end;          
                  %if %length(&PreCount) %then %do;
                     or &PreCount > .
                  %end;                                        
               ));
               Study_Name = "&StudyName";
               Report = "&trManageStudies";
               Domain = "&temp";
               Keys = "&&&temp.keys";
               SnapshotNumber = 0;
               Type = "&trDuplicate";
               Keys_Values = catx("~", %sysfunc(transtrn(%str(&&&temp.keys), %str( ), %str(,))));   
               User = "&sysuserid";
               SystemGenerated = "Y";
               Note = catx(" ", "&trDeftpk [&trlcnew:", left(PostCount), "&trtimes].");            
               Date_of_Note = datetime();             
               format Date_of_Note DATETIME19.;
               label usubjid = "&USUBJIDLabel" Study_Name = "&trStudyName" Keys_Values = "&trKeysValues" Report = "&trReport" 
                  Date_of_Note = "&trDateofNote" SnapshotNumber = "&trSnapshotNumber" Type = "&trType" Keys = "&_trKeys" Domain = "&trDomain" User = "&trUser" Note = "&trNote" SystemGenerated = "&trSystemGenerated";
            run;
            %NObsVars(dnotes);
            
            %if ^&nobs %then %do;
               %let trNNdupsXdom = %nrbquote(%LocaleFill(%nrbquote(&trRep13), f1=%nrbquote(&temp)));
               title;
               ods pdf text = "^S={font=('Arial')}";
               ods pdf text = "^S={font=('Arial')}";
               ods pdf text = "^S={font=('Arial') just=center} ----------------------------------------------------------------------";
               ods pdf text = "^S={font=('Arial') just=center} &trNNdupsXdom";
               ods pdf text = "^S={font=('Arial') just=center} ----------------------------------------------------------------------";
               ods pdf text = "^S={font=('Arial')}";
               ods pdf text = "^S={font=('Arial')}";              
            %end;

            %if ^%sysfunc(fileexist(&NotesDir.&notesDataset..sas7bdat)) %then %do;           
               data NotesLib.&notesDataset (encoding=utf8);
                  retain SnapshotNumber Type usubjid %if %length(&Siteid) %then %do; siteid %end; %if %length(&country) %then %do; country %end; Study_Name Keys Keys_Values 
                     Domain Report User Note Date_of_Note SystemGenerated;
                  set dnotes;
                  %if %length(&SiteID) %then %do; 
                     label siteid = "&SiteIDLabel";
                  %end;                         
                  %if %length(&country) %then %do; 
                     label country = "&countryLabel";
                  %end;                         
               run;
            %end;
            %else %do;  
               %UPDATELENGTH;
               
               data dnotes;
                  retain SnapshotNumber Type usubjid %if %length(&Siteid) or &notessiteid %then %do; siteid %end; %if %length(&country) or &notescountry %then %do; country %end; 
                     Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated;
                  length usubjid $ &USUBJIDlength 
                         %if &notessiteid or %length(&SiteID) %then %do; siteid $ &SITEIDlength %end;
                         %if &notescountry or %length(&Country) %then %do; country $ &COUNTRYlength %end;
                         ;                     
                  set dnotes NotesLib.&notesDataset;
                  %if &notessiteid or %length(&SiteID) %then %do; 
                     label siteid = "&SiteIDLabel";
                  %end;
                  %if %length(&country) or &notescountry %then %do; 
                     label country = "&countryLabel";
                  %end;
               run;

               proc sort data = dnotes out = NotesLib.&notesDataset;
                  by SnapshotNumber Date_of_Note;
               run;

               proc datasets nolist;
                  delete dnotes ;
               quit;      
            %end;
         %end;

         %if &managetwo %then %do;
            proc datasets nolist;
               delete keys pre post prepost;
            quit;         
         %end;
         %else %do;
            proc datasets nolist;
               delete keys post;
            quit;                                           
         %end;         
      %end;
      %let i = %eval(&i+1);
   %end; 
   ods pdf close;
   ods listing;
   %if &managetwo %then %do;
      %if ^%index(&Task,Rename) %then %do;   
         %UPDATESUBJECTFLAGS;
      %end;
      *** delete previous transformed supp ***;
      %if &InclSuppComp = YES %then %do;
         proc datasets library = basemeta memtype = (data) nolist; 
            delete tsupp:;
         quit;
     %end;      
   %end;
   %exitcomp:;
   %put Exiting COMPARE;
   %ClockStop(COMPARE);        
%mend COMPARE;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro DOMAINLISTADD;
   %put Entering DOMAINLISTADD;
   %ClockStart(DOMAINLISTADD);
   %let relrecflag =0;
   %let pooldefflag =0;
   %if %sysfunc(fileexist(&InPath.relrec.sas7bdat)) %then %let relrecflag =1;
   %if %sysfunc(fileexist(&InPath.pooldef.sas7bdat)) %then %let pooldefflag =1;
   data suppdomainsInc;
      set AllDomains;
      if find(Label, "Supplemental");
      if Folder ="SDTM" & (length(table) > 6 & substr(table,1,6) ^= "SUPPFA") then delete;
   run;
   %let suppinADaM = 0;
   * remove supp in ADAM from suppdomain list;
   %if %length(&AInPath) & %length(&suppdomains) %then %do;
   	%let i=1;
		data SuppFileList;
			%do %while(%length(%scan(&suppdomains,&i,' ')));
				Table = "%scan(&suppdomains,&i,' ')";
				output;
				%let i = %eval(&i+1);
			%end;
      run;
   	proc sort data=suppdomainsInc;
   		by table;
   	run;
   	proc sort data=SuppFileList;
   		by table;
   	run;
   	%nObsVars(suppdomainsInc);
		%let n1=&nobs;
		%nObsVars(SuppFileList);
		%let n2=&nobs;
		%if &n1>&n2 %then %let suppinADaM =1; 
		%if &suppinADaM %then %do;
   		data suppADaM;
   			merge suppdomainsInc(in=a) SuppFileList(in=b);
   			by table;
   			if (a and not b);
   			Folder= flag;
   		run;
   	%end;
   	data suppdomainsInc;
   		merge suppdomainsInc SuppFileList(in=b);
   		by table;
   		if b;
   	run;
   %end;

   data splitdomainsInc;
   	set AllDomains;
   	if find(class, "Split");
   run;
   data trialdomains;
      set AllDomains;
      if upcase(class) in ("TRIAL DESIGN");
   run;
   data AllDomains2;
   	set AllDomains;
   	if find(Label, "RELREC", "POOLDEF") then delete;
		if Folder ="SDTM" & (length(table) > 6 & substr(table,1,6) ^= "SUPPFA") then delete;
		if Folder ="SDTM" & ((length(table) =3 or length(table) =4) and substr(table,1,2) ^= "FA") then delete;
		if upcase(class) in ("OTHER") then delete;
   run;
   proc sort data=AllDomains2;
      by table;
   run;
   proc sort data=AllnoUsedDom;
      by table;
   run;
   data AllnoUsedDom2;
      length table $8.;
      merge AllDomains2(in=a) AllnoUsedDom(in=b);
      by table;
      if (not a and b);
   run;
   %if &suppinADaM %then %do;
   	data AllnoUsedDom2;
   		set AllnoUsedDom2 suppADaM;
   	run;  
   %end;
   data AllDomains2;
      set AllDomains2;
      if find(Label, "Supplemental") or find(class, "Split") then delete;
      if flag ="SDTM" and length(table) >2 then delete;
      if upcase(class) in ("TRIAL DESIGN") then delete;
   run;
   %if &relrecflag or &pooldefflag %then %do;
      data relationdomains;
         set AllnoUsedDom2;
         if table ="RELREC" or table ="POOLDEF";
      run;
   %end;

   data AllnoUsedDom2;
      set AllnoUsedDom2;
      if table ="RELREC" or table ="POOLDEF" then delete;
   run;

   options orientation = landscape nodate missing = "" sysprint="";
   ods escapechar = "^";
   ods listing close;
   ods pdf file = "&ClientOutPath.&StudyName DomainList.pdf" notoc style = statdoc;
   
   %let trIncludedDoms = %nrbquote(%LocaleGet(ListofIncludedDomainsinJMPClinicalStudy_Text));
   %let trExcludedDoms = %nrbquote(%LocaleGet(ListofExcludedDomainsinJMPClinicalStudy_Text));
   %let trSupplementDoms = %nrbquote(%LocaleGet(ListofSupplementalDomainsinJMPClinicalStudy_Text));
   %let trSplitDoms = %nrbquote(%LocaleGet(ListofSplitDomainsinJMPClinicalStudy_Text));
   %let trTrialDoms = %nrbquote(%LocaleGet(ListofTrialDesignDomainsinJMPClinicalStudy_Text));
   %let trRelationshipDoms = %nrbquote(%LocaleGet(ListofRelationshipsDomainsinJMPClinicalStudy_Text));

   %let titDomList= %nrbquote(%LocaleFill(&trIncludedDoms, %nrbquote(&StudyName)));
   %let titNoUsedDomList = %nrbquote(%LocaleFill(&trExcludedDoms, %nrbquote(&StudyName)));
   %let suppDomList = %nrbquote(%LocaleFill(&trSupplementDoms, %nrbquote(&StudyName)));
   %let splitDomList = %nrbquote(%LocaleFill(&trSplitDoms, %nrbquote(&StudyName)));
   %let trialDomList = %nrbquote(%LocaleFill(&trTrialDoms, %nrbquote(&StudyName)));
   %let relationDomList = %nrbquote(%LocaleFill(&trRelationshipDoms, %nrbquote(&StudyName)));
   %let domListDoclink = %nrbquote(%LocaleGet(PleaseRefToHDJMPCIDForInfWhyDomMayExc_Text));   
   %let trAvailableDomains = %nrbquote(%LocaleGet(AvailableDomains_Text));
   %let trFolders = %nrbquote(%LocaleGet(Folders_Text));
   %let trDomainsnotusedinJMPC = %nrbquote(%LocaleGet(DomainsnotusedinJMPC_Text));
   %let trClickHere = %nrbquote(%LocaleGet(ClickHere_Text));
   %if %symexist(adamExcluded) %then %do;
   	%let _i_=1;
   	%do %while(%length(%scan(&adamExcluded,&_i_,' ')));
   		%let temp = %scan(&adamExcluded,&_i_,' ');
   		%if %sysfunc(findw(&eventsdomains, %substr(%upcase(&temp),3))) %then %do;
   			%let ExcludedAdamDom&_i_ = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(NoteExcludedADAMDomainsNotStandard_Text)),f1=%nrbquote(%substr(&temp,3)TERM),f2=%nrbquote(PARAM),f3 = %nrbquote(&temp) ));
   		%end;
   		%else %if %sysfunc(findw(&interventionsdomains, %substr(%upcase(&temp),3))) %then %do;
   			%let ExcludedAdamDom&_i_ = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(NoteExcludedADAMDomainsNotStandard_Text)),f1=%nrbquote(%substr(&temp,3)TRT),f2=%nrbquote(PARAM),f3 = %nrbquote(&temp)));
   		%end;
   		%else %let ExcludedAdamDom&_i_ = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(NoteExcludedADAMDomainsWithPARAM_Text)),f1 = %nrbquote(&temp)));
   		%let _i_ = %eval(&_i_+1); 
   	%end;
   %end;
   
   title height=17pt "&titDomList";
   proc report nowindows missing nofs colwidth=15 style = {frame = void rules=none} data = AllDomains2;
      column table Flag;
      define table / left width = 15 "&trAvailableDomains";
      define Flag / left width = 15 "&trFolders";
   run;
   
   title height=17pt "&suppDomList";
   proc report nowindows missing nofs colwidth=15 style = {frame = void rules=none} data = suppdomainsInc;
      column table Flag;
      define table / left width = 15 "&trAvailableDomains";
      define Flag / left width = 15 "&trFolders";
   run;  
   %if %length(&splittingdomains) %then %do;
   	title height=17pt "&splitDomList";
   	proc report nowindows missing nofs colwidth=15 style = {frame = void rules=none} data = splitdomainsInc;
   	   column table Flag;
   	   define table / left width = 15 "&trAvailableDomains";
   	   define Flag / left width = 15 "&trFolders";
   	run; 
   %end;
   %if &relrecflag or &pooldefflag %then %do;
      title height=17pt "&relationDomList";
      proc report nowindows missing nofs colwidth=15 style = {frame = void rules=none} data = relationdomains;
         column table Folder;
         define table / left width = 15 "&trAvailableDomains";
         define Folder / left width = 15 "&trFolders";
      run;
   %end;
   title height=17pt "&trialDomList";
   proc report nowindows missing nofs colwidth=15 style = {frame = void rules=none} data = trialdomains;
      column table Flag;
      define table / left width = 15 "&trAvailableDomains";
      define Flag / left width = 15 "&trFolders";
   run;   
   title height=17pt "&titNoUsedDomList";
   proc report nowindows missing nofs colwidth=15 style = {frame = void rules=none} data = AllnoUsedDom2;
      column table Folder;
      define table / left width = 15 "&trDomainsnotusedinJMPC";
      define Folder / left width = 15 "&trFolders";
   run; 
   title ;
   ods pdf text= "^S={font=('Arial')}";
   ods pdf text = "^S={font=('Arial')}";
   %if %symexist(adamExcluded) %then %do;
   	%let _i_=1;
   	%do %while(%length(%scan(&adamExcluded,&_i_,' ')));
   		ods pdf text = "^S={font=('Arial') FONTSIZE=2 just=left} &&&ExcludedAdamDom&_i_";
   		%let _i_ = %eval(&_i_+1);
   	%end;
   %end;
   ods pdf text = "^S={font=('Arial')}";
   ods escapechar="^";
   ods pdf text = "^S={font=('Arial') FONTSIZE=4 just=center} &domListDoclink";         
   ods escapechar="^";
   ods pdf text="^S={font=('Arial') FONTSIZE=3  just=center URL='&DocLinkIdDomsIncStudy'} &trClickHere";
   
   ods pdf close;
   ods listing;
   proc datasets nolist;
      delete Alldomains Alldomains2 AllnoUsedDom AllnoUsedDom2;
   quit;
   %exitdomadd:;
   %put Exiting DOMAINLISTADD;
   %ClockStop(DOMAINLISTADD);           
%mend DOMAINLISTADD;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro GETPREVDATA;
   %put Entering GETPREVDATA;
   %ClockStart(GETPREVDATA);        
   %let studynameunder = %sysfunc(transtrn(&StudyName, %str( ), _));
   %include "&MacroPath./UtilityPathMacros.sas" / nosource;
   
   data getprev;     
      infile "%jg_getPath(/user/clinical/metadata/base, CSTMacroVars.sas, 0, 0, 3, &studynameunder)" linesize = 200 pad;
      input text $ 1-200;
      if substr(left(text),1,8) = "%nrstr(%let) in_" or substr(left(text),1,10) = "%nrstr(%let) Orig_" or substr(left(text),1,13) = "libname sdtm " or substr(left(text),1,13) = "libname adam ";
      if substr(left(text),1,12) = "%nrstr(%let) in_ADSL" then delete;
   run;

   data getprev;
      set getprev;
      text = trim(text);
      text = transtrn(text, "%nrstr(%let) in_", "%nrstr(%let) prev_");
      text = transtrn(text, "%nrstr(%let) Orig_", "%nrstr(%let) prev_");
      text = transtrn(text, "libname sdtm", "libname prevsdtm");
      text = transtrn(text, "libname adam", "libname prevadam");
      text = transtrn(text, "= sdtm.", "= prevsdtm.");
      text = transtrn(text, "= adam.", "= prevadam.");
   run;
   
   * get previous snapshot KEYS and then concatenate with getprev table;
   data getprevsnpKeys;     
      infile "%jg_getPath(/user/clinical/metadata/base, CSTMacroVars.sas, 0, 0, 3, &studynameunder)" linesize = 200 pad;
      input text $ 1-200;
      if substr(left(text),1,4) = "%nrstr(%let)" and substr(left(text),8,4) = "KEYS";
   run;
   data getprevsnpKeys;
   	set getprevsnpKeys;
   	text = trim(text);
   	text = transtrn(text, "%nrstr(%let) ", "%nrstr(%let) prev_");
   run;
   data getprev;
   	set getprev getprevsnpKeys;
   run;

   *** copy supp domains for comparisons ***;
   %if &InclSuppComp = YES %then %do;   
      %let meta=%jg_getPath(/user/clinical/metadata,,0,0,3,&studynameunder);  
      %let derivedmetaSupp=%jg_getPath(/user/clinical/dataderivedmetadata/supp,,0,0,3,&studynameunder); 
       
      libname sdtmmeta "&meta.SDTM";
      libname basemeta "&meta.BASE";
      libname suppmeta "&derivedmetaSupp";
      
      proc copy in = suppmeta memtype = (data) out = basemeta;
         select tsupp:;
      run;
   %end;
   
   %let ReviewPlus = %eval(&CurrentReview+1);
   libname RevLib "&ServerOutPath";
   *** Temporarily Save in Output Folder ***;   
   data RevLib.DeltaFile&ReviewPlus;
      *file "&ServerOutPath.DeltaFile&ReviewPlus..sas";
      set getprev;
      put text;
   run;

   proc datasets nolist;
      delete getprev getprevsnpKeys;
   quit;
   %put Exiting GETPREVDATA;
   %ClockStop(GETPREVDATA);        
%mend GETPREVDATA;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro MAKENOTES;
   %put Entering MAKENOTES;
   %ClockStart(MAKENOTES);        
   %let trrflg = %nrbquote(%LocaleGet(ReviewFlag_Text));
   %let trReviewed = %nrbquote(%LocaleGet(Reviewed_Text));
   %let trUnreviewed = %nrbquote(%LocaleGet(Unreviewed_Text));
   %let trIntroduced = %nrbquote(%LocaleGet(Introduced_Text));
   %let trPreviouslyAvailable = %nrbquote(%LocaleGet(PreviouslyAvailable_Text));
   %let trUser = %nrbquote(%LocaleGet(User_Text));   
   
   %let studynameunder = %sysfunc(transtrn(&studyname, %str( ), _));
   *** if notes directory doesnt exist create one ***;
   %include "&MacroPath./UtilityPathMacros.sas" / nosource;
   %let rc = %sysfunc(filename(fileref,%jg_getPath(/user/clinical/notes,,0,0,3,&studynameunder))); 
   %if ^%sysfunc(fexist(&fileref)) %then %do;
      %jg_getPath(/user/clinical/notes,,3,0,0,&studynameunder);
   %end;
      
   %if &sysscp = WIN %then %do;
      %let _slash_ = \;
   %end;
   %else %do;
      %let _slash_ = /;
   %end;

   *** if notes directory for study doesnt exist create one ***;
   %let rc = %sysfunc(filename(fileref,%jg_getPath(/user/clinical/notes,,0,0,3,&studynameunder))); 
   %if ^%sysfunc(fexist(&fileref)) %then %do;
      %jg_getPath(/user/clinical/notes,,3,0,0,&studynameunder);
   %end;
   
   libname NotesLib "%jg_getPath(/user/clinical/notes,,0,0,3,&studynameunder)";
   %global NotesDir; 
   %let NotesDir = %jg_getPath(/user/clinical/notes,,0,0,3,&studynameunder);

   * for Review packaging used (T.C. 06/21/13 S0984129);
   %if ^%symexist(AddinPackageFlag) %then %do;
      %global AddinPackageFlag;
      %let AddinPackageFlag = 0;
   %end;

/* 
   *** Kemicl: No longer delete adslrs on AddStudy to accommodate Shared notes ***;
   *** If adding a study start the review data set anew ***;
   %if &ProcessName = AddStudyLocal & &AddinPackageFlag = 0 %then %do;     
      data _null_;
         fname = "tempfile";
         rc = filename(fname,"&NotesDir.adslrs.sas7bdat");
         if rc = 0 and fexist(fname) then rc = fdelete(fname);
         rc = filename(fname);
      run;  
      
      data _null_;
         fname = "tempfile";
         rc = filename(fname,"&NotesDir.adslrsl.sas7bdat");
         if rc = 0 and fexist(fname) then rc = fdelete(fname);
         rc = filename(fname);
      run;        
   %end;
*/    
   * assign macro for review status and create default data sets if necessary;   
   %if ^%sysfunc(exist(NotesLib.adslrsl)) %then %do;
      data NotesLib.adslrsl (encoding=utf8);
         RSTATUS = "&trUnreviewed";
         output;
         RSTATUS = "&trReviewed";
         output;
      run;
   %end;
   %if ^%sysfunc(exist(NotesLib.adslrs)) %then %do;
      data _null_;
         set NotesLib.adslrsl(obs=1);
         call symput('defaultrs',trim(left(RSTATUS)));
      run;
      data NotesLib.adslrs (encoding=utf8);
         retain USUBJID RSTATUS ReviewFlag DateAdded DateUpdated User ;
         length ReviewFlag $ 20 DateAdded $ 19 DateUpdated $ 19   User $ 50 ;
         set &in_adsl;
         RSTATUS = "&defaultrs";
         ReviewFlag = "&trIntroduced"; 
         DateAdded = put(datetime(),E8601DT19.);
         DateUpdated = put(datetime(),E8601DT19.);
         User = "&sysuserid";         
         label DateAdded = "DateTime Subject Added to Data Set" ReviewFlag = "&trrflg" User = "&trUser" 
         DateUpdated = "DateTime of Last Status Update";
         keep USUBJID RSTATUS ReviewFlag User DateAdded DateUpdated;
      run;
   %end;
   %else %do;
      %if &ProcessName = AddStudyLocal %then %do;
         proc sort data=NotesLib.adslrs(keep= USUBJID) out=currSubList;
            by USUBJID;
         run;
         
         proc sort data=&in_adsl(keep=USUBJID) out=newSubList;
            by USUBJID;
         run;
         
         data checksubs;
            merge currSubList(in=a) newSubList(in=b);
            by USUBJID;
            if (a and not b) or (not a and b);
         run;
         
         %nobsvars(checksubs);
         %if &nobs %then %do; 
            %put [MS_S_0375];
            %put ERROR: A notes directory exists for a study previously defined as &StudyName and the subject list for the study you are adding does not match...Please choose a different study name or move/remove the notes directory.;
            %put The notes directory is located at %jg_getPath(/user/clinical/notes,,0,0,3,&studynameunder);
            %let exiterror = 1;
            %goto mnexit;
         %end;
      %end;
      %else %do;
         *** Patch to move NOTES to notes dataset ***;      
         %let rschk = %sysfunc(open(NotesLib.adslrs));
         %let notenum = %sysfunc(varnum(&rschk,Notes));
         %let rschk = %sysfunc(close(&rschk));

         %if &notenum %then %do;
            data notes (encoding=utf8);
               set NotesLib.adslrs;
               where notes ne "";
            run;
            %Nobsvars(notes);
            %if &nobs=0 %then %do;
               proc datasets nolist;
                  delete notes;
               quit;
            %end;
            %else %do;
               %let trPatientProfiler = %nrbquote(%LocaleGet(PatientProfiler_Text));
               %let trStudyName = %nrbquote(%LocaleGet(StudyName_Text));
               %let trKeysValues = %nrbquote(%LocaleGet(KeysValues_Text));
               %let trReport = %nrbquote(%LocaleGet(Report_Text));
               %let trDateofNote = %nrbquote(%LocaleGet(DateofNote_Text));
               %let trSnapshotNumber = %nrbquote(%LocaleGet(SnapshotNumber_Text));
               %let trSnapshot = %nrbquote(%LocaleGet(Snapshot_Text));
               %let trType = %nrbquote(%LocaleGet(Type_Text));
               %let _trKeys = %nrbquote(%LocaleGet(Keys_Text));
               %let trDomain = %nrbquote(%LocaleGet(Domain_Text));
               %let trUser = %nrbquote(%LocaleGet(User_Text));
               %let trNote = %nrbquote(%LocaleGet(Note_Text));
               %let trSystemGenerated = %nrbquote(%LocaleGet(SystemGenerated_Text));
               
               data notes (encoding=utf8);
                  length Domain $ 8 Keys $ 200 Keys_Values $ 500 User $ 50 Type $ 24 ;
                  set notes(rename = (notes = Note) drop = rstatus);
                  Report = "&trPatientProfiler";
                  Study_Name = "&StudyName";
                  SnapshotNumber = 0;
                  User = "&sysuserid";
                  Type = "&trSnapshot";
                  Date_of_Note = dhms(mdy(substr(DateAdded, 6, 2), substr(DateAdded, 9, 2), substr(DateAdded, 1, 4)), 
                     substr(DateAdded, 12, 2), substr(DateAdded, 15, 2), substr(DateAdded, 18, 2));
                  drop DateAdded;
                  format Date_of_Note DATETIME19.;
                  label Date_of_Note = "&trDateofNote" Report = "&trReport" Study_Name = "&trStudyName" Keys_Values = "&trKeysValues" 
                     SnapshotNumber = "&trSnapshotNumber" Type = "&trType" Keys = "&_trKeys" Domain = "&trDomain" User = "&trUser" Note = "&trNote";
               run;

               %if ^%sysfunc(fileexist(&NotesDir.&notesDataset..sas7bdat)) %then %do;
                  data NotesLib.&notesDataset (encoding=utf8);
                     retain SnapshotNumber Type usubjid %if %length(&Siteid) %then %do; siteid %end; %if %length(&country) %then %do; country %end; Study_Name Keys Keys_Values 
                        Domain Report User Note Date_of_Note SystemGenerated;
                     set notes;
                     %if %length(&SiteID) %then %do; 
                        label siteid = "&SiteIDLabel";
                     %end;                         
                     %if %length(&Country) %then %do; 
                        label Country = "&CountryLabel";
                     %end;                         
                  run;
               %end;
               %else %do;
                  %UPDATELENGTH;
               
                  data notes (encoding=utf8);
                     retain SnapshotNumber Type usubjid %if &notessiteid or %length(&SiteID) %then %do; siteid %end; %if &notescountry or %length(&country) %then %do; country %end; 
                        Study_Name Keys Keys_Values Domain Report User Note Date_of_Note SystemGenerated;
                     length usubjid $ &USUBJIDlength 
                            %if &notessiteid or %length(&SiteID) %then %do; siteid $ &SITEIDlength %end;
                            %if &notescountry or %length(&Country) %then %do; country $ &COUNTRYlength %end;
                            ;                     
                     set notes NotesLib.&notesDataset;
                     %if &notessiteid or %length(&SiteID) %then %do; 
                        label siteid = "&SiteIDLabel";
                     %end;
                     %if &notescountry or %length(&country) %then %do;
                        label Country = "&CountryLabel";
                     %end;
                  run;

                  proc sort data = notes out = NotesLib.&notesDataset;
                     by SnapshotNumber Date_of_Note;
                  run;
               %end;

               proc datasets nolist;
                  delete &notesDataset;
               quit;
            %end;

            data NotesLib.adslrs (encoding=utf8);
            retain USUBJID RSTATUS ReviewFlag DateAdded DateUpdated  User;
            length ReviewFlag $ 20 DateAdded $ 19 DateUpdated $ 19   User $ 50 ;
               set NotesLib.adslrs;
               ReviewFlag = "&trIntroduced";     
               DateUpdated = put(datetime(),E8601DT19.);    
               User = "&sysuserid";   
               drop notes;
            run;
         %end;    

         *** Add New Subjects ***;
         data _null_;
            set NotesLib.adslrsl(obs=1);
            call symput('defaultrs',trim(left(RSTATUS)));
         run;

         data new(keep = usubjid);
            set &in_adsl;
         run;

         proc sort data = new;
            by usubjid;
         run;

         data old;
            set NotesLib.adslrs;
         run;

         proc sort data = old;
            by usubjid;
         run;

         data new;
            length ReviewFlag $ 20 DateAdded $ 19 DateUpdated $ 19 User $ 50   ;
            merge old(in = ina) new(in = inb);
            by usubjid;
            if inb and not ina;
            RSTATUS = "&defaultrs";
            ReviewFlag = "&trIntroduced";    
            DateAdded = put(datetime(),E8601DT19.);       
            DateUpdated = put(datetime(),E8601DT19.);
            User = "&sysuserid";         
            label DateAdded = "DateTime Subject Added to Data Set" ReviewFlag = "&trrflg" User = "&trUser" 
            DateUpdated = "DateTime of Last Status Update";
            keep USUBJID RSTATUS ReviewFlag DateAdded User DateUpdated;
         run;

         data old;
            retain USUBJID RSTATUS ReviewFlag User DateAdded DateUpdated;
            set old(in = ina) new;
            %if &ProcessName = ManageStudies %then %do;
               %if ^%index(&Task,Rename) %then %do;   
                  if ina and (ReviewFlag = "Introduced" or ReviewFlag = "&trIntroduced") then do;
                     ReviewFlag = "&trPreviouslyAvailable";
                  end;
               %end;
            %end;
         run;   

         proc sort data = old out = NotesLib.adslrs;
            by usubjid;
         run;

         proc datasets nolist;
            delete old new;
         quit; 
      %end;
   %end;
   
   data _null_;
      file "%FileWorkIt(&basemeta&_slash_.CSTMacroVars.sas)" mod;
      put "%nrstr(%global) NotesDir in_adslrs in_adslrsl;";
      put "%nrstr(%let) NotesDir = &NotesDir;";
      put "libname NotesLib '&NotesDir';";
      put "%nrstr(%let) in_adslrs = NotesLib.adslrs;";
      put "%nrstr(%let) in_adslrsl = NotesLib.adslrsl;";      
   run;  
   %mnexit:;
   %put Exiting MAKENOTES;
   %ClockStop(MAKENOTES);           
%mend MAKENOTES;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro UPDATELENGTH;
   %global notesusubjid notessiteid notescountry;
   %let _tid_ = %sysfunc(open(noteslib.&notesDataset));
      %let notesusubjid = %sysfunc(varnum(&_tid_,USUBJID));         
      %let notessiteid = %sysfunc(varnum(&_tid_,SITEID));
      %let notescountry = %sysfunc(varnum(&_tid_,COUNTRY));
      %if &notesusubjid %then %let Ulength_ = %sysfunc(varlength(&_tid_,&notesusubjid));
      %else %let Ulength_ = 0;
      %if &notessiteid %then %let Slength_ = %sysfunc(varlength(&_tid_,&notessiteid));
      %else %let Slength_ = 0;         
      %if &notescountry %then %let Clength_ = %sysfunc(varlength(&_tid_,&notescountry));
      %else %let Clength_ = 0;         
      %let USUBJIDlength = %sysfunc(max(&USUBJIDlength,&Ulength_));
      %let SITEIDlength = %sysfunc(max(&SITEIDlength,&Slength_));
      %let COUNTRYlength = %sysfunc(max(&COUNTRYlength,&Clength_));         
   %let _tid_ = %sysfunc(close(&_tid_));
%mend UPDATELENGTH;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;

%macro CHKBLIND(domain = );
   %if &domain = DM or &domain = ADSL %then %do;   
      *** Need to check if ARM in data and if so if null ***;      
      %if &domain = DM and ^%sysfunc(findw(&alladamdomains, AD&domain)) %then %do;
         %let rschk = %sysfunc(open(sdtm.&domain));
         %let varlist = &&&domain.VAR;
         %let varlist2 = &&domain.VAR;
      %end;
      %else %if &domain = DM %then %do;
         %let rschk = %sysfunc(open(adam.AD&domain));
         %let varlist = &&AD&domain.VAR;
         %let varlist2 = AD&domain.VAR;
      %end;
      %else %do;
         %let rschk = %sysfunc(open(adam.&domain));
         %let varlist = &ADSLVAR;
         %let varlist2 = ADSLVAR;
      %end;  
      %let armchk = %sysfunc(varnum(&rschk,ARM));
      %let pchk = %sysfunc(varnum(&rschk,TRT01P));
      %let achk = %sysfunc(varnum(&rschk,TRT01A));
      %let actchk = %sysfunc(varnum(&rschk,ACTARM));
      %let rschk = %sysfunc(close(&rschk));

      %if ^&armchk or (&armchk and ^%sysfunc(findw(&varlist, ARM))) %then %do;
         %let &domain.Blind = 1;
         %if &domain = DM and ^%length(&adslpresent) %then %let ADSLBlind = 1;
         %if &pchk %then %do;
				%if %sysfunc(findw(&varlist, TRT01P)) %then %do;
	            %CUTWORD(list = &varlist2, word = TRT01P);
				%end;
         %end;
         %if &achk %then %do;
         	%if %sysfunc(findw(&varlist, TRT01A)) %then %do;
         	   %CUTWORD(list = &varlist2, word = TRT01A);
				%end;
         %end;
         %if &actchk %then %do;
				%if %sysfunc(findw(&varlist, ACTARM)) %then %do;
            	%CUTWORD(list = &varlist2, word = ACTARM);
            %end;
         %end;               
      %end;
   %end;
   %else %if &domain = EX %then %do;
      %if ^%sysfunc(findw(&alladamdomains, AD&domain)) %then %do;
         %let rschk = %sysfunc(open(sdtm.&domain));
         %let varlist = &&&domain.VAR;
         %let varlist2 = &&domain.VAR;
      %end;
      %else %do;
         %let rschk = %sysfunc(open(adam.AD&domain));
         %let varlist = &&AD&domain.VAR;
         %let varlist2 = AD&domain.VAR;
      %end;      
      %let doschk = %sysfunc(varnum(&rschk,EXDOSE));
      %let trtchk = %sysfunc(varnum(&rschk,EXTRT));
      %let rschk = %sysfunc(close(&rschk));

      %if ^&doschk or (&doschk and ^%sysfunc(findw(&varlist, EXDOSE))) or ^&trtchk or (&trtchk and ^%sysfunc(findw(&varlist, EXTRT))) %then %let &domain.Blind = 1;                        
   %end; 
%mend CHKBLIND;

*************************************************************************************;
*************************************************************************************;
*************************************************************************************;